models/account library

Classes

Account
auto generated This is an object representing a Stripe account. You can retrieve it to seeproperties on the account like its current requirements or if the account isenabled to make live charges or receive payouts.For accounts where controller.requirement_collectionis application, which includes Custom accounts, the properties below are alwaysreturned.For accounts where controller.requirement_collectionis stripe, which includes Standard and Express accounts, some properties are only returneduntil you create an Account Link or Account Sessionto start Connect Onboarding. Learn about the differences between accounts.