Account constructor
Account()
Instantiates a new Account and sets the default values.
Implementation
Account() : additionalData = {};
Instantiates a new Account and sets the default values.
Account() : additionalData = {};