defaultCurrency property

String? defaultCurrency
getter/setter pair

Three-letter ISO currency code representing the default currency for the account. This must be a currency that Stripe supports in the account's country.

Implementation

String? defaultCurrency;