currentlyDue property

Iterable<String>? currentlyDue
getter/setter pair

Fields that need to be resolved to keep the capability enabled. If not resolved by future_requirements[current_deadline], these fields will transition to the main requirements hash.

Implementation

Iterable<String>? currentlyDue;