models/account_link library
Classes
- AccountLink
- auto generated Account Links are the means by which a Connect platform grants a connected account permission to accessStripe-hosted applications, such as Connect Onboarding.Related guide: Connect Onboarding