AccountLink class

auto generated Account Links are the means by which a Connect platform grants a connected account permission to accessStripe-hosted applications, such as Connect Onboarding.Related guide: Connect Onboarding

Constructors

AccountLink()
Instantiates a new AccountLink and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
expiresAt int?
The timestamp at which this account link will expire.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
object AccountLinkObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
The URL for the account link.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) AccountLink
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object