AccountRequirements class

auto generated

Constructors

AccountRequirements()
Instantiates a new AccountRequirements and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
alternatives Iterable<AccountRequirementsAlternative>?
Fields that are due and can be resolved by providing the corresponding alternative fields instead. Many alternatives can list the same original_fields_due, and any of these alternatives can serve as a pathway for attempting to resolve the fields again. Re-providing original_fields_due also serves as a pathway for attempting to resolve the fields again.
getter/setter pair
currentDeadline int?
Date by which the fields in currently_due must be collected to keep the account enabled. These fields may disable the account sooner if the next threshold is reached before they are collected.
getter/setter pair
currentlyDue Iterable<String>?
Fields that need to be resolved to keep the account enabled. If not resolved by current_deadline, these fields will appear in past_due as well, and the account is disabled.
getter/setter pair
disabledReason AccountRequirementsDisabledReason?
If the account is disabled, this enum describes why. Learn more about handling verification issues.
getter/setter pair
errors Iterable<AccountRequirementsError>?
Details about validation and verification failures for due requirements that must be resolved.
getter/setter pair
eventuallyDue Iterable<String>?
Fields you must collect when all thresholds are reached. As they become required, they appear in currently_due as well, and current_deadline becomes set.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pastDue Iterable<String>?
Fields that haven't been resolved by current_deadline. These fields need to be resolved to enable the account.
getter/setter pair
pendingVerification Iterable<String>?
Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move to eventually_due, currently_due, past_due or alternatives. Fields might appear in eventually_due, currently_due, past_due or alternatives and in pending_verification if one verification fails but another is still pending.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) AccountRequirements
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object