reason property
An informative message that indicates the error type and provides additional details about the error.
Implementation
String? reason;
An informative message that indicates the error type and provides additional details about the error.
String? reason;