models/account_session library

Classes

AccountSession
auto generated An AccountSession allows a Connect platform to grant access to a connected account in Connect embedded components.We recommend that you create an AccountSession each time you need to display an embedded componentto your user. Do not save AccountSessions to your database as they expire relativelyquickly, and cannot be used more than once.Related guide: Connect embedded components