AccountSession class

auto generated An AccountSession allows a Connect platform to grant access to a connected account in Connect embedded components.We recommend that you create an AccountSession each time you need to display an embedded componentto your user. Do not save AccountSessions to your database as they expire relativelyquickly, and cannot be used more than once.Related guide: Connect embedded components

Constructors

AccountSession()
Instantiates a new AccountSession and sets the default values.

Properties

account String?
The ID of the account the AccountSession was created for
getter/setter pair
additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
clientSecret String?
The client secret of this AccountSession. Used on the client to set up secure access to the given account.The client secret can be used to provide access to account from your frontend. It should not be stored, logged, or exposed to anyone other than the connected account. Make sure that you have TLS enabled on any page that includes the client secret.Refer to our docs to setup Connect embedded components and learn about how client_secret should be handled.
getter/setter pair
components ConnectEmbeddedAccountSessionCreateComponents?
The components property
getter/setter pair
expiresAt int?
The timestamp at which this AccountSession will expire.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
object AccountSessionObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) AccountSession
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object