clientSecret property

String? clientSecret
getter/setter pair

The client secret of this AccountSession. Used on the client to set up secure access to the given account.The client secret can be used to provide access to account from your frontend. It should not be stored, logged, or exposed to anyone other than the connected account. Make sure that you have TLS enabled on any page that includes the client secret.Refer to our docs to setup Connect embedded components and learn about how client_secret should be handled.

Implementation

String? clientSecret;