userAgent property
The user agent of the browser from which the account representative accepted the service agreement.
Implementation
String? userAgent;
The user agent of the browser from which the account representative accepted the service agreement.
String? userAgent;