AccountUnificationAccountController class

auto generated

Constructors

AccountUnificationAccountController()
Instantiates a new AccountUnificationAccountController and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
fees AccountUnificationAccountControllerFees?
The fees property
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isController bool?
true if the Connect application retrieving the resource controls the account and can therefore exercise platform controls. Otherwise, this field is null.
getter/setter pair
losses AccountUnificationAccountControllerLosses?
The losses property
getter/setter pair
requirementCollection AccountUnificationAccountControllerRequirementCollection?
A value indicating responsibility for collecting requirements on this account. Only returned when the Connect application retrieving the resource controls the account.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stripeDashboard AccountUnificationAccountControllerStripeDashboard?
The stripe_dashboard property
getter/setter pair
type_ AccountUnificationAccountControllerType?
The controller type. Can be application, if a Connect application controls the account, or account, if the account controls itself.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) AccountUnificationAccountController
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object