createFromDiscriminatorValue static method
Creates a new instance of the appropriate class based on discriminator value
parseNode The parse node to use to read the discriminator value and create the object
Implementation
static ApiErrorsSource createFromDiscriminatorValue(ParseNode parseNode) {
var result = ApiErrorsSource();
result.bankAccount = BankAccount();
result.card = Card();
result.source = Source();
return result;
}