ApplicationFee class
auto generated
Constructors
- ApplicationFee()
- Instantiates a new ApplicationFee and sets the default values.
Properties
- account ↔ ApplicationFeeAccount?
-
ID of the Stripe account this fee was taken from.
getter/setter pair
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- amount ↔ int?
-
Amount earned, in cents (or local equivalent).
getter/setter pair
- amountRefunded ↔ int?
-
Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the fee if a partial refund was issued)
getter/setter pair
- application ↔ ApplicationFeeApplication?
-
ID of the Connect application that earned the fee.
getter/setter pair
- balanceTransaction ↔ ApplicationFeeBalanceTransaction?
-
Balance transaction that describes the impact of this collected application fee on your account balance (not including refunds).
getter/setter pair
- charge ↔ ApplicationFeeCharge?
-
ID of the charge that the application fee was taken from.
getter/setter pair
- created ↔ int?
-
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
- currency ↔ String?
-
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
- feeSource ↔ PlatformEarningFeeSource?
-
Polymorphic source of the application fee. Includes the ID of the object the application fee was created from.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - object ↔ ApplicationFeeObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- originatingTransaction ↔ ApplicationFeeOriginatingTransaction?
-
ID of the corresponding charge on the platform account, if this fee was the result of a charge using the
destinationparameter.getter/setter pair - refunded ↔ bool?
-
Whether the fee has been fully refunded. If the fee is only partially refunded, this attribute will still be false.
getter/setter pair
- refunds ↔ ApplicationFeeRefunds?
-
A list of refunds that have been applied to the fee.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → ApplicationFee -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object