originatingTransaction property
ID of the corresponding charge on the platform account, if this fee was the result of a charge using the destination parameter.
Implementation
ApplicationFeeOriginatingTransaction? originatingTransaction;
ID of the corresponding charge on the platform account, if this fee was the result of a charge using the destination parameter.
ApplicationFeeOriginatingTransaction? originatingTransaction;