refunded property
Whether the fee has been fully refunded. If the fee is only partially refunded, this attribute will still be false.
Implementation
bool? refunded;
Whether the fee has been fully refunded. If the fee is only partially refunded, this attribute will still be false.
bool? refunded;