createFromDiscriminatorValue static method

ApplicationFeeOriginatingTransaction createFromDiscriminatorValue(
  1. ParseNode parseNode
)

Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object

Implementation

static ApplicationFeeOriginatingTransaction createFromDiscriminatorValue(
    ParseNode parseNode) {
  var result = ApplicationFeeOriginatingTransaction();
  if (parseNode.getStringValue() != null) {
    result.string_ = parseNode.getStringValue();
  } else {
    result.charge = Charge();
  }
  return result;
}