ApplicationFeeRefunds class

auto generated A list of refunds that have been applied to the fee.

Constructors

ApplicationFeeRefunds()
Instantiates a new ApplicationFeeRefunds and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
data Iterable<FeeRefund>?
Details about each object.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasMore bool?
True if this list has another page of items after this one that can be fetched.
getter/setter pair
object ApplicationFeeRefundsObject?
String representing the object's type. Objects of the same type share the same value. Always has the value list.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
The URL where this list can be accessed.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) ApplicationFeeRefunds
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object