Secret class

auto generated Secret Store is an API that allows Stripe Apps developers to securely persist secrets for use by UI Extensions and app backends.The primary resource in Secret Store is a secret. Other apps can't view secrets created by an app. Additionally, secrets are scoped to provide further permission control.All Dashboard users and the app backend share account scoped secrets. Use the account scope for secrets that don't change per-user, like a third-party API key.A user scoped secret is accessible by the app backend and one specific Dashboard user. Use the user scope for per-user secrets like per-user OAuth tokens, where different users might have different permissions.Related guide: Store data between page reloads

Constructors

Secret()
Instantiates a new Secret and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
deleted bool?
If true, indicates that this secret has been deleted
getter/setter pair
expiresAt int?
The Unix timestamp for the expiry time of the secret, after which the secret deletes.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
name String?
A name for the secret that's unique within the scope.
getter/setter pair
object SecretObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
payload String?
The plaintext secret value to be stored.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope SecretServiceResourceScope?
The scope property
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) Secret
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object