Balance class
auto generated
This is an object representing your Stripe balance. You can retrieve it to seethe balance currently on your Stripe account.The top-level available and pending comprise your "payments balance."Related guide: Balances and settlement time, Understanding Connect account balances
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
-
available
↔ Iterable<
BalanceAmount> ? -
Available funds that you can transfer or pay out automatically by Stripe or explicitly through the Transfers API or Payouts API. You can find the available balance for each currency and payment type in the
source_typesproperty.getter/setter pair -
connectReserved
↔ Iterable<
BalanceAmount> ? -
Funds held due to negative balances on connected accounts where account.controller.requirement_collection is
application, which includes Custom accounts. You can find the connect reserve balance for each currency and payment type in thesource_typesproperty.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
-
instantAvailable
↔ Iterable<
BalanceAmountNet> ? -
Funds that you can pay out using Instant Payouts.
getter/setter pair
- issuing ↔ BalanceDetail?
-
The issuing property
getter/setter pair
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - object ↔ BalanceObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
-
pending
↔ Iterable<
BalanceAmount> ? -
Funds that aren't available in the balance yet. You can find the pending balance for each currency and each payment type in the
source_typesproperty.getter/setter pair - refundAndDisputePrefunding ↔ BalanceDetailUngated?
-
The refund_and_dispute_prefunding property
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → Balance -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object