pending property
Funds that aren't available in the balance yet. You can find the pending balance for each currency and each payment type in the source_types property.
Implementation
Iterable<BalanceAmount>? pending;
Funds that aren't available in the balance yet. You can find the pending balance for each currency and each payment type in the source_types property.
Iterable<BalanceAmount>? pending;