BalanceTransaction class

auto generated Balance transactions represent funds moving through your Stripe account.Stripe creates them for every type of transaction that enters or leaves your Stripe account balance.Related guide: Balance transaction types

Constructors

BalanceTransaction()
Instantiates a new BalanceTransaction and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amount int?
Gross amount of this transaction (in cents (or local equivalent)). A positive value represents funds charged to another party, and a negative value represents funds sent to another party.
getter/setter pair
availableOn int?
The date that the transaction's net funds become available in the Stripe balance.
getter/setter pair
balanceType BalanceTransactionBalanceType?
The balance that this transaction impacts.
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
description String?
An arbitrary string attached to the object. Often useful for displaying to users.
getter/setter pair
exchangeRate double?
If applicable, this transaction uses an exchange rate. If money converts from currency A to currency B, then the amount in currency A, multipled by the exchange_rate, equals the amount in currency B. For example, if you charge a customer 10.00 EUR, the PaymentIntent's amount is 1000 and currency is eur. If this converts to 12.34 USD in your Stripe account, the BalanceTransaction's amount is 1234, its currency is usd, and the exchange_rate is 1.234.
getter/setter pair
fee int?
Fees (in cents (or local equivalent)) paid for this transaction. Represented as a positive integer when assessed.
getter/setter pair
feeDetails Iterable<Fee>?
Detailed breakdown of fees (in cents (or local equivalent)) paid for this transaction.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
net int?
Net impact to a Stripe balance (in cents (or local equivalent)). A positive value represents incrementing a Stripe balance, and a negative value decrementing a Stripe balance. You can calculate the net impact of a transaction on a balance by amount - fee
getter/setter pair
object BalanceTransactionObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
reportingCategory String?
Learn more about how reporting categories can help you understand balance transactions from an accounting perspective.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source BalanceTransactionSource?
This transaction relates to the Stripe object.
getter/setter pair
status String?
The transaction's net funds status in the Stripe balance, which are either available or pending.
getter/setter pair
type_ BalanceTransactionType?
Transaction type: adjustment, advance, advance_funding, anticipation_repayment, application_fee, application_fee_refund, charge, climate_order_purchase, climate_order_refund, connect_collection_transfer, contribution, issuing_authorization_hold, issuing_authorization_release, issuing_dispute, issuing_transaction, obligation_outbound, obligation_reversal_inbound, payment, payment_failure_refund, payment_network_reserve_hold, payment_network_reserve_release, payment_refund, payment_reversal, payment_unreconciled, payout, payout_cancel, payout_failure, payout_minimum_balance_hold, payout_minimum_balance_release, refund, refund_failure, reserve_transaction, reserved_funds, stripe_fee, stripe_fx_fee, stripe_balance_payment_debit, stripe_balance_payment_debit_reversal, tax_fee, topup, topup_reversal, transfer, transfer_cancel, transfer_failure, or transfer_refund. Learn more about balance transaction types and what they represent. To classify transactions for accounting purposes, consider reporting_category instead.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) BalanceTransaction
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object