amount property

int? amount
getter/setter pair

Gross amount of this transaction (in cents (or local equivalent)). A positive value represents funds charged to another party, and a negative value represents funds sent to another party.

Implementation

int? amount;