reportingCategory property
Learn more about how reporting categories can help you understand balance transactions from an accounting perspective.
Implementation
String? reportingCategory;
Learn more about how reporting categories can help you understand balance transactions from an accounting perspective.
String? reportingCategory;