status property
The transaction's net funds status in the Stripe balance, which are either available or pending.
Implementation
String? status;
The transaction's net funds status in the Stripe balance, which are either available or pending.
String? status;