BankAccount class
auto generated
These bank accounts are payment methods on Customer objects.On the other hand External Accounts are transferdestinations on Account objects for connected accounts.They can be bank accounts or debit cards as well, and are documented in the links above.Related guide: Bank debits and transfers
Constructors
- BankAccount()
- Instantiates a new BankAccount and sets the default values.
Properties
- account ↔ BankAccountAccount?
-
The account this bank account belongs to. Only applicable on Accounts (not customers or recipients) This property is only available when returned as an External Account where controller.is_controller is
true.getter/setter pair - accountHolderName ↔ String?
-
The name of the person or business that owns the bank account.
getter/setter pair
- accountHolderType ↔ String?
-
The type of entity that holds the account. This can be either
individualorcompany.getter/setter pair - accountType ↔ String?
-
The bank account type. This can only be
checkingorsavingsin most countries. In Japan, this can only befutsuortoza.getter/setter pair -
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
-
availablePayoutMethods
↔ Iterable<
BankAccountAvailablePayoutMethods> ? -
A set of available payout methods for this bank account. Only values from this set should be passed as the
methodwhen creating a payout.getter/setter pair - bankName ↔ String?
-
Name of the bank associated with the routing number (e.g.,
WELLS FARGO).getter/setter pair - country ↔ String?
-
Two-letter ISO code representing the country the bank account is located in.
getter/setter pair
- currency ↔ String?
-
Three-letter ISO code for the currency paid out to the bank account.
getter/setter pair
- customer ↔ BankAccountCustomer?
-
The ID of the customer that the bank account is associated with.
getter/setter pair
- defaultForCurrency ↔ bool?
-
Whether this bank account is the default external account for its currency.
getter/setter pair
- fingerprint ↔ String?
-
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
getter/setter pair
- futureRequirements ↔ ExternalAccountRequirements?
-
Information about the upcoming new requirements for the bank account, including what information needs to be collected, and by when.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- last4 ↔ String?
-
The last four digits of the bank account number.
getter/setter pair
- metadata ↔ BankAccountMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- object ↔ BankAccountObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- requirements ↔ ExternalAccountRequirements?
-
Information about the requirements for the bank account, including what information needs to be collected.
getter/setter pair
- routingNumber ↔ String?
-
The routing transit number for the bank account.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String?
-
For bank accounts, possible values are
new,validated,verified,verification_failed,tokenized_account_number_deactivatedorerrored. A bank account that hasn't had any activity or validation performed isnew. If Stripe can determine that the bank account exists, its status will bevalidated. Note that there often isn’t enough information to know (e.g., for smaller credit unions), and the validation is not always run. If customer bank account verification has succeeded, the bank account status will beverified. If the verification failed for any reason, such as microdeposit failure, the status will beverification_failed. If the status istokenized_account_number_deactivated, the account utilizes a tokenized account number which has been deactivated due to expiration or revocation. This account will need to be reverified to continue using it for money movement. If a payout sent to this bank account fails, we'll set the status toerroredand will not continue to send scheduled payouts until the bank details are updated.For external accounts, possible values arenew,errored,verification_failed, andtokenized_account_number_deactivated. If a payout fails, the status is set toerroredand scheduled payouts are stopped until account details are updated. In the US and India, if we can't verify the owner of the bank account, we'll set the status toverification_failed. Other validations aren't run against external accounts because they're only used for payouts. This means the other statuses don't apply.getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → BankAccount -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object