MeterEvent class

auto generated Meter events represent actions that customers take in your system. You can use meter events to bill a customer based on their usage. Meter events are associated with billing meters, which define both the contents of the event’s payload and how to aggregate those events.

Constructors

MeterEvent()
Instantiates a new MeterEvent and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
eventName String?
The name of the meter event. Corresponds with the event_name field on a meter.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
identifier String?
A unique identifier for the event.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
object MeterEventObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
payload MeterEventPayload?
The payload of the event. This contains the fields corresponding to a meter's customer_mapping.event_payload_key (default is stripe_customer_id) and value_settings.event_payload_key (default is value). Read more about the payload.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int?
The timestamp passed in when creating the event. Measured in seconds since the Unix epoch.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) MeterEvent
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object