MeterEventPayload class
auto generated
The payload of the event. This contains the fields corresponding to a meter's customer_mapping.event_payload_key (default is stripe_customer_id) and value_settings.event_payload_key (default is value). Read more about the payload.
Constructors
- MeterEventPayload()
- Instantiates a new MeterEventPayload and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → MeterEventPayload -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object