availablePayoutMethods property
A set of available payout methods for this card. Only values from this set should be passed as the method when creating a payout.
Implementation
Iterable<CardAvailablePayoutMethods>? availablePayoutMethods;
A set of available payout methods for this card. Only values from this set should be passed as the method when creating a payout.
Iterable<CardAvailablePayoutMethods>? availablePayoutMethods;