customer property

CardCustomer? customer
getter/setter pair

The customer that this card belongs to. This attribute will not be in the card object if the card belongs to an account or recipient instead.

Implementation

CardCustomer? customer;