defaultForCurrency property

bool? defaultForCurrency
getter/setter pair

Whether this card is the default external account for its currency. This property is only available for accounts where controller.requirement_collection is application, which includes Custom accounts.

Implementation

bool? defaultForCurrency;