status property

String? status
getter/setter pair

For external accounts that are cards, possible values are new and errored. If a payout fails, the status is set to errored and scheduled payouts are stopped until account details are updated.

Implementation

String? status;