CardAllowRedisplay enum

auto generated This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.

Inheritance
Available extensions

Values

always → const CardAllowRedisplay
const CardAllowRedisplay('always')
limited → const CardAllowRedisplay
const CardAllowRedisplay('limited')
unspecified → const CardAllowRedisplay
const CardAllowRedisplay('unspecified')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CardAllowRedisplay>
A constant List of the values in this enum, in order of their declaration.