Charge class

auto generated The Charge object represents a single attempt to move money into your Stripe account.PaymentIntent confirmation is the most common way to create Charges, but Account Debits may also create Charges.Some legacy payment flows create Charges directly, which is not recommended for new integrations.

Constructors

Charge()
Instantiates a new Charge and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amount int?
Amount intended to be collected by this payment. A positive integer representing how much to charge in the smallest currency unit (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or equivalent in charge currency. The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).
getter/setter pair
amountCaptured int?
Amount in cents (or local equivalent) captured (can be less than the amount attribute on the charge if a partial capture was made).
getter/setter pair
amountRefunded int?
Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the charge if a partial refund was issued).
getter/setter pair
application ChargeApplication?
ID of the Connect application that created the charge.
getter/setter pair
applicationFee ChargeApplicationFee?
The application fee (if any) for the charge. See the Connect documentation for details.
getter/setter pair
applicationFeeAmount int?
The amount of the application fee (if any) requested for the charge. See the Connect documentation for details.
getter/setter pair
balanceTransaction ChargeBalanceTransaction?
ID of the balance transaction that describes the impact of this charge on your account balance (not including refunds or disputes).
getter/setter pair
billingDetails BillingDetails?
The billing_details property
getter/setter pair
calculatedStatementDescriptor String?
The full statement descriptor that is passed to card networks, and that is displayed on your customers' credit card and bank statements. Allows you to see what the statement descriptor looks like after the static and dynamic portions are combined. This value only exists for card payments.
getter/setter pair
captured bool?
If the charge was created without capturing, this Boolean represents whether it is still uncaptured or has since been captured.
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
customer ChargeCustomer?
ID of the customer this charge is for if one exists.
getter/setter pair
description String?
An arbitrary string attached to the object. Often useful for displaying to users.
getter/setter pair
disputed bool?
Whether the charge has been disputed.
getter/setter pair
failureBalanceTransaction ChargeFailureBalanceTransaction?
ID of the balance transaction that describes the reversal of the balance on your account due to payment failure.
getter/setter pair
failureCode String?
Error code explaining reason for charge failure if available (see the errors section for a list of codes).
getter/setter pair
failureMessage String?
Message to user further explaining reason for charge failure if available.
getter/setter pair
fraudDetails ChargeFraudDetails?
Information on fraud assessments for the charge.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
metadata ChargeMetadata?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
object ChargeObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
onBehalfOf ChargeOnBehalfOf?
The account (if any) the charge was made on behalf of without triggering an automatic transfer. See the Connect documentation for details.
getter/setter pair
outcome ChargeOutcome?
Details about whether the payment was accepted, and why. See understanding declines for details.
getter/setter pair
true if the charge succeeded, or was successfully authorized for later capture.
getter/setter pair
paymentIntent ChargePaymentIntent?
ID of the PaymentIntent associated with this charge, if one exists.
getter/setter pair
paymentMethod String?
ID of the payment method used in this charge.
getter/setter pair
paymentMethodDetails PaymentMethodDetails?
Details about the payment method at the time of the transaction.
getter/setter pair
presentmentDetails PaymentFlowsPaymentIntentPresentmentDetails?
The presentment_details property
getter/setter pair
radarOptions RadarRadarOptions?
Options to configure Radar. See Radar Session for more information.
getter/setter pair
receiptEmail String?
This is the email address that the receipt for this charge was sent to.
getter/setter pair
receiptNumber String?
This is the transaction number that appears on email receipts sent for this charge. This attribute will be null until a receipt has been sent.
getter/setter pair
receiptUrl String?
This is the URL to view the receipt for this charge. The receipt is kept up-to-date to the latest state of the charge, including any refunds. If the charge is for an Invoice, the receipt will be stylized as an Invoice receipt.
getter/setter pair
refunded bool?
Whether the charge has been fully refunded. If the charge is only partially refunded, this attribute will still be false.
getter/setter pair
refunds ChargeRefunds?
A list of refunds that have been applied to the charge.
getter/setter pair
review ChargeReview?
ID of the review associated with this charge if one exists.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shipping Shipping?
Shipping information for the charge.
getter/setter pair
sourceTransfer ChargeSourceTransfer?
The transfer ID which created this charge. Only present if the charge came from another Stripe account. See the Connect documentation for details.
getter/setter pair
statementDescriptor String?
For a non-card charge, text that appears on the customer's statement as the statement descriptor. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see the Statement Descriptor docs.For a card charge, this value is ignored unless you don't specify a statement_descriptor_suffix, in which case this value is used as the suffix.
getter/setter pair
statementDescriptorSuffix String?
Provides information about a card charge. Concatenated to the account's statement descriptor prefix to form the complete statement descriptor that appears on the customer's statement. If the account has no prefix value, the suffix is concatenated to the account's statement descriptor.
getter/setter pair
status ChargeStatus?
The status of the payment is either succeeded, pending, or failed.
getter/setter pair
transfer ChargeTransfer?
ID of the transfer to the destination account (only applicable if the charge was created using the destination parameter).
getter/setter pair
transferData ChargeTransferData?
An optional dictionary including the account to automatically transfer to as part of a destination charge. See the Connect documentation for details.
getter/setter pair
transferGroup String?
A string that identifies this transaction as part of a group. See the Connect documentation for details.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) Charge
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object