amountCaptured property
Amount in cents (or local equivalent) captured (can be less than the amount attribute on the charge if a partial capture was made).
Implementation
int? amountCaptured;
Amount in cents (or local equivalent) captured (can be less than the amount attribute on the charge if a partial capture was made).
int? amountCaptured;