amountRefunded property
Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the charge if a partial refund was issued).
Implementation
int? amountRefunded;
Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the charge if a partial refund was issued).
int? amountRefunded;