balanceTransaction property
ID of the balance transaction that describes the impact of this charge on your account balance (not including refunds or disputes).
Implementation
ChargeBalanceTransaction? balanceTransaction;
ID of the balance transaction that describes the impact of this charge on your account balance (not including refunds or disputes).
ChargeBalanceTransaction? balanceTransaction;