calculatedStatementDescriptor property

String? calculatedStatementDescriptor
getter/setter pair

The full statement descriptor that is passed to card networks, and that is displayed on your customers' credit card and bank statements. Allows you to see what the statement descriptor looks like after the static and dynamic portions are combined. This value only exists for card payments.

Implementation

String? calculatedStatementDescriptor;