captured property
If the charge was created without capturing, this Boolean represents whether it is still uncaptured or has since been captured.
Implementation
bool? captured;
If the charge was created without capturing, this Boolean represents whether it is still uncaptured or has since been captured.
bool? captured;