onBehalfOf property
The account (if any) the charge was made on behalf of without triggering an automatic transfer. See the Connect documentation for details.
Implementation
ChargeOnBehalfOf? onBehalfOf;
The account (if any) the charge was made on behalf of without triggering an automatic transfer. See the Connect documentation for details.
ChargeOnBehalfOf? onBehalfOf;