receiptNumber property
This is the transaction number that appears on email receipts sent for this charge. This attribute will be null until a receipt has been sent.
Implementation
String? receiptNumber;
This is the transaction number that appears on email receipts sent for this charge. This attribute will be null until a receipt has been sent.
String? receiptNumber;