receiptUrl property

String? receiptUrl
getter/setter pair

This is the URL to view the receipt for this charge. The receipt is kept up-to-date to the latest state of the charge, including any refunds. If the charge is for an Invoice, the receipt will be stylized as an Invoice receipt.

Implementation

String? receiptUrl;