sourceTransfer property
The transfer ID which created this charge. Only present if the charge came from another Stripe account. See the Connect documentation for details.
Implementation
ChargeSourceTransfer? sourceTransfer;
The transfer ID which created this charge. Only present if the charge came from another Stripe account. See the Connect documentation for details.
ChargeSourceTransfer? sourceTransfer;