transfer property
ID of the transfer to the destination account (only applicable if the charge was created using the destination parameter).
Implementation
ChargeTransfer? transfer;
ID of the transfer to the destination account (only applicable if the charge was created using the destination parameter).
ChargeTransfer? transfer;