transferData property
An optional dictionary including the account to automatically transfer to as part of a destination charge. See the Connect documentation for details.
Implementation
ChargeTransferData? transferData;
An optional dictionary including the account to automatically transfer to as part of a destination charge. See the Connect documentation for details.
ChargeTransferData? transferData;