transferGroup property
A string that identifies this transaction as part of a group. See the Connect documentation for details.
Implementation
String? transferGroup;
A string that identifies this transaction as part of a group. See the Connect documentation for details.
String? transferGroup;