amount property

int? amount
getter/setter pair

The amount transferred to the destination account, if specified. By default, the entire charge amount is transferred to the destination account.

Implementation

int? amount;