destination property
ID of an existing, connected Stripe account to transfer funds to if transfer_data was specified in the charge request.
Implementation
ChargeTransferDataDestination? destination;
ID of an existing, connected Stripe account to transfer funds to if transfer_data was specified in the charge request.
ChargeTransferDataDestination? destination;