CheckoutAcssDebitPaymentMethodOptions class

auto generated

Constructors

CheckoutAcssDebitPaymentMethodOptions()
Instantiates a new CheckoutAcssDebitPaymentMethodOptions and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
currency CheckoutAcssDebitPaymentMethodOptionsCurrency?
Currency supported by the bank account. Returned when the Session is in setup mode.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mandateOptions CheckoutAcssDebitMandateOptions?
The mandate_options property
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setupFutureUsage CheckoutAcssDebitPaymentMethodOptionsSetupFutureUsage?
Indicates that you intend to make future payments with this PaymentIntent's payment method.If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
getter/setter pair
targetDate String?
Controls when Stripe will attempt to debit the funds from the customer's account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.
getter/setter pair
verificationMethod CheckoutAcssDebitPaymentMethodOptionsVerificationMethod?
Bank account verification method.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) CheckoutAcssDebitPaymentMethodOptions
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object