captureMethod property
Controls when the funds will be captured from the customer's account.
Implementation
CheckoutAlmaPaymentMethodOptionsCaptureMethod? captureMethod;
Controls when the funds will be captured from the customer's account.
CheckoutAlmaPaymentMethodOptionsCaptureMethod? captureMethod;