captureMethod property
Controls when the funds will be captured from the customer's account.
Implementation
CheckoutAmazonPayPaymentMethodOptionsCaptureMethod? captureMethod;
Controls when the funds will be captured from the customer's account.
CheckoutAmazonPayPaymentMethodOptionsCaptureMethod? captureMethod;