captureMethod property
Controls when the funds will be captured from the customer's account.
Implementation
CheckoutBilliePaymentMethodOptionsCaptureMethod? captureMethod;
Controls when the funds will be captured from the customer's account.
CheckoutBilliePaymentMethodOptionsCaptureMethod? captureMethod;