captureMethod property
Controls when the funds will be captured from the customer's account.
Implementation
CheckoutKrCardPaymentMethodOptionsCaptureMethod? captureMethod;
Controls when the funds will be captured from the customer's account.
CheckoutKrCardPaymentMethodOptionsCaptureMethod? captureMethod;