captureMethod property
Controls when the funds will be captured from the customer's account.
Implementation
CheckoutMobilepayPaymentMethodOptionsCaptureMethod? captureMethod;
Controls when the funds will be captured from the customer's account.
CheckoutMobilepayPaymentMethodOptionsCaptureMethod? captureMethod;