captureMethod property
Controls when the funds will be captured from the customer's account.
Implementation
CheckoutPaycoPaymentMethodOptionsCaptureMethod? captureMethod;
Controls when the funds will be captured from the customer's account.
CheckoutPaycoPaymentMethodOptionsCaptureMethod? captureMethod;