captureMethod property
Controls when the funds will be captured from the customer's account.
Implementation
CheckoutSatispayPaymentMethodOptionsCaptureMethod? captureMethod;
Controls when the funds will be captured from the customer's account.
CheckoutSatispayPaymentMethodOptionsCaptureMethod? captureMethod;