models/checkout/session library

Classes

Session
auto generated A Checkout Session represents your customer's session as they pay forone-time purchases or subscriptions through Checkoutor Payment Links. We recommend creating anew Session each time your customer attempts to pay.Once payment is successful, the Checkout Session will contain a referenceto the Customer, and either the successfulPaymentIntent or an activeSubscription.You can create a Checkout Session on your server and redirect to its URLto begin Checkout.Related guide: Checkout quickstart