Session constructor
Session()
Instantiates a new Session and sets the default values.
Implementation
Session() : additionalData = {};
Instantiates a new Session and sets the default values.
Session() : additionalData = {};