collectedInformation property
Information about the customer collected within the Checkout Session.
Implementation
PaymentPagesCheckoutSessionCollectedInformation? collectedInformation;
Information about the customer collected within the Checkout Session.
PaymentPagesCheckoutSessionCollectedInformation? collectedInformation;