consentCollection property
When set, provides configuration for the Checkout Session to gather active consent from customers.
Implementation
PaymentPagesCheckoutSessionConsentCollection? consentCollection;
When set, provides configuration for the Checkout Session to gather active consent from customers.
PaymentPagesCheckoutSessionConsentCollection? consentCollection;