customer property

SessionCustomer? customer
getter/setter pair

The ID of the customer for this Session.For Checkout Sessions in subscription mode or Checkout Sessions with customer_creation set as always in payment mode, Checkoutwill create a new customer object based on information providedduring the payment flow unless an existing customer was provided whenthe Session was created.

Implementation

SessionCustomer? customer;