customerCreation property
Configure whether a Checkout Session creates a Customer when the Checkout Session completes.
Implementation
SessionCustomerCreation? customerCreation;
Configure whether a Checkout Session creates a Customer when the Checkout Session completes.
SessionCustomerCreation? customerCreation;