customerEmail property

String? customerEmail
getter/setter pair

If provided, this value will be used when the Customer object is created.If not provided, customers will be asked to enter their email address.Use this parameter to prefill customer data if you already have an emailon file. To access information about the customer once the payment flow iscomplete, use the customer attribute.

Implementation

String? customerEmail;