originContext property
Where the user is coming from. This informs the optimizations that are applied to the session.
Implementation
SessionOriginContext? originContext;
Where the user is coming from. This informs the optimizations that are applied to the session.
SessionOriginContext? originContext;