paymentMethodCollection property
Configure whether a Checkout Session should collect a payment method. Defaults to always.
Implementation
SessionPaymentMethodCollection? paymentMethodCollection;
Configure whether a Checkout Session should collect a payment method. Defaults to always.
SessionPaymentMethodCollection? paymentMethodCollection;