permissions property
This property is used to set up permissions for various actions (e.g., update) on the CheckoutSession object.For specific permissions, please refer to their dedicated subsections, such as permissions.update_shipping_details.
Implementation
PaymentPagesCheckoutSessionPermissions? permissions;