shippingAddressCollection property
When set, provides configuration for Checkout to collect a shipping address from a customer.
Implementation
PaymentPagesCheckoutSessionShippingAddressCollection?
shippingAddressCollection;
When set, provides configuration for Checkout to collect a shipping address from a customer.
PaymentPagesCheckoutSessionShippingAddressCollection?
shippingAddressCollection;