successUrl property
The URL the customer will be directed to after the payment orsubscription creation is successful.
Implementation
String? successUrl;
The URL the customer will be directed to after the payment orsubscription creation is successful.
String? successUrl;