SessionOriginContext enum

auto generated Where the user is coming from. This informs the optimizations that are applied to the session.

Inheritance
Available extensions

Values

mobileApp → const SessionOriginContext
const SessionOriginContext('mobile_app')
web → const SessionOriginContext
const SessionOriginContext('web')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SessionOriginContext>
A constant List of the values in this enum, in order of their declaration.