createFromDiscriminatorValue static method
Creates a new instance of the appropriate class based on discriminator value
parseNode The parse node to use to read the discriminator value and create the object
Implementation
static SessionPaymentLink createFromDiscriminatorValue(ParseNode parseNode) {
var result = SessionPaymentLink();
if (parseNode.getStringValue() != null) {
result.string_ = parseNode.getStringValue();
} else {
result.paymentLink = PaymentLink();
}
return result;
}