SessionPaymentStatus enum

auto generated The payment status of the Checkout Session, one of paid, unpaid, or no_payment_required.You can use this value to decide when to fulfill your customer's order.

Inheritance
Available extensions

Values

noPaymentRequired → const SessionPaymentStatus
const SessionPaymentStatus('no_payment_required')
const SessionPaymentStatus('paid')
unpaid → const SessionPaymentStatus
const SessionPaymentStatus('unpaid')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SessionPaymentStatus>
A constant List of the values in this enum, in order of their declaration.