SessionStatus enum

auto generated The status of the Checkout Session, one of open, complete, or expired.

Inheritance
Available extensions

Values

complete → const SessionStatus
const SessionStatus('complete')
expired → const SessionStatus
const SessionStatus('expired')
open → const SessionStatus
const SessionStatus('open')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SessionStatus>
A constant List of the values in this enum, in order of their declaration.