ConnectCollectionTransferDestination class

auto generated Composed type wrapper for classes Account, String?

Properties

account Account?
Composed type representation for type Account
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
string_ String?
Composed type representation for type String?
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) ConnectCollectionTransferDestination
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object