createFromDiscriminatorValue static method

ConnectEmbeddedPaymentsFeatures createFromDiscriminatorValue(
  1. ParseNode parseNode
)

Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object

Implementation

static ConnectEmbeddedPaymentsFeatures createFromDiscriminatorValue(
    ParseNode parseNode) {
  return ConnectEmbeddedPaymentsFeatures();
}