destinationOnBehalfOfChargeManagement property
Whether connected accounts can manage destination charges that are created on behalf of them. This is false by default.
Implementation
bool? destinationOnBehalfOfChargeManagement;
Whether connected accounts can manage destination charges that are created on behalf of them. This is false by default.
bool? destinationOnBehalfOfChargeManagement;