createFromDiscriminatorValue static method
Creates a new instance of the appropriate class based on discriminator value
parseNode The parse node to use to read the discriminator value and create the object
Implementation
static CreditNoteCustomer createFromDiscriminatorValue(ParseNode parseNode) {
var result = CreditNoteCustomer();
if (parseNode.getStringValue() != null) {
result.string_ = parseNode.getStringValue();
} else {
result.customer = Customer();
result.deletedCustomer = DeletedCustomer();
}
return result;
}