CreditNoteReason enum

auto generated Reason for issuing this credit note, one of duplicate, fraudulent, order_change, or product_unsatisfactory

Inheritance
Available extensions

Values

duplicate → const CreditNoteReason
const CreditNoteReason('duplicate')
fraudulent → const CreditNoteReason
const CreditNoteReason('fraudulent')
orderChange → const CreditNoteReason
const CreditNoteReason('order_change')
productUnsatisfactory → const CreditNoteReason
const CreditNoteReason('product_unsatisfactory')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CreditNoteReason>
A constant List of the values in this enum, in order of their declaration.