cashBalance property

CashBalance? cashBalance
getter/setter pair

The current funds being held by Stripe on behalf of the customer. You can apply these funds towards payment intents when the source is "cash_balance". The settings[reconciliation_mode] field describes if these funds apply to these payment intents manually or automatically.

Implementation

CashBalance? cashBalance;