defaultSource property

CustomerDefaultSource? defaultSource
getter/setter pair

ID of the default payment source for the customer.If you use payment methods created through the PaymentMethods API, see the invoice_settings.default_payment_method field instead.

Implementation

CustomerDefaultSource? defaultSource;