taxExempt property
Describes the customer's tax exemption status, which is none, exempt, or reverse. When set to reverse, invoice and receipt PDFs include the following text: "Reverse charge".
Implementation
CustomerTaxExempt? taxExempt;
Describes the customer's tax exemption status, which is none, exempt, or reverse. When set to reverse, invoice and receipt PDFs include the following text: "Reverse charge".
CustomerTaxExempt? taxExempt;