amount property
The amount of the transaction. A negative value is a credit for the customer's balance, and a positive value is a debit to the customer's balance.
Implementation
int? amount;
The amount of the transaction. A negative value is a credit for the customer's balance, and a positive value is a debit to the customer's balance.
int? amount;