CustomerSession class
auto generated A Customer Session allows you to grant Stripe's frontend SDKs (like Stripe.js) client-side accesscontrol over a Customer.Related guides: Customer Session with the Payment Element,Customer Session with the Pricing Table,Customer Session with the Buy Button.
Constructors
- CustomerSession()
- Instantiates a new CustomerSession and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- clientSecret ↔ String?
-
The client secret of this Customer Session. Used on the client to set up secure access to the given
customer.The client secret can be used to provide access tocustomerfrom your frontend. It should not be stored, logged, or exposed to anyone other than the relevant customer. Make sure that you have TLS enabled on any page that includes the client secret.getter/setter pair - components ↔ CustomerSessionResourceComponents?
-
Configuration for the components supported by this Customer Session.
getter/setter pair
- created ↔ int?
-
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
- customer ↔ CustomerSessionCustomer?
-
The Customer the Customer Session was created for.
getter/setter pair
- customerAccount ↔ String?
-
The Account that the Customer Session was created for.
getter/setter pair
- expiresAt ↔ int?
-
The timestamp at which this Customer Session will expire.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - object ↔ CustomerSessionObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → CustomerSession -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object