clientSecret property

String? clientSecret
getter/setter pair

The client secret of this Customer Session. Used on the client to set up secure access to the given customer.The client secret can be used to provide access to customer from your frontend. It should not be stored, logged, or exposed to anyone other than the relevant customer. Make sure that you have TLS enabled on any page that includes the client secret.

Implementation

String? clientSecret;