components property
Configuration for the components supported by this Customer Session.
Implementation
CustomerSessionResourceComponents? components;
Configuration for the components supported by this Customer Session.
CustomerSessionResourceComponents? components;