CustomerTaxExempt enum
auto generated
Describes the customer's tax exemption status, which is none, exempt, or reverse. When set to reverse, invoice and receipt PDFs include the following text: "Reverse charge".
Values
- exempt → const CustomerTaxExempt
-
const CustomerTaxExempt('exempt') - none → const CustomerTaxExempt
-
const CustomerTaxExempt('none') - reverse → const CustomerTaxExempt
-
const CustomerTaxExempt('reverse')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CustomerTaxExempt> - A constant List of the values in this enum, in order of their declaration.