CustomerTaxLocationSource enum

auto generated The data source used to infer the customer's location.

Inheritance
Available extensions

Values

billingAddress → const CustomerTaxLocationSource
const CustomerTaxLocationSource('billing_address')
ipAddress → const CustomerTaxLocationSource
const CustomerTaxLocationSource('ip_address')
paymentMethod → const CustomerTaxLocationSource
const CustomerTaxLocationSource('payment_method')
shippingDestination → const CustomerTaxLocationSource
const CustomerTaxLocationSource('shipping_destination')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CustomerTaxLocationSource>
A constant List of the values in this enum, in order of their declaration.