createFromDiscriminatorValue static method

DeletedDiscountPromotionCode createFromDiscriminatorValue(
  1. ParseNode parseNode
)

Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object

Implementation

static DeletedDiscountPromotionCode createFromDiscriminatorValue(
    ParseNode parseNode) {
  var result = DeletedDiscountPromotionCode();
  if (parseNode.getStringValue() != null) {
    result.string_ = parseNode.getStringValue();
  } else {
    result.promotionCode = PromotionCode();
  }
  return result;
}