object property
String representing the object's type. Objects of the same type share the same value.
Implementation
DeletedInvoiceObject? object;
String representing the object's type. Objects of the same type share the same value.
DeletedInvoiceObject? object;