object property
String representing the object's type. Objects of the same type share the same value.
Implementation
LocationObject? object;
String representing the object's type. Objects of the same type share the same value.
LocationObject? object;