models/discount library
Classes
- Discount
- auto generated A discount represents the actual application of a coupon or promotion code.It contains information about when the discount began, when it will end, and what it is applied to.Related guide: Applying discounts to subscriptions