checkoutSession property

String? checkoutSession
getter/setter pair

The Checkout session that this coupon is applied to, if it is applied to a particular session in payment mode. Will not be present for subscription mode.

Implementation

String? checkoutSession;