invoice property
The invoice that the discount's coupon was applied to, if it was applied directly to a particular invoice.
Implementation
String? invoice;
The invoice that the discount's coupon was applied to, if it was applied directly to a particular invoice.
String? invoice;