invoiceItem property

String? invoiceItem
getter/setter pair

The invoice item id (or invoice line item id for invoice line items of type='subscription') that the discount's coupon was applied to, if it was applied directly to a particular invoice item or invoice line item.

Implementation

String? invoiceItem;