object property
String representing the object's type. Objects of the same type share the same value.
Implementation
DiscountObject? object;
String representing the object's type. Objects of the same type share the same value.
DiscountObject? object;