subscription property
The subscription that this coupon is applied to, if it is applied to a particular subscription.
Implementation
String? subscription;
The subscription that this coupon is applied to, if it is applied to a particular subscription.
String? subscription;