discount property
ID of an existing discount on the object (or one of its ancestors) to reuse.
Implementation
DiscountsResourceStackableDiscountDiscount? discount;
ID of an existing discount on the object (or one of its ancestors) to reuse.
DiscountsResourceStackableDiscountDiscount? discount;