promotionCode property
ID of the promotion code to create a new discount for.
Implementation
DiscountsResourceStackableDiscountPromotionCode? promotionCode;
ID of the promotion code to create a new discount for.
DiscountsResourceStackableDiscountPromotionCode? promotionCode;