createFromDiscriminatorValue static method

DiscountsResourceStackableDiscountCoupon createFromDiscriminatorValue(
  1. ParseNode parseNode
)

Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object

Implementation

static DiscountsResourceStackableDiscountCoupon createFromDiscriminatorValue(
    ParseNode parseNode) {
  var result = DiscountsResourceStackableDiscountCoupon();
  if (parseNode.getStringValue() != null) {
    result.string_ = parseNode.getStringValue();
  } else {
    result.coupon = Coupon();
  }
  return result;
}