models/dispute library
Classes
- Dispute
- auto generated A dispute occurs when a customer questions your charge with their card issuer.When this happens, you have the opportunity to respond to the dispute withevidence that shows that the charge is legitimate.Related guide: Disputes and fraud