Dispute class

auto generated A dispute occurs when a customer questions your charge with their card issuer.When this happens, you have the opportunity to respond to the dispute withevidence that shows that the charge is legitimate.Related guide: Disputes and fraud

Constructors

Dispute()
Instantiates a new Dispute and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amount int?
Disputed amount. Usually the amount of the charge, but it can differ (usually because of currency fluctuation or because only part of the order is disputed).
getter/setter pair
balanceTransactions Iterable<BalanceTransaction>?
List of zero, one, or two balance transactions that show funds withdrawn and reinstated to your Stripe account as a result of this dispute.
getter/setter pair
charge DisputeCharge?
ID of the charge that's disputed.
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
enhancedEligibilityTypes Iterable<DisputeEnhancedEligibilityTypes>?
List of eligibility types that are included in enhanced_evidence.
getter/setter pair
evidence DisputeEvidence?
The evidence property
getter/setter pair
evidenceDetails DisputeEvidenceDetails?
The evidence_details property
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
isChargeRefundable bool?
If true, it's still possible to refund the disputed payment. After the payment has been fully refunded, no further funds are withdrawn from your Stripe account as a result of this dispute.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
metadata DisputeMetadata?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
object DisputeObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
paymentIntent DisputePaymentIntent?
ID of the PaymentIntent that's disputed.
getter/setter pair
paymentMethodDetails DisputePaymentMethodDetails?
The payment_method_details property
getter/setter pair
reason String?
Reason given by cardholder for dispute. Possible values are bank_cannot_process, check_returned, credit_not_processed, customer_initiated, debit_not_authorized, duplicate, fraudulent, general, incorrect_account_details, insufficient_funds, noncompliant, product_not_received, product_unacceptable, subscription_canceled, or unrecognized. Learn more about dispute reasons.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status DisputeStatus?
The current status of a dispute. Possible values include:warning_needs_response, warning_under_review, warning_closed, needs_response, under_review, won, lost, or prevented.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) Dispute
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object