Dispute constructor
Dispute()
Instantiates a new Dispute and sets the default values.
Implementation
Dispute() : additionalData = {};
Instantiates a new Dispute and sets the default values.
Dispute() : additionalData = {};