amount property

int? amount
getter/setter pair

Disputed amount. Usually the amount of the charge, but it can differ (usually because of currency fluctuation or because only part of the order is disputed).

Implementation

int? amount;