models/event library

Classes

Event
auto generated Snapshot events allow you to track and react to activity in your Stripe integration. Whenthe state of another API resource changes, Stripe creates an Event object that containsall the relevant information associated with that action, including the affected APIresource. For example, a successful payment triggers a charge.succeeded event, whichcontains the Charge in the event's data property. Some actions trigger multiple events.For example, if you create a new subscription for a customer, it triggers both acustomer.subscription.created event and a charge.succeeded event.Configure an event destination in your account to listen for events that represent actionsyour integration needs to respond to. Additionally, you can retrieve an individual event ora list of events from the API.Connect platforms can also receive event notificationsthat occur in their connected accounts. These events include an account attribute thatidentifies the relevant connected account.You can access events through the Retrieve Event APIfor 30 days.