apiVersion property
The Stripe API version used to render data when the event was created. The contents of data never change, so this value remains static regardless of the API version currently in use. This property is populated only for events created on or after October 31, 2014.
Implementation
String? apiVersion;