GelatoReportDocumentOptions class

auto generated

Constructors

GelatoReportDocumentOptions()
Instantiates a new GelatoReportDocumentOptions and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
allowedTypes Iterable<GelatoReportDocumentOptionsAllowedTypes>?
Array of strings of allowed identity document types. If the provided identity document isn’t one of the allowed types, the verification check will fail with a document_type_not_allowed error code.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
requireIdNumber bool?
Collect an ID number and perform an ID number check with the document’s extracted name and date of birth.
getter/setter pair
requireLiveCapture bool?
Disable image uploads, identity document images have to be captured using the device’s camera.
getter/setter pair
requireMatchingSelfie bool?
Capture a face image and perform a selfie check comparing a photo ID and a picture of your user’s face. Learn more.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) GelatoReportDocumentOptions
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object