InvoiceBillingReason enum

auto generated Indicates the reason why the invoice was created.* manual: Unrelated to a subscription, for example, created via the invoice editor.* subscription: No longer in use. Applies to subscriptions from before May 2018 where no distinction was made between updates, cycles, and thresholds.* subscription_create: A new subscription was created.* subscription_cycle: A subscription advanced into a new period.* subscription_threshold: A subscription reached a billing threshold.* subscription_update: A subscription was updated.* upcoming: Reserved for upcoming invoices created through the Create Preview Invoice API or when an invoice.upcoming event is generated for an upcoming invoice on a subscription.

Inheritance
Available extensions

Values

automaticPendingInvoiceItemInvoice → const InvoiceBillingReason
const InvoiceBillingReason('automatic_pending_invoice_item_invoice')
manual → const InvoiceBillingReason
const InvoiceBillingReason('manual')
quoteAccept → const InvoiceBillingReason
const InvoiceBillingReason('quote_accept')
subscription → const InvoiceBillingReason
const InvoiceBillingReason('subscription')
subscriptionCreate → const InvoiceBillingReason
const InvoiceBillingReason('subscription_create')
subscriptionCycle → const InvoiceBillingReason
const InvoiceBillingReason('subscription_cycle')
subscriptionThreshold → const InvoiceBillingReason
const InvoiceBillingReason('subscription_threshold')
subscriptionUpdate → const InvoiceBillingReason
const InvoiceBillingReason('subscription_update')
upcoming → const InvoiceBillingReason
const InvoiceBillingReason('upcoming')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<InvoiceBillingReason>
A constant List of the values in this enum, in order of their declaration.