InvoicePayment class

auto generated Invoice Payments represent payments made against invoices. Invoice Payments canbe accessed in two ways:1. By expanding the payments field on the Invoice resource.2. By using the Invoice Payment retrieve and list endpoints.Invoice Payments include the mapping between payment objects, such as Payment Intent, and Invoices.This resource and its endpoints allows you to easily track if a payment is associated with a specific invoice andmonitor the allocation details of the payments.

Constructors

InvoicePayment()
Instantiates a new InvoicePayment and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amountPaid int?
Amount that was actually paid for this invoice, in cents (or local equivalent). This field is null until the payment is paid. This amount can be less than the amount_requested if the PaymentIntent’s amount_received is not sufficient to pay all of the invoices that it is attached to.
getter/setter pair
amountRequested int?
Amount intended to be paid toward this invoice, in cents (or local equivalent)
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
invoice InvoicePaymentInvoice?
The invoice that was paid.
getter/setter pair
isDefault bool?
Stripe automatically creates a default InvoicePayment when the invoice is finalized, and keeps it synchronized with the invoice’s amount_remaining. The PaymentIntent associated with the default payment can’t be edited or canceled directly.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
object InvoicePaymentObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
payment InvoicesPaymentsInvoicePaymentAssociatedPayment?
The payment property
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
The status of the payment, one of open, paid, or canceled.
getter/setter pair
statusTransitions InvoicesPaymentsInvoicePaymentStatusTransitions?
The status_transitions property
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) InvoicePayment
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object