preferredLanguage property
Preferred language of the Bancontact authorization page that the customer is redirected to.
Implementation
InvoicePaymentMethodOptionsBancontactPreferredLanguage? preferredLanguage;
Preferred language of the Bancontact authorization page that the customer is redirected to.
InvoicePaymentMethodOptionsBancontactPreferredLanguage? preferredLanguage;