version property

int? version
getter/setter pair

Version of this template; version increases by one when an update on the template changes any field that controls invoice rendering

Implementation

int? version;