InvoiceSettingCustomerRenderingOptions class

auto generated

Constructors

InvoiceSettingCustomerRenderingOptions()
Instantiates a new InvoiceSettingCustomerRenderingOptions and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amountTaxDisplay String?
How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
template String?
ID of the invoice rendering template to be used for this customer's invoices. If set, the template will be used on all invoices for this customer unless a template is set directly on the invoice.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) InvoiceSettingCustomerRenderingOptions
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object