template property

String? template
getter/setter pair

ID of the invoice rendering template to be used for this customer's invoices. If set, the template will be used on all invoices for this customer unless a template is set directly on the invoice.

Implementation

String? template;