InvoiceSettingSubscriptionSchedulePhaseSetting class

auto generated

Constructors

InvoiceSettingSubscriptionSchedulePhaseSetting()
Instantiates a new InvoiceSettingSubscriptionSchedulePhaseSetting and sets the default values.

Properties

accountTaxIds Iterable<String>?
The account tax IDs associated with this phase of the subscription schedule. Will be set on invoices generated by this phase of the subscription schedule.
getter/setter pair
additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
daysUntilDue int?
Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be null for subscription schedules where billing=charge_automatically.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
issuer ConnectAccountReference?
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) InvoiceSettingSubscriptionSchedulePhaseSetting
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object