InvoiceSettingSubscriptionScheduleSetting class
auto generated
Constructors
- InvoiceSettingSubscriptionScheduleSetting()
- Instantiates a new InvoiceSettingSubscriptionScheduleSetting and sets the default values.
Properties
-
accountTaxIds
↔ Iterable<
String> ? -
The account tax IDs associated with the subscription schedule. Will be set on invoices generated by the subscription schedule.
getter/setter pair
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- daysUntilDue ↔ int?
-
Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be
nullfor subscription schedules wherebilling=charge_automatically.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- issuer ↔ ConnectAccountReference?
-
The issuer property
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → InvoiceSettingSubscriptionScheduleSetting -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object