daysUntilDue property

int? daysUntilDue
getter/setter pair

Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be null for subscription schedules where billing=charge_automatically.

Implementation

int? daysUntilDue;