InvoicesResourceInvoiceRendering class

auto generated

Constructors

InvoicesResourceInvoiceRendering()
Instantiates a new InvoicesResourceInvoiceRendering and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amountTaxDisplay String?
How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pdf InvoiceRenderingPdf?
Invoice pdf rendering options
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
template String?
ID of the rendering template that the invoice is formatted by.
getter/setter pair
templateVersion int?
Version of the rendering template that the invoice is using.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) InvoicesResourceInvoiceRendering
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object