models/issuing/authorization library

Classes

Authorization
auto generated When an issued card is used to make a purchase, an Issuing Authorizationobject is created. Authorizations must be approved for thepurchase to be completed successfully.Related guide: Issued card authorizations