channel property
The method by which the fraud challenge was delivered to the cardholder.
Implementation
IssuingAuthorizationFraudChallengeChannel? channel;
The method by which the fraud challenge was delivered to the cardholder.
IssuingAuthorizationFraudChallengeChannel? channel;