undeliverableReason property
If the challenge is not deliverable, the reason why.
Implementation
IssuingAuthorizationFraudChallengeUndeliverableReason? undeliverableReason;
If the challenge is not deliverable, the reason why.
IssuingAuthorizationFraudChallengeUndeliverableReason? undeliverableReason;