IssuingAuthorizationFuelDataUnit enum
auto generated
The units for quantity_decimal.
Values
- chargingMinute → const IssuingAuthorizationFuelDataUnit
-
const IssuingAuthorizationFuelDataUnit('charging_minute') - imperialGallon → const IssuingAuthorizationFuelDataUnit
-
const IssuingAuthorizationFuelDataUnit('imperial_gallon') - kilogram → const IssuingAuthorizationFuelDataUnit
-
const IssuingAuthorizationFuelDataUnit('kilogram') - kilowattHour → const IssuingAuthorizationFuelDataUnit
-
const IssuingAuthorizationFuelDataUnit('kilowatt_hour') - liter → const IssuingAuthorizationFuelDataUnit
-
const IssuingAuthorizationFuelDataUnit('liter') - other → const IssuingAuthorizationFuelDataUnit
-
const IssuingAuthorizationFuelDataUnit('other') - pound → const IssuingAuthorizationFuelDataUnit
-
const IssuingAuthorizationFuelDataUnit('pound') - usGallon → const IssuingAuthorizationFuelDataUnit
-
const IssuingAuthorizationFuelDataUnit('us_gallon')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
IssuingAuthorizationFuelDataUnit> - A constant List of the values in this enum, in order of their declaration.