merchantAmount property
The amount the merchant is requesting to be authorized in the merchant_currency. The amount is in the smallest currency unit.
Implementation
int? merchantAmount;
The amount the merchant is requesting to be authorized in the merchant_currency. The amount is in the smallest currency unit.
int? merchantAmount;