IssuingAuthorizationRequest class

auto generated

Constructors

IssuingAuthorizationRequest()
Instantiates a new IssuingAuthorizationRequest and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amount int?
The pending_request.amount at the time of the request, presented in your card's currency and in the smallest currency unit. Stripe held this amount from your account to fund the authorization if the request was approved.
getter/setter pair
amountDetails IssuingAuthorizationAmountDetails?
Detailed breakdown of amount components. These amounts are denominated in currency and in the smallest currency unit.
getter/setter pair
approved bool?
Whether this request was approved.
getter/setter pair
authorizationCode String?
A code created by Stripe which is shared with the merchant to validate the authorization. This field will be populated if the authorization message was approved. The code typically starts with the letter "S", followed by a six-digit number. For example, "S498162". Please note that the code is not guaranteed to be unique across authorizations.
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
merchantAmount int?
The pending_request.merchant_amount at the time of the request, presented in the merchant_currency and in the smallest currency unit.
getter/setter pair
merchantCurrency String?
The currency that was collected by the merchant and presented to the cardholder for the authorization. Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
networkRiskScore int?
The card network's estimate of the likelihood that an authorization is fraudulent. Takes on values between 1 and 99.
getter/setter pair
reason IssuingAuthorizationRequestReason?
When an authorization is approved or declined by you or by Stripe, this field provides additional detail on the reason for the outcome.
getter/setter pair
reasonMessage String?
If the request_history.reason is webhook_error because the direct webhook response is invalid (for example, parsing errors or missing parameters), we surface a more detailed error message via this field.
getter/setter pair
requestedAt int?
Time when the card network received an authorization request from the acquirer in UTC. Referred to by networks as transmission time.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) IssuingAuthorizationRequest
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object