requestedAt property
Time when the card network received an authorization request from the acquirer in UTC. Referred to by networks as transmission time.
Implementation
int? requestedAt;
Time when the card network received an authorization request from the acquirer in UTC. Referred to by networks as transmission time.
int? requestedAt;