Card class

auto generated You can create physical or virtual cards that are issued to cardholders.

Constructors

Card()
Instantiates a new Card and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
brand String?
The brand of the card.
getter/setter pair
cancellationReason CardCancellationReason?
The reason why the card was canceled.
getter/setter pair
cardholder Cardholder?
An Issuing Cardholder object represents an individual or business entity who is issued cards.Related guide: How to create a cardholder
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Supported currencies are usd in the US, eur in the EU, and gbp in the UK.
getter/setter pair
cvc String?
The card's CVC. For security reasons, this is only available for virtual cards, and will be omitted unless you explicitly request it with the expand parameter. Additionally, it's only available via the "Retrieve a card" endpoint, not via "List all cards" or any other endpoint.
getter/setter pair
expMonth int?
The expiration month of the card.
getter/setter pair
expYear int?
The expiration year of the card.
getter/setter pair
financialAccount String?
The financial account this card is attached to.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
last4 String?
The last 4 digits of the card number.
getter/setter pair
latestFraudWarning IssuingCardFraudWarning?
Stripe’s assessment of whether this card’s details have been compromised. If this property isn't null, cancel and reissue the card to prevent fraudulent activity risk.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
metadata CardMetadata?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
number String?
The full unredacted card number. For security reasons, this is only available for virtual cards, and will be omitted unless you explicitly request it with the expand parameter. Additionally, it's only available via the "Retrieve a card" endpoint, not via "List all cards" or any other endpoint.
getter/setter pair
object CardObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
personalizationDesign CardPersonalizationDesign?
The personalization design object belonging to this card.
getter/setter pair
replacedBy CardReplacedBy?
The latest card that replaces this card, if any.
getter/setter pair
replacementFor CardReplacementFor?
The card this card replaces, if any.
getter/setter pair
replacementReason CardReplacementReason?
The reason why the previous card needed to be replaced.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondLine String?
Text separate from cardholder name, printed on the card.
getter/setter pair
shipping IssuingCardShipping?
Where and how the card will be shipped.
getter/setter pair
spendingControls IssuingCardAuthorizationControls?
The spending_controls property
getter/setter pair
status CardStatus?
Whether authorizations can be approved on this card. May be blocked from activating cards depending on past-due Cardholder requirements. Defaults to inactive.
getter/setter pair
type_ CardType?
The type of the card.
getter/setter pair
wallets IssuingCardWallets?
Information relating to digital wallets (like Apple Pay and Google Pay).
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) Card
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object