IssuingCardAuthorizationControls class
auto generated
Constructors
- IssuingCardAuthorizationControls()
- Instantiates a new IssuingCardAuthorizationControls and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
-
allowedCategories
↔ Iterable<
IssuingCardAuthorizationControlsAllowedCategories> ? -
Array of strings containing categories of authorizations to allow. All other categories will be blocked. Cannot be set with
blocked_categories.getter/setter pair -
allowedMerchantCountries
↔ Iterable<
String> ? -
Array of strings containing representing countries from which authorizations will be allowed. Authorizations from merchants in all other countries will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g.
US). Cannot be set withblocked_merchant_countries. Provide an empty value to unset this control.getter/setter pair -
blockedCategories
↔ Iterable<
IssuingCardAuthorizationControlsBlockedCategories> ? -
Array of strings containing categories of authorizations to decline. All other categories will be allowed. Cannot be set with
allowed_categories.getter/setter pair -
blockedMerchantCountries
↔ Iterable<
String> ? -
Array of strings containing representing countries from which authorizations will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g.
US). Cannot be set withallowed_merchant_countries. Provide an empty value to unset this control.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
spendingLimits
↔ Iterable<
IssuingCardSpendingLimit> ? -
Limit spending with amount-based rules that apply across any cards this card replaced (i.e., its
replacement_forcard and that card'sreplacement_forcard, up the chain).getter/setter pair - spendingLimitsCurrency ↔ String?
-
Currency of the amounts within
spending_limits. Always the same as the currency of the card.getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → IssuingCardAuthorizationControls -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object