allowedMerchantCountries property

Iterable<String>? allowedMerchantCountries
getter/setter pair

Array of strings containing representing countries from which authorizations will be allowed. Authorizations from merchants in all other countries will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. US). Cannot be set with blocked_merchant_countries. Provide an empty value to unset this control.

Implementation

Iterable<String>? allowedMerchantCountries;