IssuingCardSpendingLimitInterval enum

auto generated Interval (or event) to which the amount applies.

Inheritance
Available extensions

Values

allTime → const IssuingCardSpendingLimitInterval
const IssuingCardSpendingLimitInterval('all_time')
daily → const IssuingCardSpendingLimitInterval
const IssuingCardSpendingLimitInterval('daily')
monthly → const IssuingCardSpendingLimitInterval
const IssuingCardSpendingLimitInterval('monthly')
perAuthorization → const IssuingCardSpendingLimitInterval
const IssuingCardSpendingLimitInterval('per_authorization')
weekly → const IssuingCardSpendingLimitInterval
const IssuingCardSpendingLimitInterval('weekly')
yearly → const IssuingCardSpendingLimitInterval
const IssuingCardSpendingLimitInterval('yearly')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IssuingCardSpendingLimitInterval>
A constant List of the values in this enum, in order of their declaration.