IssuingNetworkTokenDevice class

auto generated

Constructors

IssuingNetworkTokenDevice()
Instantiates a new IssuingNetworkTokenDevice and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
deviceFingerprint String?
An obfuscated ID derived from the device ID.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ipAddress String?
The IP address of the device at provisioning time.
getter/setter pair
location String?
The geographic latitude/longitude coordinates of the device at provisioning time. The format is +-decimal/+-decimal.
getter/setter pair
name String?
The name of the device used for tokenization.
getter/setter pair
phoneNumber String?
The phone number of the device used for tokenization.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type_ IssuingNetworkTokenDeviceType?
The type of device used for tokenization.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) IssuingNetworkTokenDevice
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object