IssuingNetworkTokenMastercard class

auto generated

Constructors

IssuingNetworkTokenMastercard()
Instantiates a new IssuingNetworkTokenMastercard and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
cardReferenceId String?
A unique reference ID from MasterCard to represent the card account number.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenReferenceId String?
The network-unique identifier for the token.
getter/setter pair
tokenRequestorId String?
The ID of the entity requesting tokenization, specific to MasterCard.
getter/setter pair
tokenRequestorName String?
The name of the entity requesting tokenization, if known. This is directly provided from MasterCard.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) IssuingNetworkTokenMastercard
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object