IssuingNetworkTokenWalletProvider class

auto generated

Constructors

IssuingNetworkTokenWalletProvider()
Instantiates a new IssuingNetworkTokenWalletProvider and sets the default values.

Properties

accountId String?
The wallet provider-given account ID of the digital wallet the token belongs to.
getter/setter pair
accountTrustScore int?
An evaluation on the trustworthiness of the wallet account between 1 and 5. A higher score indicates more trustworthy.
getter/setter pair
additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
cardholderAddress IssuingNetworkTokenAddress?
The cardholder_address property
getter/setter pair
cardholderName String?
The name of the cardholder tokenizing the card.
getter/setter pair
cardNumberSource IssuingNetworkTokenWalletProviderCardNumberSource?
The method used for tokenizing a card.
getter/setter pair
deviceTrustScore int?
An evaluation on the trustworthiness of the device. A higher score indicates more trustworthy.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hashedAccountEmailAddress String?
The hashed email address of the cardholder's account with the wallet provider.
getter/setter pair
reasonCodes Iterable<IssuingNetworkTokenWalletProviderReasonCodes>?
The reasons for suggested tokenization given by the card network.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suggestedDecision IssuingNetworkTokenWalletProviderSuggestedDecision?
The recommendation on responding to the tokenization request.
getter/setter pair
suggestedDecisionVersion String?
The version of the standard for mapping reason codes followed by the wallet provider.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) IssuingNetworkTokenWalletProvider
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object