PersonalizationDesign class
auto generated A Personalization Design is a logical grouping of a Physical Bundle, card logo, and carrier text that represents a product line.
Constructors
- PersonalizationDesign()
- Instantiates a new PersonalizationDesign and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- cardLogo ↔ PersonalizationDesignCardLogo?
-
The file for the card logo to use with physical bundles that support card logos. Must have a
purposevalue ofissuing_logo.getter/setter pair - carrierText ↔ IssuingPersonalizationDesignCarrierText?
-
Hash containing carrier text, for use with physical bundles that support carrier text.
getter/setter pair
- created ↔ int?
-
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - lookupKey ↔ String?
-
A lookup key used to retrieve personalization designs dynamically from a static string. This may be up to 200 characters.
getter/setter pair
- metadata ↔ PersonalizationDesignMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- name ↔ String?
-
Friendly display name.
getter/setter pair
- object ↔ PersonalizationDesignObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- physicalBundle ↔ PersonalizationDesignPhysicalBundle?
-
The physical bundle object belonging to this personalization design.
getter/setter pair
- preferences ↔ IssuingPersonalizationDesignPreferences?
-
The preferences property
getter/setter pair
- rejectionReasons ↔ IssuingPersonalizationDesignRejectionReasons?
-
The rejection_reasons property
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ PersonalizationDesignStatus?
-
Whether this personalization design can be used to create cards.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → PersonalizationDesign -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object