cardLogo property
The file for the card logo to use with physical bundles that support card logos. Must have a purpose value of issuing_logo.
Implementation
PersonalizationDesignCardLogo? cardLogo;
The file for the card logo to use with physical bundles that support card logos. Must have a purpose value of issuing_logo.
PersonalizationDesignCardLogo? cardLogo;