physicalBundle property
The physical bundle object belonging to this personalization design.
Implementation
PersonalizationDesignPhysicalBundle? physicalBundle;
The physical bundle object belonging to this personalization design.
PersonalizationDesignPhysicalBundle? physicalBundle;