IssuingPersonalizationDesignPreferences class

auto generated

Constructors

IssuingPersonalizationDesignPreferences()
Instantiates a new IssuingPersonalizationDesignPreferences and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
isDefault bool?
Whether we use this personalization design to create cards when one isn't specified. A connected account uses the Connect platform's default design if no personalization design is set as the default design.
getter/setter pair
isPlatformDefault bool?
Whether this personalization design is used to create cards when one is not specified and a default for this connected account does not exist.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) IssuingPersonalizationDesignPreferences
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object