PhysicalBundle class

auto generated A Physical Bundle represents the bundle of physical items - card stock, carrier letter, and envelope - that is shipped to a cardholder when you create a physical card.

Constructors

PhysicalBundle()
Instantiates a new PhysicalBundle and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
features IssuingPhysicalBundleFeatures?
The features property
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
name String?
Friendly display name.
getter/setter pair
object PhysicalBundleObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status PhysicalBundleStatus?
Whether this physical bundle can be used to create cards.
getter/setter pair
type_ PhysicalBundleType?
Whether this physical bundle is a standard Stripe offering or custom-made for you.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PhysicalBundle
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object