cardLogo property

IssuingPhysicalBundleFeaturesCardLogo? cardLogo
getter/setter pair

The policy for how to use card logo images in a card design with this physical bundle.

Implementation

IssuingPhysicalBundleFeaturesCardLogo? cardLogo;