carrierText property
The policy for how to use carrier letter text in a card design with this physical bundle.
Implementation
IssuingPhysicalBundleFeaturesCarrierText? carrierText;
The policy for how to use carrier letter text in a card design with this physical bundle.
IssuingPhysicalBundleFeaturesCarrierText? carrierText;