secondLine property
The policy for how to use a second line on a card with this physical bundle.
Implementation
IssuingPhysicalBundleFeaturesSecondLine? secondLine;
The policy for how to use a second line on a card with this physical bundle.
IssuingPhysicalBundleFeaturesSecondLine? secondLine;