models/issuing/token library

Classes

Token
auto generated An issuing token object is created when an issued card is added to a digital wallet. As a card issuer, you can view and manage these tokens through Stripe.