deviceFingerprint property
The hashed ID derived from the device ID from the card network associated with the token.
Implementation
String? deviceFingerprint;
The hashed ID derived from the device ID from the card network associated with the token.
String? deviceFingerprint;