networkUpdatedAt property
Time at which the token was last updated by the card network. Measured in seconds since the Unix epoch.
Implementation
int? networkUpdatedAt;
Time at which the token was last updated by the card network. Measured in seconds since the Unix epoch.
int? networkUpdatedAt;