TransactionWallet enum

auto generated The digital wallet used for this transaction. One of apple_pay, google_pay, or samsung_pay.

Inheritance
Available extensions

Values

applePay → const TransactionWallet
const TransactionWallet('apple_pay')
googlePay → const TransactionWallet
const TransactionWallet('google_pay')
samsungPay → const TransactionWallet
const TransactionWallet('samsung_pay')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TransactionWallet>
A constant List of the values in this enum, in order of their declaration.