userAgent property
The user-agent string from the browser where the representative declaration attestation was made.
Implementation
String? userAgent;
The user-agent string from the browser where the representative declaration attestation was made.
String? userAgent;