models/line_item library

Classes

LineItem
auto generated Invoice Line Items represent the individual lines within an invoice and only exist within the context of an invoice.Each line item is backed by either an invoice item or a subscription item.