LineItem class

auto generated Invoice Line Items represent the individual lines within an invoice and only exist within the context of an invoice.Each line item is backed by either an invoice item or a subscription item.

Constructors

LineItem()
Instantiates a new LineItem and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amount int?
The amount, in cents (or local equivalent).
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
description String?
An arbitrary string attached to the object. Often useful for displaying to users.
getter/setter pair
discountable bool?
If true, discounts will apply to this line item. Always false for prorations.
getter/setter pair
discountAmounts Iterable<DiscountsResourceDiscountAmount>?
The amount of discount calculated per discount for this line item.
getter/setter pair
discounts Iterable<String>?
The discounts applied to the invoice line item. Line item discounts are applied before invoice discounts. Use expand[]=discounts to expand each discount.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
invoice String?
The ID of the invoice that contains this line item.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
metadata LineItemMetadata?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Note that for line items with type=subscription, metadata reflects the current metadata from the subscription associated with the line item, unless the invoice line was directly updated with different metadata after creation.
getter/setter pair
object LineItemObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
parent BillingBillResourceInvoicingLinesParentsInvoiceLineItemParent?
The parent that generated this line item.
getter/setter pair
period InvoiceLineItemPeriod?
The period property
getter/setter pair
pretaxCreditAmounts Iterable<InvoicesResourcePretaxCreditAmount>?
Contains pretax credit amounts (ex: discount, credit grants, etc) that apply to this line item.
getter/setter pair
pricing BillingBillResourceInvoicingPricingPricing?
The pricing information of the line item.
getter/setter pair
quantity int?
The quantity of the subscription, if the line item is a subscription or a proration.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscription LineItemSubscription?
The subscription property
getter/setter pair
subtotal int?
The subtotal of the line item, in cents (or local equivalent), before any discounts or taxes.
getter/setter pair
taxes Iterable<BillingBillResourceInvoicingTaxesTax>?
The tax information of the line item.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) LineItem
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object