metadata property

LineItemMetadata? metadata
getter/setter pair

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Note that for line items with type=subscription, metadata reflects the current metadata from the subscription associated with the line item, unless the invoice line was directly updated with different metadata after creation.

Implementation

LineItemMetadata? metadata;