LineItemsTaxAmount class

auto generated

Constructors

LineItemsTaxAmount()
Instantiates a new LineItemsTaxAmount and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amount int?
Amount of tax applied for this rate.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rate TaxRate?
Tax rates can be applied to invoices, subscriptions and Checkout Sessions to collect tax.Related guide: Tax rates
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taxabilityReason LineItemsTaxAmountTaxabilityReason?
The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.
getter/setter pair
taxableAmount int?
The amount on which tax is calculated, in cents (or local equivalent).
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) LineItemsTaxAmount
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object