LinkedAccountOptionsCommon class
auto generated
Constructors
- LinkedAccountOptionsCommon()
- Instantiates a new LinkedAccountOptionsCommon and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- filters ↔ PaymentFlowsPrivatePaymentMethodsFinancialConnectionsCommonLinkedAccountOptionsFilters?
-
The filters property
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
permissions
↔ Iterable<
LinkedAccountOptionsCommonPermissions> ? -
The list of permissions to request. The
payment_methodpermission must be included.getter/setter pair -
prefetch
↔ Iterable<
LinkedAccountOptionsCommonPrefetch> ? -
Data features requested to be retrieved upon account creation.
getter/setter pair
- returnUrl ↔ String?
-
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → LinkedAccountOptionsCommon -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object