prefetch property
Data features requested to be retrieved upon account creation.
Implementation
Iterable<LinkedAccountOptionsCommonPrefetch>? prefetch;
Data features requested to be retrieved upon account creation.
Iterable<LinkedAccountOptionsCommonPrefetch>? prefetch;