models/login_link library
Classes
- LoginLink
- auto generated Login Links are single-use URLs that takes an Express account to the login page for their Stripe dashboard.A Login Link differs from an Account Link in that it takes the user directly to their Express dashboard for the specified account