LoginLink class
auto generated Login Links are single-use URLs that takes an Express account to the login page for their Stripe dashboard.A Login Link differs from an Account Link in that it takes the user directly to their Express dashboard for the specified account
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- created ↔ int?
-
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- object ↔ LoginLinkObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url ↔ String?
-
The URL for the login link.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → LoginLink -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object