MandatePaymentMethodDetails class

auto generated

Constructors

MandatePaymentMethodDetails()
Instantiates a new MandatePaymentMethodDetails and sets the default values.

Properties

acssDebit MandateAcssDebit?
The acss_debit property
getter/setter pair
additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amazonPay MandateAmazonPay?
The amazon_pay property
getter/setter pair
auBecsDebit MandateAuBecsDebit?
The au_becs_debit property
getter/setter pair
bacsDebit MandateBacsDebit?
The bacs_debit property
getter/setter pair
card CardMandatePaymentMethodDetails?
The card property
getter/setter pair
cashapp MandateCashapp?
The cashapp property
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
kakaoPay MandateKakaoPay?
The kakao_pay property
getter/setter pair
klarna MandateKlarna?
The klarna property
getter/setter pair
krCard MandateKrCard?
The kr_card property
getter/setter pair
The link property
getter/setter pair
The naver_pay property
getter/setter pair
nzBankAccount MandateNzBankAccount?
The nz_bank_account property
getter/setter pair
paypal MandatePaypal?
The paypal property
getter/setter pair
payto MandatePayto?
The payto property
getter/setter pair
revolutPay MandateRevolutPay?
The revolut_pay property
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sepaDebit MandateSepaDebit?
The sepa_debit property
getter/setter pair
type_ String?
This mandate corresponds with a specific payment method type. The payment_method_details includes an additional hash with the same name and contains mandate information that's specific to that payment method.
getter/setter pair
usBankAccount MandateUsBankAccount?
The us_bank_account property
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) MandatePaymentMethodDetails
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object