object property
Object containing the API resource relevant to the event. For example, an invoice.created event will have a full invoice object as the value of the object key.
Implementation
NotificationEventDataObject? object;
Object containing the API resource relevant to the event. For example, an invoice.created event will have a full invoice object as the value of the object key.
NotificationEventDataObject? object;