NotificationEventRequest class

auto generated

Constructors

NotificationEventRequest()
Instantiates a new NotificationEventRequest and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
id String?
ID of the API request that caused the event. If null, the event was automatic (e.g., Stripe's automatic subscription handling). Request logs are available in the dashboard, but currently not in the API.
getter/setter pair
idempotencyKey String?
The idempotency key transmitted during the request, if any. Note: This property is populated only for events on or after May 23, 2017.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) NotificationEventRequest
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object