idempotencyKey property
The idempotency key transmitted during the request, if any. Note: This property is populated only for events on or after May 23, 2017.
Implementation
String? idempotencyKey;
The idempotency key transmitted during the request, if any. Note: This property is populated only for events on or after May 23, 2017.
String? idempotencyKey;