PaymentFlowsAutomaticPaymentMethodsPaymentIntent class

auto generated

Constructors

PaymentFlowsAutomaticPaymentMethodsPaymentIntent()
Instantiates a new PaymentFlowsAutomaticPaymentMethodsPaymentIntent and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
allowRedirects PaymentFlowsAutomaticPaymentMethodsPaymentIntentAllowRedirects?
Controls whether this PaymentIntent will accept redirect-based payment methods.Redirect-based payment methods may require your customer to be redirected to a payment method's app or site for authentication or additional steps. To confirm this PaymentIntent, you may be required to provide a return_url to redirect customers back to your site after they authenticate or complete the payment.
getter/setter pair
enabled bool?
Automatically calculates compatible payment methods
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PaymentFlowsAutomaticPaymentMethodsPaymentIntent
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object