PaymentIntentNextAction class

auto generated

Constructors

PaymentIntentNextAction()
Instantiates a new PaymentIntentNextAction and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
alipayHandleRedirect PaymentIntentNextActionAlipayHandleRedirect?
The alipay_handle_redirect property
getter/setter pair
boletoDisplayDetails PaymentIntentNextActionBoleto?
The boleto_display_details property
getter/setter pair
cardAwaitNotification PaymentIntentNextActionCardAwaitNotification?
The card_await_notification property
getter/setter pair
cashappHandleRedirectOrDisplayQrCode PaymentIntentNextActionCashappHandleRedirectOrDisplayQrCode?
The cashapp_handle_redirect_or_display_qr_code property
getter/setter pair
displayBankTransferInstructions PaymentIntentNextActionDisplayBankTransferInstructions?
The display_bank_transfer_instructions property
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
konbiniDisplayDetails PaymentIntentNextActionKonbini?
The konbini_display_details property
getter/setter pair
multibancoDisplayDetails PaymentIntentNextActionDisplayMultibancoDetails?
The multibanco_display_details property
getter/setter pair
oxxoDisplayDetails PaymentIntentNextActionDisplayOxxoDetails?
The oxxo_display_details property
getter/setter pair
paynowDisplayQrCode PaymentIntentNextActionPaynowDisplayQrCode?
The paynow_display_qr_code property
getter/setter pair
pixDisplayQrCode PaymentIntentNextActionPixDisplayQrCode?
The pix_display_qr_code property
getter/setter pair
promptpayDisplayQrCode PaymentIntentNextActionPromptpayDisplayQrCode?
The promptpay_display_qr_code property
getter/setter pair
redirectToUrl PaymentIntentNextActionRedirectToUrl?
The redirect_to_url property
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
swishHandleRedirectOrDisplayQrCode PaymentIntentNextActionSwishHandleRedirectOrDisplayQrCode?
The swish_handle_redirect_or_display_qr_code property
getter/setter pair
type_ String?
Type of the next action to perform. Refer to the other child attributes under next_action for available values. Examples include: redirect_to_url, use_stripe_sdk, alipay_handle_redirect, oxxo_display_details, or verify_with_microdeposits.
getter/setter pair
useStripeSdk PaymentIntentNextActionUseStripeSdk?
When confirming a PaymentIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows. The shape of the contents is subject to change and is only intended to be used by Stripe.js.
getter/setter pair
verifyWithMicrodeposits PaymentIntentNextActionVerifyWithMicrodeposits?
The verify_with_microdeposits property
getter/setter pair
wechatPayDisplayQrCode PaymentIntentNextActionWechatPayDisplayQrCode?
The wechat_pay_display_qr_code property
getter/setter pair
wechatPayRedirectToAndroidApp PaymentIntentNextActionWechatPayRedirectToAndroidApp?
The wechat_pay_redirect_to_android_app property
getter/setter pair
wechatPayRedirectToIosApp PaymentIntentNextActionWechatPayRedirectToIosApp?
The wechat_pay_redirect_to_ios_app property
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PaymentIntentNextAction
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object