captureMethod property
Controls when the funds will be captured from the customer's account.
Implementation
PaymentIntentPaymentMethodOptionsLinkCaptureMethod? captureMethod;
Controls when the funds will be captured from the customer's account.
PaymentIntentPaymentMethodOptionsLinkCaptureMethod? captureMethod;