PaymentIntentPaymentMethodOptionsSatispay class

auto generated Composed type wrapper for classes PaymentIntentTypeSpecificPaymentMethodOptionsClient, PaymentMethodOptionsSatispay

Properties

hashCode int
The hash code for this object.
no setterinherited
paymentIntentTypeSpecificPaymentMethodOptionsClient PaymentIntentTypeSpecificPaymentMethodOptionsClient?
Composed type representation for type PaymentIntentTypeSpecificPaymentMethodOptionsClient
getter/setter pair
paymentMethodOptionsSatispay PaymentMethodOptionsSatispay?
Composed type representation for type PaymentMethodOptionsSatispay
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PaymentIntentPaymentMethodOptionsSatispay
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object