models/payment_link library
Classes
- PaymentLink
- auto generated A payment link is a shareable URL that will take your customers to a hosted payment page. A payment link can be shared and used multiple times.When a customer opens a payment link it will open a new checkout session to render the payment page. You can use checkout session events to track payments through payment links.Related guide: Payment Links API