PaymentLink class

auto generated A payment link is a shareable URL that will take your customers to a hosted payment page. A payment link can be shared and used multiple times.When a customer opens a payment link it will open a new checkout session to render the payment page. You can use checkout session events to track payments through payment links.Related guide: Payment Links API

Constructors

PaymentLink()
Instantiates a new PaymentLink and sets the default values.

Properties

active bool?
Whether the payment link's url is active. If false, customers visiting the URL will be shown a page saying that the link has been deactivated.
getter/setter pair
additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
afterCompletion PaymentLinksResourceAfterCompletion?
The after_completion property
getter/setter pair
allowPromotionCodes bool?
Whether user redeemable promotion codes are enabled.
getter/setter pair
application PaymentLinkApplication?
The ID of the Connect application that created the Payment Link.
getter/setter pair
applicationFeeAmount int?
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account.
getter/setter pair
applicationFeePercent double?
This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account.
getter/setter pair
automaticTax PaymentLinksResourceAutomaticTax?
The automatic_tax property
getter/setter pair
billingAddressCollection PaymentLinkBillingAddressCollection?
Configuration for collecting the customer's billing address. Defaults to auto.
getter/setter pair
consentCollection PaymentLinksResourceConsentCollection?
When set, provides configuration to gather active consent from customers.
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
customerCreation PaymentLinkCustomerCreation?
Configuration for Customer creation during checkout.
getter/setter pair
customFields Iterable<PaymentLinksResourceCustomFields>?
Collect additional information from your customer using custom fields. Up to 3 fields are supported.
getter/setter pair
customText PaymentLinksResourceCustomText?
The custom_text property
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
inactiveMessage String?
The custom message to be displayed to a customer when a payment link is no longer active.
getter/setter pair
invoiceCreation PaymentLinksResourceInvoiceCreation?
Configuration for creating invoice for payment mode payment links.
getter/setter pair
lineItems PaymentLinkLineItems?
The line items representing what is being sold.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
metadata PaymentLinkMetadata?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
nameCollection PaymentLinksResourceNameCollection?
The name_collection property
getter/setter pair
object PaymentLinkObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
onBehalfOf PaymentLinkOnBehalfOf?
The account on behalf of which to charge. See the Connect documentation for details.
getter/setter pair
optionalItems Iterable<PaymentLinksResourceOptionalItem>?
The optional items presented to the customer at checkout.
getter/setter pair
paymentIntentData PaymentLinksResourcePaymentIntentData?
Indicates the parameters to be passed to PaymentIntent creation during checkout.
getter/setter pair
paymentMethodCollection PaymentLinkPaymentMethodCollection?
Configuration for collecting a payment method during checkout. Defaults to always.
getter/setter pair
paymentMethodTypes Iterable<PaymentLinkPaymentMethodTypes>?
The list of payment method types that customers can use. When null, Stripe will dynamically show relevant payment methods you've enabled in your payment method settings.
getter/setter pair
phoneNumberCollection PaymentLinksResourcePhoneNumberCollection?
The phone_number_collection property
getter/setter pair
restrictions PaymentLinksResourceRestrictions?
Settings that restrict the usage of a payment link.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingAddressCollection PaymentLinksResourceShippingAddressCollection?
Configuration for collecting the customer's shipping address.
getter/setter pair
shippingOptions Iterable<PaymentLinksResourceShippingOption>?
The shipping rate options applied to the session.
getter/setter pair
submitType PaymentLinkSubmitType?
Indicates the type of transaction being performed which customizes relevant text on the page, such as the submit button.
getter/setter pair
subscriptionData PaymentLinksResourceSubscriptionData?
When creating a subscription, the specified configuration data will be used. There must be at least one line item with a recurring price to use subscription_data.
getter/setter pair
taxIdCollection PaymentLinksResourceTaxIdCollection?
The tax_id_collection property
getter/setter pair
transferData PaymentLinksResourceTransferData?
The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to.
getter/setter pair
url String?
The public URL that can be shared with customers.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PaymentLink
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object