active property
Whether the payment link's url is active. If false, customers visiting the URL will be shown a page saying that the link has been deactivated.
Implementation
bool? active;
Whether the payment link's url is active. If false, customers visiting the URL will be shown a page saying that the link has been deactivated.
bool? active;