applicationFeeAmount property
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account.
Implementation
int? applicationFeeAmount;
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account.
int? applicationFeeAmount;