consentCollection property
When set, provides configuration to gather active consent from customers.
Implementation
PaymentLinksResourceConsentCollection? consentCollection;
When set, provides configuration to gather active consent from customers.
PaymentLinksResourceConsentCollection? consentCollection;