inactiveMessage property
The custom message to be displayed to a customer when a payment link is no longer active.
Implementation
String? inactiveMessage;
The custom message to be displayed to a customer when a payment link is no longer active.
String? inactiveMessage;