transferData property

PaymentLinksResourceTransferData? transferData
getter/setter pair

The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to.

Implementation

PaymentLinksResourceTransferData? transferData;