shippingAddress property
Custom text that should be displayed alongside shipping address collection.
Implementation
PaymentLinksResourceCustomTextPosition? shippingAddress;
Custom text that should be displayed alongside shipping address collection.
PaymentLinksResourceCustomTextPosition? shippingAddress;