submit property
Custom text that should be displayed alongside the payment confirmation button.
Implementation
PaymentLinksResourceCustomTextPosition? submit;
Custom text that should be displayed alongside the payment confirmation button.
PaymentLinksResourceCustomTextPosition? submit;