PaymentLinksResourceSubscriptionData class
auto generated
Constructors
- PaymentLinksResourceSubscriptionData()
- Instantiates a new PaymentLinksResourceSubscriptionData and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- description ↔ String?
-
The subscription's description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- invoiceSettings ↔ PaymentLinksResourceSubscriptionDataInvoiceSettings?
-
The invoice_settings property
getter/setter pair
- metadata ↔ PaymentLinksResourceSubscriptionDataMetadata?
-
Set of key-value pairs that will set metadata on Subscriptions generated from this payment link.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trialPeriodDays ↔ int?
-
Integer representing the number of trial period days before the customer is charged for the first time.
getter/setter pair
- trialSettings ↔ SubscriptionsTrialsResourceTrialSettings?
-
Settings related to subscription trials.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → PaymentLinksResourceSubscriptionData -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object