trialPeriodDays property
Integer representing the number of trial period days before the customer is charged for the first time.
Implementation
int? trialPeriodDays;
Integer representing the number of trial period days before the customer is charged for the first time.
int? trialPeriodDays;