PaymentMethod class

auto generated PaymentMethod objects represent your customer's payment instruments.You can use them with PaymentIntents to collect payments or save them toCustomer objects to store instrument details for future payments.Related guides: Payment Methods and More Payment Scenarios.

Constructors

PaymentMethod()
Instantiates a new PaymentMethod and sets the default values.

Properties

acssDebit PaymentMethodAcssDebit?
The acss_debit property
getter/setter pair
additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
affirm PaymentMethodAffirm?
The affirm property
getter/setter pair
afterpayClearpay PaymentMethodAfterpayClearpay?
The afterpay_clearpay property
getter/setter pair
alipay PaymentFlowsPrivatePaymentMethodsAlipay?
The alipay property
getter/setter pair
allowRedisplay PaymentMethodAllowRedisplay?
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.
getter/setter pair
alma PaymentMethodAlma?
The alma property
getter/setter pair
amazonPay PaymentMethodAmazonPay?
The amazon_pay property
getter/setter pair
auBecsDebit PaymentMethodAuBecsDebit?
The au_becs_debit property
getter/setter pair
bacsDebit PaymentMethodBacsDebit?
The bacs_debit property
getter/setter pair
bancontact PaymentMethodBancontact?
The bancontact property
getter/setter pair
billie PaymentMethodBillie?
The billie property
getter/setter pair
billingDetails BillingDetails?
The billing_details property
getter/setter pair
blik PaymentMethodBlik?
The blik property
getter/setter pair
boleto PaymentMethodBoleto?
The boleto property
getter/setter pair
card PaymentMethodCard?
The card property
getter/setter pair
cardPresent PaymentMethodCardPresent?
The card_present property
getter/setter pair
cashapp PaymentMethodCashapp?
The cashapp property
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
crypto PaymentMethodCrypto?
The crypto property
getter/setter pair
custom PaymentMethodCustom?
The custom property
getter/setter pair
customer PaymentMethodCustomer?
The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.
getter/setter pair
customerAccount String?
The customer_account property
getter/setter pair
customerBalance PaymentMethodCustomerBalance?
The customer_balance property
getter/setter pair
eps PaymentMethodEps?
The eps property
getter/setter pair
fpx PaymentMethodFpx?
The fpx property
getter/setter pair
giropay PaymentMethodGiropay?
The giropay property
getter/setter pair
grabpay PaymentMethodGrabpay?
The grabpay property
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
ideal PaymentMethodIdeal?
The ideal property
getter/setter pair
interacPresent PaymentMethodInteracPresent?
The interac_present property
getter/setter pair
kakaoPay PaymentMethodKakaoPay?
The kakao_pay property
getter/setter pair
klarna PaymentMethodKlarna?
The klarna property
getter/setter pair
konbini PaymentMethodKonbini?
The konbini property
getter/setter pair
krCard PaymentMethodKrCard?
The kr_card property
getter/setter pair
The link property
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
mbWay PaymentMethodMbWay?
The mb_way property
getter/setter pair
metadata PaymentMethodMetadata?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
mobilepay PaymentMethodMobilepay?
The mobilepay property
getter/setter pair
multibanco PaymentMethodMultibanco?
The multibanco property
getter/setter pair
The naver_pay property
getter/setter pair
nzBankAccount PaymentMethodNzBankAccount?
The nz_bank_account property
getter/setter pair
object PaymentMethodObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
oxxo PaymentMethodOxxo?
The oxxo property
getter/setter pair
p24 PaymentMethodP24?
The p24 property
getter/setter pair
payByBank PaymentMethodPayByBank?
The pay_by_bank property
getter/setter pair
payco PaymentMethodPayco?
The payco property
getter/setter pair
paynow PaymentMethodPaynow?
The paynow property
getter/setter pair
paypal PaymentMethodPaypal?
The paypal property
getter/setter pair
payto PaymentMethodPayto?
The payto property
getter/setter pair
pix PaymentMethodPix?
The pix property
getter/setter pair
promptpay PaymentMethodPromptpay?
The promptpay property
getter/setter pair
radarOptions RadarRadarOptions?
Options to configure Radar. See Radar Session for more information.
getter/setter pair
revolutPay PaymentMethodRevolutPay?
The revolut_pay property
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samsungPay PaymentMethodSamsungPay?
The samsung_pay property
getter/setter pair
satispay PaymentMethodSatispay?
The satispay property
getter/setter pair
sepaDebit PaymentMethodSepaDebit?
The sepa_debit property
getter/setter pair
sofort PaymentMethodSofort?
The sofort property
getter/setter pair
swish PaymentMethodSwish?
The swish property
getter/setter pair
twint PaymentMethodTwint?
The twint property
getter/setter pair
type_ PaymentMethodType?
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
getter/setter pair
usBankAccount PaymentMethodUsBankAccount?
The us_bank_account property
getter/setter pair
wechatPay PaymentMethodWechatPay?
The wechat_pay property
getter/setter pair
zip PaymentMethodZip?
The zip property
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PaymentMethod
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object