object property
String representing the object's type. Objects of the same type share the same value.
Implementation
PaymentMethodObject? object;
String representing the object's type. Objects of the same type share the same value.
PaymentMethodObject? object;