PaymentMethodAcssDebit class

auto generated

Constructors

PaymentMethodAcssDebit()
Instantiates a new PaymentMethodAcssDebit and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
bankName String?
Name of the bank associated with the bank account.
getter/setter pair
fingerprint String?
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
institutionNumber String?
Institution number of the bank account.
getter/setter pair
last4 String?
Last four digits of the bank account number.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transitNumber String?
Transit number of the bank account.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PaymentMethodAcssDebit
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object