fingerprint property
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
Implementation
String? fingerprint;
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
String? fingerprint;