paymentMethodDetails property
Transaction-specific details of the payment method used in the payment.
Implementation
CardGeneratedFromPaymentMethodDetails? paymentMethodDetails;
Transaction-specific details of the payment method used in the payment.
CardGeneratedFromPaymentMethodDetails? paymentMethodDetails;