PaymentMethodCardPresent class

auto generated

Constructors

PaymentMethodCardPresent()
Instantiates a new PaymentMethodCardPresent and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
brand String?
Card brand. Can be amex, cartes_bancaires, diners, discover, eftpos_au, jcb, link, mastercard, unionpay, visa or unknown.
getter/setter pair
brandProduct String?
The product code that identifies the specific program or product associated with a card.
getter/setter pair
cardholderName String?
The cardholder name as read from the card, in ISO 7813 format. May include alphanumeric characters, special characters and first/last name separator (/). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.
getter/setter pair
country String?
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.
getter/setter pair
description String?
A high-level description of the type of cards issued in this range.
getter/setter pair
expMonth int?
Two-digit number representing the card's expiration month.
getter/setter pair
expYear int?
Four-digit number representing the card's expiration year.
getter/setter pair
fingerprint String?
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.
getter/setter pair
funding String?
Card funding type. Can be credit, debit, prepaid, or unknown.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
issuer String?
The name of the card's issuing bank.
getter/setter pair
last4 String?
The last four digits of the card.
getter/setter pair
networks PaymentMethodCardPresentNetworks?
Contains information about card networks that can be used to process the payment.
getter/setter pair
offline PaymentMethodDetailsCardPresentOffline?
Details about payment methods collected offline.
getter/setter pair
preferredLocales Iterable<String>?
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card's chip.
getter/setter pair
readMethod PaymentMethodCardPresentReadMethod?
How card details were read in this transaction.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wallet PaymentFlowsPrivatePaymentMethodsCardPresentCommonWallet?
The wallet property
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PaymentMethodCardPresent
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object