networks property
Contains information about card networks that can be used to process the payment.
Implementation
PaymentMethodCardPresentNetworks? networks;
Contains information about card networks that can be used to process the payment.
PaymentMethodCardPresentNetworks? networks;