PaymentMethodCardPresentReadMethod enum

auto generated How card details were read in this transaction.

Inheritance
Available extensions

Values

contactEmv → const PaymentMethodCardPresentReadMethod
const PaymentMethodCardPresentReadMethod('contact_emv')
contactlessEmv → const PaymentMethodCardPresentReadMethod
const PaymentMethodCardPresentReadMethod('contactless_emv')
contactlessMagstripeMode → const PaymentMethodCardPresentReadMethod
const PaymentMethodCardPresentReadMethod('contactless_magstripe_mode')
magneticStripeFallback → const PaymentMethodCardPresentReadMethod
const PaymentMethodCardPresentReadMethod('magnetic_stripe_fallback')
magneticStripeTrack2 → const PaymentMethodCardPresentReadMethod
const PaymentMethodCardPresentReadMethod('magnetic_stripe_track2')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PaymentMethodCardPresentReadMethod>
A constant List of the values in this enum, in order of their declaration.