PaymentMethodCardWallet class
auto generated
Constructors
- PaymentMethodCardWallet()
- Instantiates a new PaymentMethodCardWallet and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- amexExpressCheckout ↔ PaymentMethodCardWalletAmexExpressCheckout?
-
The amex_express_checkout property
getter/setter pair
- applePay ↔ PaymentMethodCardWalletApplePay?
-
The apple_pay property
getter/setter pair
- dynamicLast4 ↔ String?
-
(For tokenized numbers only.) The last four digits of the device account number.
getter/setter pair
- googlePay ↔ PaymentMethodCardWalletGooglePay?
-
The google_pay property
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- link ↔ PaymentMethodCardWalletLink?
-
The link property
getter/setter pair
- masterpass ↔ PaymentMethodCardWalletMasterpass?
-
The masterpass property
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samsungPay ↔ PaymentMethodCardWalletSamsungPay?
-
The samsung_pay property
getter/setter pair
- type_ ↔ PaymentMethodCardWalletType?
-
The type of the card wallet, one of
amex_express_checkout,apple_pay,google_pay,masterpass,samsung_pay,visa_checkout, orlink. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.getter/setter pair - visaCheckout ↔ PaymentMethodCardWalletVisaCheckout?
-
The visa_checkout property
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → PaymentMethodCardWallet -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object