PaymentMethodCardWalletMasterpass class

auto generated

Constructors

PaymentMethodCardWalletMasterpass()
Instantiates a new PaymentMethodCardWalletMasterpass and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
billingAddress Address?
Owner's verified billing address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
getter/setter pair
email String?
Owner's verified email. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Owner's verified full name. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingAddress Address?
Owner's verified shipping address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PaymentMethodCardWalletMasterpass
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object