PaymentMethodConfigResourceDisplayPreference class

auto generated

Constructors

PaymentMethodConfigResourceDisplayPreference()
Instantiates a new PaymentMethodConfigResourceDisplayPreference and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
overridable bool?
For child configs, whether or not the account's preference will be observed. If false, the parent configuration's default is used.
getter/setter pair
preference PaymentMethodConfigResourceDisplayPreferencePreference?
The account's display preference.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value PaymentMethodConfigResourceDisplayPreferenceValue?
The effective display preference value.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PaymentMethodConfigResourceDisplayPreference
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object