createFromDiscriminatorValue static method

PaymentMethodConfiguration createFromDiscriminatorValue(
  1. ParseNode parseNode
)

Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object

Implementation

static PaymentMethodConfiguration createFromDiscriminatorValue(
    ParseNode parseNode) {
  return PaymentMethodConfiguration();
}