PaymentMethodDetailsCrypto class

auto generated

Constructors

PaymentMethodDetailsCrypto()
Instantiates a new PaymentMethodDetailsCrypto and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
buyerAddress String?
The wallet address of the customer.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
network PaymentMethodDetailsCryptoNetwork?
The blockchain network that the transaction was sent on.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenCurrency PaymentMethodDetailsCryptoTokenCurrency?
The token currency that the transaction was sent with.
getter/setter pair
transactionHash String?
The blockchain transaction hash of the crypto payment.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PaymentMethodDetailsCrypto
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object