tokenCurrency property
The token currency that the transaction was sent with.
Implementation
PaymentMethodDetailsCryptoTokenCurrency? tokenCurrency;
The token currency that the transaction was sent with.
PaymentMethodDetailsCryptoTokenCurrency? tokenCurrency;