PaymentMethodDetailsP24 class

auto generated

Constructors

PaymentMethodDetailsP24()
Instantiates a new PaymentMethodDetailsP24 and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
bank PaymentMethodDetailsP24Bank?
The customer's bank. Can be one of ing, citi_handlowy, tmobile_usbugi_bankowe, plus_bank, etransfer_pocztowy24, banki_spbdzielcze, bank_nowy_bfg_sa, getin_bank, velobank, blik, noble_pay, ideabank, envelobank, santander_przelew24, nest_przelew, mbank_mtransfer, inteligo, pbac_z_ipko, bnp_paribas, credit_agricole, toyota_bank, bank_pekao_sa, volkswagen_bank, bank_millennium, alior_bank, or boz.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
reference String?
Unique reference for this Przelewy24 payment.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verifiedName String?
Owner's verified full name. Values are verified or provided by Przelewy24 directly(if supported) at the time of authorization or settlement. They cannot be set or mutated.Przelewy24 rarely provides this information so the attribute is usually empty.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PaymentMethodDetailsP24
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object