PaymentMethodDetailsPaypal class

auto generated

Constructors

PaymentMethodDetailsPaypal()
Instantiates a new PaymentMethodDetailsPaypal and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
country String?
Two-letter ISO code representing the buyer's country. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
payerEmail String?
Owner's email. Values are provided by PayPal directly(if supported) at the time of authorization or settlement. They cannot be set or mutated.
getter/setter pair
payerId String?
PayPal account PayerID. This identifier uniquely identifies the PayPal customer.
getter/setter pair
payerName String?
Owner's full name. Values provided by PayPal directly(if supported) at the time of authorization or settlement. They cannot be set or mutated.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sellerProtection PaypalSellerProtection?
The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.
getter/setter pair
transactionId String?
A unique ID generated by PayPal for this transaction.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PaymentMethodDetailsPaypal
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object