PaymentMethodInteracPresentReadMethod enum

auto generated How card details were read in this transaction.

Inheritance
  • Object
  • Enum
  • PaymentMethodInteracPresentReadMethod
Available extensions

Values

contactEmv → const PaymentMethodInteracPresentReadMethod
const PaymentMethodInteracPresentReadMethod('contact_emv')
contactlessEmv → const PaymentMethodInteracPresentReadMethod
const PaymentMethodInteracPresentReadMethod('contactless_emv')
contactlessMagstripeMode → const PaymentMethodInteracPresentReadMethod
const PaymentMethodInteracPresentReadMethod('contactless_magstripe_mode')
magneticStripeFallback → const PaymentMethodInteracPresentReadMethod
const PaymentMethodInteracPresentReadMethod('magnetic_stripe_fallback')
magneticStripeTrack2 → const PaymentMethodInteracPresentReadMethod
const PaymentMethodInteracPresentReadMethod('magnetic_stripe_track2')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PaymentMethodInteracPresentReadMethod>
A constant List of the values in this enum, in order of their declaration.