preferredLocale property
Preferred language of the Affirm authorization page that the customer is redirected to.
Implementation
String? preferredLocale;
Preferred language of the Affirm authorization page that the customer is redirected to.
String? preferredLocale;