PaymentMethodOptionsCardMandateOptions class

auto generated

Constructors

PaymentMethodOptionsCardMandateOptions()
Instantiates a new PaymentMethodOptionsCardMandateOptions and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amount int?
Amount to be charged for future payments.
getter/setter pair
amountType PaymentMethodOptionsCardMandateOptionsAmountType?
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
getter/setter pair
description String?
A description of the mandate or subscription that is meant to be displayed to the customer.
getter/setter pair
endDate int?
End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
interval PaymentMethodOptionsCardMandateOptionsInterval?
Specifies payment frequency. One of day, week, month, year, or sporadic.
getter/setter pair
intervalCount int?
The number of intervals between payments. For example, interval=month and interval_count=3 indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when interval=sporadic.
getter/setter pair
reference String?
Unique identifier for the mandate or subscription.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate int?
Start date of the mandate or subscription. Start date should not be lesser than yesterday.
getter/setter pair
supportedTypes Iterable<PaymentMethodOptionsCardMandateOptionsSupportedTypes>?
Specifies the type of mandates supported. Possible values are india.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PaymentMethodOptionsCardMandateOptions
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object