description property
A description of the mandate or subscription that is meant to be displayed to the customer.
Implementation
String? description;
A description of the mandate or subscription that is meant to be displayed to the customer.
String? description;