captureMethod property
Controls when the funds will be captured from the customer's account.
Implementation
PaymentMethodOptionsCashappCaptureMethod? captureMethod;
Controls when the funds will be captured from the customer's account.
PaymentMethodOptionsCashappCaptureMethod? captureMethod;