PaymentMethodOptionsKonbiniSetupFutureUsage enum

auto generated Indicates that you intend to make future payments with this PaymentIntent's payment method.If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.

Inheritance
  • Object
  • Enum
  • PaymentMethodOptionsKonbiniSetupFutureUsage
Available extensions

Values

none → const PaymentMethodOptionsKonbiniSetupFutureUsage
const PaymentMethodOptionsKonbiniSetupFutureUsage('none')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PaymentMethodOptionsKonbiniSetupFutureUsage>
A constant List of the values in this enum, in order of their declaration.