captureMethod property
Controls when the funds will be captured from the customer's account.
Implementation
PaymentMethodOptionsKrCardCaptureMethod? captureMethod;
Controls when the funds will be captured from the customer's account.
PaymentMethodOptionsKrCardCaptureMethod? captureMethod;