captureMethod property
Controls when the funds will be captured from the customer's account.
Implementation
PaymentMethodOptionsSatispayCaptureMethod? captureMethod;
Controls when the funds will be captured from the customer's account.
PaymentMethodOptionsSatispayCaptureMethod? captureMethod;