PaymentPagesCheckoutSessionCustomFieldsDropdown class

auto generated

Constructors

PaymentPagesCheckoutSessionCustomFieldsDropdown()
Instantiates a new PaymentPagesCheckoutSessionCustomFieldsDropdown and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
defaultValue String?
The value that will pre-fill on the payment page.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
options Iterable<PaymentPagesCheckoutSessionCustomFieldsOption>?
The options available for the customer to select. Up to 200 options allowed.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
The option selected by the customer. This will be the value for the option.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PaymentPagesCheckoutSessionCustomFieldsDropdown
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object