PaymentPagesCheckoutSessionCustomFieldsText class
auto generated
Constructors
- PaymentPagesCheckoutSessionCustomFieldsText()
- Instantiates a new PaymentPagesCheckoutSessionCustomFieldsText and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- defaultValue ↔ String?
-
The value that will pre-fill the field on the payment page.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- maximumLength ↔ int?
-
The maximum character length constraint for the customer's input.
getter/setter pair
- minimumLength ↔ int?
-
The minimum character length requirement for the customer's input.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ String?
-
The value entered by the customer.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → PaymentPagesCheckoutSessionCustomFieldsText -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object