afterSubmit property
Custom text that should be displayed after the payment confirmation button.
Implementation
PaymentPagesCheckoutSessionCustomTextPosition? afterSubmit;
Custom text that should be displayed after the payment confirmation button.
PaymentPagesCheckoutSessionCustomTextPosition? afterSubmit;