shippingAddress property
Custom text that should be displayed alongside shipping address collection.
Implementation
PaymentPagesCheckoutSessionCustomTextPosition? shippingAddress;
Custom text that should be displayed alongside shipping address collection.
PaymentPagesCheckoutSessionCustomTextPosition? shippingAddress;