submit property
Custom text that should be displayed alongside the payment confirmation button.
Implementation
PaymentPagesCheckoutSessionCustomTextPosition? submit;
Custom text that should be displayed alongside the payment confirmation button.
PaymentPagesCheckoutSessionCustomTextPosition? submit;