termsOfServiceAcceptance property
Custom text that should be displayed in place of the default terms of service agreement text.
Implementation
PaymentPagesCheckoutSessionCustomTextPosition? termsOfServiceAcceptance;
Custom text that should be displayed in place of the default terms of service agreement text.
PaymentPagesCheckoutSessionCustomTextPosition? termsOfServiceAcceptance;