detailsSubmitted property

bool? detailsSubmitted
getter/setter pair

Whether account details have been submitted. Accounts with Stripe Dashboard access, which includes Standard accounts, cannot receive payouts before this is true. Accounts where this is false should be directed to an onboarding flow to finish submitting account details.

Implementation

bool? detailsSubmitted;