email property
An email address associated with the account. It's not used for authentication and Stripe doesn't market to this field without explicit approval from the platform.
Implementation
String? email;
An email address associated with the account. It's not used for authentication and Stripe doesn't market to this field without explicit approval from the platform.
String? email;