livemode property
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
Implementation
bool? livemode;
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
bool? livemode;