Payout class
auto generated
A Payout object is created when you receive funds from Stripe, or when youinitiate a payout to either a bank account or debit card of a connectedStripe account. You can retrieve individual payouts,and list all payouts. Payouts are made on varyingschedules, depending on your country andindustry.Related guide: Receiving payouts
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- amount ↔ int?
-
The amount (in cents (or local equivalent)) that transfers to your bank account or debit card.
getter/setter pair
- applicationFee ↔ PayoutApplicationFee?
-
The application fee (if any) for the payout. See the Connect documentation for details.
getter/setter pair
- applicationFeeAmount ↔ int?
-
The amount of the application fee (if any) requested for the payout. See the Connect documentation for details.
getter/setter pair
- arrivalDate ↔ int?
-
Date that you can expect the payout to arrive in the bank. This factors in delays to account for weekends or bank holidays.
getter/setter pair
- automatic ↔ bool?
-
Returns
trueif the payout is created by an automated payout schedule andfalseif it's requested manually.getter/setter pair - balanceTransaction ↔ PayoutBalanceTransaction?
-
ID of the balance transaction that describes the impact of this payout on your account balance.
getter/setter pair
- created ↔ int?
-
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
- currency ↔ String?
-
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
- description ↔ String?
-
An arbitrary string attached to the object. Often useful for displaying to users.
getter/setter pair
- destination ↔ PayoutDestination?
-
ID of the bank account or card the payout is sent to.
getter/setter pair
- failureBalanceTransaction ↔ PayoutFailureBalanceTransaction?
-
If the payout fails or cancels, this is the ID of the balance transaction that reverses the initial balance transaction and returns the funds from the failed payout back in your balance.
getter/setter pair
- failureCode ↔ String?
-
Error code that provides a reason for a payout failure, if available. View our list of failure codes.
getter/setter pair
- failureMessage ↔ String?
-
Message that provides the reason for a payout failure, if available.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - metadata ↔ PayoutMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- method ↔ String?
-
The method used to send this payout, which can be
standardorinstant.instantis supported for payouts to debit cards and bank accounts in certain countries. Learn more about bank support for Instant Payouts.getter/setter pair - object ↔ PayoutObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- originalPayout ↔ PayoutOriginalPayout?
-
If the payout reverses another, this is the ID of the original payout.
getter/setter pair
- payoutMethod ↔ String?
-
ID of the v2 FinancialAccount the funds are sent to.
getter/setter pair
- reconciliationStatus ↔ PayoutReconciliationStatus?
-
If
completed, you can use the Balance Transactions API to list all balance transactions that are paid out in this payout.getter/setter pair - reversedBy ↔ PayoutReversedBy?
-
If the payout reverses, this is the ID of the payout that reverses this payout.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceType ↔ String?
-
The source balance this payout came from, which can be one of the following:
card,fpx, orbank_account.getter/setter pair - statementDescriptor ↔ String?
-
Extra information about a payout that displays on the user's bank statement.
getter/setter pair
- status ↔ String?
-
Current status of the payout:
paid,pending,in_transit,canceledorfailed. A payout ispendinguntil it's submitted to the bank, when it becomesin_transit. The status changes topaidif the transaction succeeds, or tofailedorcanceled(within 5 business days). Some payouts that fail might initially show aspaid, then change tofailed.getter/setter pair - traceId ↔ PayoutsTraceId?
-
A value that generates from the beneficiary's bank that allows users to track payouts with their bank. Banks might call this a "reference number" or something similar.
getter/setter pair
- type_ ↔ PayoutType?
-
Can be
bank_accountorcard.getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → Payout -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object