arrivalDate property
Date that you can expect the payout to arrive in the bank. This factors in delays to account for weekends or bank holidays.
Implementation
int? arrivalDate;
Date that you can expect the payout to arrive in the bank. This factors in delays to account for weekends or bank holidays.
int? arrivalDate;