automatic property
Returns true if the payout is created by an automated payout schedule and false if it's requested manually.
Implementation
bool? automatic;
Returns true if the payout is created by an automated payout schedule and false if it's requested manually.
bool? automatic;