failureCode property
Error code that provides a reason for a payout failure, if available. View our list of failure codes.
Implementation
String? failureCode;
Error code that provides a reason for a payout failure, if available. View our list of failure codes.
String? failureCode;