originalPayout property
If the payout reverses another, this is the ID of the original payout.
Implementation
PayoutOriginalPayout? originalPayout;
If the payout reverses another, this is the ID of the original payout.
PayoutOriginalPayout? originalPayout;