reconciliationStatus property
If completed, you can use the Balance Transactions API to list all balance transactions that are paid out in this payout.
Implementation
PayoutReconciliationStatus? reconciliationStatus;
If completed, you can use the Balance Transactions API to list all balance transactions that are paid out in this payout.
PayoutReconciliationStatus? reconciliationStatus;