statementDescriptor property
Extra information about a payout that displays on the user's bank statement.
Implementation
String? statementDescriptor;
Extra information about a payout that displays on the user's bank statement.
String? statementDescriptor;