createFromDiscriminatorValue static method
Creates a new instance of the appropriate class based on discriminator value
parseNode The parse node to use to read the discriminator value and create the object
Implementation
static PayoutDestination createFromDiscriminatorValue(ParseNode parseNode) {
var result = PayoutDestination();
if (parseNode.getStringValue() != null) {
result.string_ = parseNode.getStringValue();
} else {
result.bankAccount = BankAccount();
result.card = Card();
result.deletedBankAccount = DeletedBankAccount();
result.deletedCard = DeletedCard();
}
return result;
}