currentlyDue property

Iterable<String>? currentlyDue
getter/setter pair

Fields that need to be resolved to keep the person's account enabled. If not resolved by the account's future_requirements[current_deadline], these fields will transition to the main requirements hash, and may immediately become past_due, but the account may also be given a grace period depending on the account's enablement state prior to transition.

Implementation

Iterable<String>? currentlyDue;