pendingVerification property

Iterable<String>? pendingVerification
getter/setter pair

Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move to eventually_due, currently_due, past_due or alternatives. Fields might appear in eventually_due, currently_due, past_due or alternatives and in pending_verification if one verification fails but another is still pending.

Implementation

Iterable<String>? pendingVerification;