PersonRelationship class

auto generated

Constructors

PersonRelationship()
Instantiates a new PersonRelationship and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
authorizer bool?
Whether the person is the authorizer of the account's representative.
getter/setter pair
director bool?
Whether the person is a director of the account's legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
getter/setter pair
executive bool?
Whether the person has significant responsibility to control, manage, or direct the organization.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
legalGuardian bool?
Whether the person is the legal guardian of the account's representative.
getter/setter pair
owner bool?
Whether the person is an owner of the account’s legal entity.
getter/setter pair
percentOwnership double?
The percent owned by the person of the account's legal entity.
getter/setter pair
representative bool?
Whether the person is authorized as the primary representative of the account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
The person's title (e.g., CEO, Support Engineer).
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PersonRelationship
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object