Plan class
auto generated You can now model subscriptions more flexibly using the Prices API. It replaces the Plans API and is backwards compatible to simplify your migration.Plans define the base price, currency, and billing cycle for recurring purchases of products.Products help you track inventory or provisioning, and plans help you track pricing. Different physical goods or levels of service should be represented by products, and pricing options should be represented by plans. This approach lets you change prices without having to change your provisioning scheme.For example, you might have a single "gold" product that has plans for $10/month, $100/year, €9/month, and €90/year.Related guides: Set up a subscription and more about products and prices.
Properties
- active ↔ bool?
-
Whether the plan can be used for new purchases.
getter/setter pair
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- amount ↔ int?
-
The unit amount in cents (or local equivalent) to be charged, represented as a whole integer if possible. Only set if
billing_scheme=per_unit.getter/setter pair - amountDecimal ↔ String?
-
The unit amount in cents (or local equivalent) to be charged, represented as a decimal string with at most 12 decimal places. Only set if
billing_scheme=per_unit.getter/setter pair - billingScheme ↔ PlanBillingScheme?
-
Describes how to compute the price per period. Either
per_unitortiered.per_unitindicates that the fixed amount (specified inamount) will be charged per unit inquantity(for plans withusage_type=licensed), or per unit of total usage (for plans withusage_type=metered).tieredindicates that the unit pricing will be computed using a tiering strategy as defined using thetiersandtiers_modeattributes.getter/setter pair - created ↔ int?
-
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
- currency ↔ String?
-
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- interval ↔ PlanInterval?
-
The frequency at which a subscription is billed. One of
day,week,monthoryear.getter/setter pair - intervalCount ↔ int?
-
The number of intervals (specified in the
intervalattribute) between subscription billings. For example,interval=monthandinterval_count=3bills every 3 months.getter/setter pair - livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - metadata ↔ PlanMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- meter ↔ String?
-
The meter tracking the usage of a metered price
getter/setter pair
- nickname ↔ String?
-
A brief description of the plan, hidden from customers.
getter/setter pair
- object ↔ PlanObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- product ↔ PlanProduct?
-
The product whose pricing this plan determines.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tiers
↔ Iterable<
PlanTier> ? -
Each element represents a pricing tier. This parameter requires
billing_schemeto be set totiered. See also the documentation forbilling_scheme.getter/setter pair - tiersMode ↔ PlanTiersMode?
-
Defines if the tiering price should be
graduatedorvolumebased. Involume-based tiering, the maximum quantity within a period determines the per unit price. Ingraduatedtiering, pricing can change as the quantity grows.getter/setter pair - transformUsage ↔ TransformUsage?
-
Apply a transformation to the reported usage or set quantity before computing the amount billed. Cannot be combined with
tiers.getter/setter pair - trialPeriodDays ↔ int?
-
Default number of trial days when subscribing a customer to this plan using
trial_from_plan=true.getter/setter pair - usageType ↔ PlanUsageType?
-
Configures how the quantity per period should be determined. Can be either
meteredorlicensed.licensedautomatically bills thequantityset when adding it to a subscription.meteredaggregates the total usage based on usage records. Defaults tolicensed.getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → Plan -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object