trialPeriodDays property
Default number of trial days when subscribing a customer to this plan using trial_from_plan=true.
Implementation
int? trialPeriodDays;
Default number of trial days when subscribing a customer to this plan using trial_from_plan=true.
int? trialPeriodDays;