models/plan_metadata library

Classes

PlanMetadata
auto generated Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.