flatAmountDecimal property
Same as flat_amount, but contains a decimal value with at most 12 decimal places.
Implementation
String? flatAmountDecimal;
Same as flat_amount, but contains a decimal value with at most 12 decimal places.
String? flatAmountDecimal;