unitAmountDecimal property
Same as unit_amount, but contains a decimal value with at most 12 decimal places.
Implementation
String? unitAmountDecimal;
Same as unit_amount, but contains a decimal value with at most 12 decimal places.
String? unitAmountDecimal;