Price class

auto generated Prices define the unit cost, currency, and (optional) billing cycle for both recurring and one-time purchases of products.Products help you track inventory or provisioning, and prices help you track payment terms. Different physical goods or levels of service should be represented by products, and pricing options should be represented by prices. This approach lets you change prices without having to change your provisioning scheme.For example, you might have a single "gold" product that has prices for $10/month, $100/year, and €9 once.Related guides: Set up a subscription, create an invoice, and more about products and prices.

Constructors

Price()
Instantiates a new Price and sets the default values.

Properties

active bool?
Whether the price can be used for new purchases.
getter/setter pair
additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
billingScheme PriceBillingScheme?
Describes how to compute the price per period. Either per_unit or tiered. per_unit indicates that the fixed amount (specified in unit_amount or unit_amount_decimal) will be charged per unit in quantity (for prices with usage_type=licensed), or per unit of total usage (for prices with usage_type=metered). tiered indicates that the unit pricing will be computed using a tiering strategy as defined using the tiers and tiers_mode attributes.
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
currencyOptions PriceCurrencyOptions?
Prices defined in each available currency option. Each key must be a three-letter ISO currency code and a supported currency.
getter/setter pair
customUnitAmount CustomUnitAmount?
When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
lookupKey String?
A lookup key used to retrieve prices dynamically from a static string. This may be up to 200 characters.
getter/setter pair
metadata PriceMetadata?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
nickname String?
A brief description of the price, hidden from customers.
getter/setter pair
object PriceObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
product PriceProduct?
The ID of the product this price is associated with.
getter/setter pair
recurring Recurring?
The recurring components of a price such as interval and usage_type.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taxBehavior PriceTaxBehavior?
Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified. Once specified as either inclusive or exclusive, it cannot be changed.
getter/setter pair
tiers Iterable<PriceTier>?
Each element represents a pricing tier. This parameter requires billing_scheme to be set to tiered. See also the documentation for billing_scheme.
getter/setter pair
tiersMode PriceTiersMode?
Defines if the tiering price should be graduated or volume based. In volume-based tiering, the maximum quantity within a period determines the per unit price. In graduated tiering, pricing can change as the quantity grows.
getter/setter pair
transformQuantity TransformQuantity?
Apply a transformation to the reported usage or set quantity before computing the amount billed. Cannot be combined with tiers.
getter/setter pair
type_ PriceType?
One of one_time or recurring depending on whether the price is for a one-time purchase or a recurring (subscription) purchase.
getter/setter pair
unitAmount int?
The unit amount in cents (or local equivalent) to be charged, represented as a whole integer if possible. Only set if billing_scheme=per_unit.
getter/setter pair
unitAmountDecimal String?
The unit amount in cents (or local equivalent) to be charged, represented as a decimal string with at most 12 decimal places. Only set if billing_scheme=per_unit.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) Price
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object