lookupKey property
A lookup key used to retrieve prices dynamically from a static string. This may be up to 200 characters.
Implementation
String? lookupKey;
A lookup key used to retrieve prices dynamically from a static string. This may be up to 200 characters.
String? lookupKey;