models/price_type library
Enums
- PriceType
-
auto generated
One of
one_timeorrecurringdepending on whether the price is for a one-time purchase or a recurring (subscription) purchase.
one_time or recurring depending on whether the price is for a one-time purchase or a recurring (subscription) purchase.