models/product_feature library

Classes

ProductFeature
auto generated A product_feature represents an attachment between a feature and a product.When a product is purchased that has a feature attached, Stripe will create an entitlement to the feature for the purchasing customer.