ProductFeature class

auto generated A product_feature represents an attachment between a feature and a product.When a product is purchased that has a feature attached, Stripe will create an entitlement to the feature for the purchasing customer.

Constructors

ProductFeature()
Instantiates a new ProductFeature and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
entitlementFeature Feature?
A feature represents a monetizable ability or functionality in your system.Features can be assigned to products, and when those products are purchased, Stripe will create an entitlement to the feature for the purchasing customer.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
object ProductFeatureObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) ProductFeature
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object