object property
String representing the object's type. Objects of the same type share the same value.
Implementation
ProductFeatureObject? object;
String representing the object's type. Objects of the same type share the same value.
ProductFeatureObject? object;