active property
Whether the promotion code is currently active. A promotion code is only active if the coupon is also valid.
Implementation
bool? active;
Whether the promotion code is currently active. A promotion code is only active if the coupon is also valid.
bool? active;