models/quote library

Classes

Quote
auto generated A Quote is a way to model prices that you'd like to provide to a customer.Once accepted, it will automatically create an invoice, subscription or subscription schedule.