Quote class

auto generated A Quote is a way to model prices that you'd like to provide to a customer.Once accepted, it will automatically create an invoice, subscription or subscription schedule.

Constructors

Quote()
Instantiates a new Quote and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amountSubtotal int?
Total before any discounts or taxes are applied.
getter/setter pair
amountTotal int?
Total after discounts and taxes are applied.
getter/setter pair
application QuoteApplication?
ID of the Connect Application that created the quote.
getter/setter pair
applicationFeeAmount int?
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. Only applicable if there are no line items with recurring prices on the quote.
getter/setter pair
applicationFeePercent double?
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. Only applicable if there are line items with recurring prices on the quote.
getter/setter pair
automaticTax QuotesResourceAutomaticTax?
The automatic_tax property
getter/setter pair
collectionMethod QuoteCollectionMethod?
Either charge_automatically, or send_invoice. When charging automatically, Stripe will attempt to pay invoices at the end of the subscription cycle or on finalization using the default payment method attached to the subscription or customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as active. Defaults to charge_automatically.
getter/setter pair
computed QuotesResourceComputed?
The computed property
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
customer QuoteCustomer?
The customer who received this quote. A customer is required to finalize the quote. Once specified, you can't change it.
getter/setter pair
customerAccount String?
The account representing the customer who received this quote. A customer or account is required to finalize the quote. Once specified, you can't change it.
getter/setter pair
defaultTaxRates Iterable<String>?
The tax rates applied to this quote.
getter/setter pair
description String?
A description that will be displayed on the quote PDF.
getter/setter pair
discounts Iterable<String>?
The discounts applied to this quote.
getter/setter pair
expiresAt int?
The date on which the quote will be canceled if in open or draft status. Measured in seconds since the Unix epoch.
getter/setter pair
A footer that will be displayed on the quote PDF.
getter/setter pair
fromQuote QuotesResourceFromQuote?
Details of the quote that was cloned. See the cloning documentation for more details.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
A header that will be displayed on the quote PDF.
getter/setter pair
id String?
Unique identifier for the object.
getter/setter pair
invoice QuoteInvoice?
The invoice that was created from this quote.
getter/setter pair
invoiceSettings InvoiceSettingQuoteSetting?
The invoice_settings property
getter/setter pair
lineItems QuoteLineItems?
A list of items the customer is being quoted for.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
metadata QuoteMetadata?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
number String?
A unique number that identifies this particular quote. This number is assigned once the quote is finalized.
getter/setter pair
object QuoteObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
onBehalfOf QuoteOnBehalfOf?
The account on behalf of which to charge. See the Connect documentation for details.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status QuoteStatus?
The status of the quote.
getter/setter pair
statusTransitions QuotesResourceStatusTransitions?
The status_transitions property
getter/setter pair
subscription QuoteSubscription?
The subscription that was created or updated from this quote.
getter/setter pair
subscriptionData QuotesResourceSubscriptionDataSubscriptionData?
The subscription_data property
getter/setter pair
subscriptionSchedule QuoteSubscriptionSchedule?
The subscription schedule that was created or updated from this quote.
getter/setter pair
testClock QuoteTestClock?
ID of the test clock this quote belongs to.
getter/setter pair
totalDetails QuotesResourceTotalDetails?
The total_details property
getter/setter pair
transferData QuotesResourceTransferData?
The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to for each of the invoices.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) Quote
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object