applicationFeeAmount property

int? applicationFeeAmount
getter/setter pair

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. Only applicable if there are no line items with recurring prices on the quote.

Implementation

int? applicationFeeAmount;