customerAccount property
The account representing the customer who received this quote. A customer or account is required to finalize the quote. Once specified, you can't change it.
Implementation
String? customerAccount;
The account representing the customer who received this quote. A customer or account is required to finalize the quote. Once specified, you can't change it.
String? customerAccount;