expiresAt property
The date on which the quote will be canceled if in open or draft status. Measured in seconds since the Unix epoch.
Implementation
int? expiresAt;
The date on which the quote will be canceled if in open or draft status. Measured in seconds since the Unix epoch.
int? expiresAt;