transferData property
The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to for each of the invoices.
Implementation
QuotesResourceTransferData? transferData;
The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to for each of the invoices.
QuotesResourceTransferData? transferData;