createFromDiscriminatorValue static method

QuoteApplication createFromDiscriminatorValue(
  1. ParseNode parseNode
)

Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object

Implementation

static QuoteApplication createFromDiscriminatorValue(ParseNode parseNode) {
  var result = QuoteApplication();
  if (parseNode.getStringValue() != null) {
    result.string_ = parseNode.getStringValue();
  } else {
    result.application = Application();
    result.deletedApplication = DeletedApplication();
  }
  return result;
}