QuotesResourceSubscriptionDataSubscriptionData class

auto generated

Constructors

QuotesResourceSubscriptionDataSubscriptionData()
Instantiates a new QuotesResourceSubscriptionDataSubscriptionData and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
billingMode QuotesResourceSubscriptionDataBillingMode?
The billing mode of the quote.
getter/setter pair
description String?
The subscription's description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
getter/setter pair
effectiveDate int?
When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. This date is ignored if it is in the past when the quote is accepted. Measured in seconds since the Unix epoch.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
metadata QuotesResourceSubscriptionDataSubscriptionDataMetadata?
Set of key-value pairs that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included in line_items, this field will be passed to the resulting subscription's metadata field. If subscription_data.effective_date is used, this field will be passed to the resulting subscription schedule's phases.metadata field. Unlike object-level metadata, this field is declarative. Updates will clear prior values.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trialPeriodDays int?
Integer representing the number of trial period days before the customer is charged for the first time.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) QuotesResourceSubscriptionDataSubscriptionData
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object