effectiveDate property

int? effectiveDate
getter/setter pair

When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. This date is ignored if it is in the past when the quote is accepted. Measured in seconds since the Unix epoch.

Implementation

int? effectiveDate;