trialPeriodDays property

int? trialPeriodDays
getter/setter pair

Integer representing the number of trial period days before the customer is charged for the first time.

Implementation

int? trialPeriodDays;