models/quotes_resource_subscription_data_subscription_data_metadata library

Classes

QuotesResourceSubscriptionDataSubscriptionDataMetadata
auto generated Set of key-value pairs that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included in line_items, this field will be passed to the resulting subscription's metadata field. If subscription_data.effective_date is used, this field will be passed to the resulting subscription schedule's phases.metadata field. Unlike object-level metadata, this field is declarative. Updates will clear prior values.