amount property

int? amount
getter/setter pair

The amount in cents (or local equivalent) that will be transferred to the destination account when the invoice is paid. By default, the entire amount is transferred to the destination.

Implementation

int? amount;