QuotesResourceUpfront class

auto generated

Constructors

QuotesResourceUpfront()
Instantiates a new QuotesResourceUpfront and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amountSubtotal int?
Total before any discounts or taxes are applied.
getter/setter pair
amountTotal int?
Total after discounts and taxes are applied.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lineItems QuotesResourceUpfrontLineItems?
The line items that will appear on the next invoice after this quote is accepted. This does not include pending invoice items that exist on the customer but may still be included in the next invoice.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalDetails QuotesResourceTotalDetails?
The total_details property
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) QuotesResourceUpfront
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object