models/quotes_resource_upfront_line_items library

Classes

QuotesResourceUpfrontLineItems
auto generated The line items that will appear on the next invoice after this quote is accepted. This does not include pending invoice items that exist on the customer but may still be included in the next invoice.