RadarRadarOptions class

auto generated Options to configure Radar. See Radar Session for more information.

Constructors

RadarRadarOptions()
Instantiates a new RadarRadarOptions and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session String?
A Radar Session is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) RadarRadarOptions
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object