RadarReviewResourceSession class

auto generated

Constructors

RadarReviewResourceSession()
Instantiates a new RadarReviewResourceSession and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
browser String?
The browser used in this browser session (e.g., Chrome).
getter/setter pair
device String?
Information about the device used for the browser session (e.g., Samsung SM-G930T).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
platform String?
The platform for the browser session (e.g., Macintosh).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String?
The version for the browser session (e.g., 61.0.3163.100).
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) RadarReviewResourceSession
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object