Refund class

auto generated Refund objects allow you to refund a previously created charge that isn'trefunded yet. Funds are refunded to the credit or debit card that'sinitially charged.Related guide: Refunds

Constructors

Refund()
Instantiates a new Refund and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amount int?
Amount, in cents (or local equivalent).
getter/setter pair
balanceTransaction RefundBalanceTransaction?
Balance transaction that describes the impact on your account balance.
getter/setter pair
charge RefundCharge?
ID of the charge that's refunded.
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
description String?
An arbitrary string attached to the object. You can use this for displaying to users (available on non-card refunds only).
getter/setter pair
destinationDetails RefundDestinationDetails?
The destination_details property
getter/setter pair
failureBalanceTransaction RefundFailureBalanceTransaction?
After the refund fails, this balance transaction describes the adjustment made on your account balance that reverses the initial balance transaction.
getter/setter pair
failureReason String?
Provides the reason for the refund failure. Possible values are: lost_or_stolen_card, expired_or_canceled_card, charge_for_pending_refund_disputed, insufficient_funds, declined, merchant_request, or unknown.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
instructionsEmail String?
For payment methods without native refund support (for example, Konbini, PromptPay), provide an email address for the customer to receive refund instructions.
getter/setter pair
metadata RefundMetadata?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
nextAction RefundNextAction?
The next_action property
getter/setter pair
object RefundObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
paymentIntent RefundPaymentIntent?
ID of the PaymentIntent that's refunded.
getter/setter pair
pendingReason RefundPendingReason?
Provides the reason for why the refund is pending. Possible values are: processing, insufficient_funds, or charge_pending.
getter/setter pair
presentmentDetails PaymentFlowsPaymentIntentPresentmentDetails?
The presentment_details property
getter/setter pair
reason RefundReason?
Reason for the refund, which is either user-provided (duplicate, fraudulent, or requested_by_customer) or generated by Stripe internally (expired_uncaptured_charge).
getter/setter pair
receiptNumber String?
This is the transaction number that appears on email receipts sent for this refund.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceTransferReversal RefundSourceTransferReversal?
The transfer reversal that's associated with the refund. Only present if the charge came from another Stripe account.
getter/setter pair
status String?
Status of the refund. This can be pending, requires_action, succeeded, failed, or canceled. Learn more about failed refunds.
getter/setter pair
transferReversal RefundTransferReversal?
This refers to the transfer reversal object if the accompanying transfer reverses. This is only applicable if the charge was created using the destination parameter.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) Refund
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object