description property
An arbitrary string attached to the object. You can use this for displaying to users (available on non-card refunds only).
Implementation
String? description;
An arbitrary string attached to the object. You can use this for displaying to users (available on non-card refunds only).
String? description;