pendingReason property
Provides the reason for why the refund is pending. Possible values are: processing, insufficient_funds, or charge_pending.
Implementation
RefundPendingReason? pendingReason;
Provides the reason for why the refund is pending. Possible values are: processing, insufficient_funds, or charge_pending.
RefundPendingReason? pendingReason;