receiptNumber property
This is the transaction number that appears on email receipts sent for this refund.
Implementation
String? receiptNumber;
This is the transaction number that appears on email receipts sent for this refund.
String? receiptNumber;