sourceTransferReversal property
The transfer reversal that's associated with the refund. Only present if the charge came from another Stripe account.
Implementation
RefundSourceTransferReversal? sourceTransferReversal;
The transfer reversal that's associated with the refund. Only present if the charge came from another Stripe account.
RefundSourceTransferReversal? sourceTransferReversal;