transferReversal property
This refers to the transfer reversal object if the accompanying transfer reverses. This is only applicable if the charge was created using the destination parameter.
Implementation
RefundTransferReversal? transferReversal;
This refers to the transfer reversal object if the accompanying transfer reverses. This is only applicable if the charge was created using the destination parameter.
RefundTransferReversal? transferReversal;