RefundReason enum

auto generated Reason for the refund, which is either user-provided (duplicate, fraudulent, or requested_by_customer) or generated by Stripe internally (expired_uncaptured_charge).

Inheritance
Available extensions

Values

duplicate → const RefundReason
const RefundReason('duplicate')
expiredUncapturedCharge → const RefundReason
const RefundReason('expired_uncaptured_charge')
fraudulent → const RefundReason
const RefundReason('fraudulent')
requestedByCustomer → const RefundReason
const RefundReason('requested_by_customer')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RefundReason>
A constant List of the values in this enum, in order of their declaration.