models/reporting/report_run library
Classes
- ReportRun
- auto generated The Report Run object represents an instance of a report type generated withspecific run parameters. Once the object is created, Stripe begins processing the report.When the report has finished running, it will give you a reference to a filewhere you can retrieve your results. For an overview, seeAPI Access to Reports.Note that certain report types can only be run based on your live-mode data (not test-modedata), and will error when queried without a live-mode API key.