ReportRun class

auto generated The Report Run object represents an instance of a report type generated withspecific run parameters. Once the object is created, Stripe begins processing the report.When the report has finished running, it will give you a reference to a filewhere you can retrieve your results. For an overview, seeAPI Access to Reports.Note that certain report types can only be run based on your live-mode data (not test-modedata), and will error when queried without a live-mode API key.

Constructors

ReportRun()
Instantiates a new ReportRun and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
error String?
If something should go wrong during the run, a message about the failure (populated when status=failed).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
livemode bool?
true if the report is run on live mode data and false if it is run on test mode data.
getter/setter pair
object ReportRunObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
parameters FinancialReportingFinanceReportRunRunParameters?
The parameters property
getter/setter pair
reportType String?
The ID of the report type to run, such as "balance.summary.1".
getter/setter pair
result File?
The file object representing the result of the report run (populated when status=succeeded).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
Status of this report run. This will be pending when the run is initially created. When the run finishes, this will be set to succeeded and the result field will be populated. Rarely, we may encounter an error, at which point this will be set to failed and the error field will be populated.
getter/setter pair
succeededAt int?
Timestamp at which this run successfully finished (populated when status=succeeded). Measured in seconds since the Unix epoch.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) ReportRun
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object