result property
The file object representing the result of the report run (populated when status=succeeded).
Implementation
File? result;
The file object representing the result of the report run (populated when status=succeeded).
File? result;