createFromDiscriminatorValue static method
Creates a new instance of the appropriate class based on discriminator value
parseNode The parse node to use to read the discriminator value and create the object
Implementation
static ReviewCharge createFromDiscriminatorValue(ParseNode parseNode) {
var result = ReviewCharge();
if (parseNode.getStringValue() != null) {
result.string_ = parseNode.getStringValue();
} else {
result.charge = Charge();
}
return result;
}