wallet property
If this Card is part of a card wallet, this contains the details of the card wallet.
Implementation
SetupAttemptPaymentMethodDetailsCardWallet? wallet;
If this Card is part of a card wallet, this contains the details of the card wallet.
SetupAttemptPaymentMethodDetailsCardWallet? wallet;