createFromDiscriminatorValue static method

SetupAttemptSetupIntent createFromDiscriminatorValue(
  1. ParseNode parseNode
)

Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object

Implementation

static SetupAttemptSetupIntent createFromDiscriminatorValue(
    ParseNode parseNode) {
  var result = SetupAttemptSetupIntent();
  if (parseNode.getStringValue() != null) {
    result.string_ = parseNode.getStringValue();
  } else {
    result.setupIntent = SetupIntent();
  }
  return result;
}