models/setup_intent library
Classes
- SetupIntent
- auto generated A SetupIntent guides you through the process of setting up and saving a customer's payment credentials for future payments.For example, you can use a SetupIntent to set up and save your customer's card without immediately collecting a payment.Later, you can use PaymentIntents to drive the payment flow.Create a SetupIntent when you're ready to collect your customer's payment credentials.Don't maintain long-lived, unconfirmed SetupIntents because they might not be valid.The SetupIntent transitions through multiple statuses as it guidesyou through the setup process.Successful SetupIntents result in payment credentials that are optimized for future payments.For example, cardholders in certain regions might need to be run throughStrong Customer Authentication during payment method collectionto streamline later off-session payments.If you use the SetupIntent with a Customer,it automatically attaches the resulting payment method to that Customer after successful setup.We recommend using SetupIntents or setup_future_usage onPaymentIntents to save payment methods to prevent saving invalid or unoptimized payment methods.By using SetupIntents, you can reduce friction for your customers, even as regulations change over time.Related guide: Setup Intents API