customer property

SetupIntentCustomer? customer
getter/setter pair

ID of the Customer this SetupIntent belongs to, if one exists.If present, the SetupIntent's payment method will be attached to the Customer on successful setup. Payment methods attached to other Customers cannot be used with this SetupIntent.

Implementation

SetupIntentCustomer? customer;