customerAccount property

String? customerAccount
getter/setter pair

ID of the Account this SetupIntent belongs to, if one exists.If present, the SetupIntent's payment method will be attached to the Account on successful setup. Payment methods attached to other Accounts cannot be used with this SetupIntent.

Implementation

String? customerAccount;