nextAction property
If present, this property tells you what actions you need to take in order for your customer to continue payment setup.
Implementation
SetupIntentNextAction? nextAction;
If present, this property tells you what actions you need to take in order for your customer to continue payment setup.
SetupIntentNextAction? nextAction;