usage property
Indicates how the payment method is intended to be used in the future.Use on_session if you intend to only reuse the payment method when the customer is in your checkout flow. Use off_session if your customer may or may not be in your checkout flow. If not provided, this value defaults to off_session.
Implementation
String? usage;