SetupIntentOnBehalfOf class
auto generated
Composed type wrapper for classes Account, String?
Methods
-
getFieldDeserializers()
→ Map<String, void Function(ParseNode)>
-
The deserialization information for the current model
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(SerializationWriter writer)
→ void
-
Serializes information the current object
writer Serialization writer to use to serialize this model
override
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
createFromDiscriminatorValue(ParseNode parseNode)
→ SetupIntentOnBehalfOf
-
Creates a new instance of the appropriate class based on discriminator value
parseNode The parse node to use to read the discriminator value and create the object