createFromDiscriminatorValue static method
Creates a new instance of the appropriate class based on discriminator value
parseNode The parse node to use to read the discriminator value and create the object
Implementation
static SetupIntentOnBehalfOf createFromDiscriminatorValue(
ParseNode parseNode) {
var result = SetupIntentOnBehalfOf();
if (parseNode.getStringValue() != null) {
result.string_ = parseNode.getStringValue();
} else {
result.account = Account();
}
return result;
}