SetupIntentPaymentMethodOptionsCard class

auto generated

Constructors

SetupIntentPaymentMethodOptionsCard()
Instantiates a new SetupIntentPaymentMethodOptionsCard and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
mandateOptions SetupIntentPaymentMethodOptionsCardMandateOptions?
Configuration options for setting up an eMandate for cards issued in India.
getter/setter pair
network SetupIntentPaymentMethodOptionsCardNetwork?
Selected network to process this SetupIntent on. Depends on the available networks of the card attached to the setup intent. Can be only set confirm-time.
getter/setter pair
requestThreeDSecure SetupIntentPaymentMethodOptionsCardRequestThreeDSecure?
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to automatic. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) SetupIntentPaymentMethodOptionsCard
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object