SetupIntentStatus enum

auto generated Status of this SetupIntent, one of requires_payment_method, requires_confirmation, requires_action, processing, canceled, or succeeded.

Inheritance
Available extensions

Values

canceled → const SetupIntentStatus
const SetupIntentStatus('canceled')
processing → const SetupIntentStatus
const SetupIntentStatus('processing')
requiresAction → const SetupIntentStatus
const SetupIntentStatus('requires_action')
requiresConfirmation → const SetupIntentStatus
const SetupIntentStatus('requires_confirmation')
requiresPaymentMethod → const SetupIntentStatus
const SetupIntentStatus('requires_payment_method')
succeeded → const SetupIntentStatus
const SetupIntentStatus('succeeded')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SetupIntentStatus>
A constant List of the values in this enum, in order of their declaration.