ShippingRateFixedAmount class

auto generated

Constructors

ShippingRateFixedAmount()
Instantiates a new ShippingRateFixedAmount and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amount int?
A non-negative integer in cents representing how much to charge.
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
currencyOptions ShippingRateFixedAmountCurrencyOptions?
Shipping rates defined in each available currency option. Each key must be a three-letter ISO currency code and a supported currency.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) ShippingRateFixedAmount
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object