attemptsRemaining property
The number of attempts remaining to authenticate the source object with a verification code.
Implementation
int? attemptsRemaining;
The number of attempts remaining to authenticate the source object with a verification code.
int? attemptsRemaining;