SourceOrder class

auto generated

Constructors

SourceOrder()
Instantiates a new SourceOrder and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amount int?
A positive integer in the smallest currency unit (that is, 100 cents for $1.00, or 1 for ¥1, Japanese Yen being a zero-decimal currency) representing the total amount for the order.
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
email String?
The email address of the customer placing the order.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
items Iterable<SourceOrderItem>?
List of items constituting the order.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shipping Shipping?
The shipping property
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) SourceOrder
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object