SourceOrderItem class

auto generated

Constructors

SourceOrderItem()
Instantiates a new SourceOrderItem and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amount int?
The amount (price) for this order item.
getter/setter pair
currency String?
This currency of this order item. Required when amount is present.
getter/setter pair
description String?
Human-readable description for this order item.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
parent String?
The ID of the associated object for this line item. Expandable if not null (e.g., expandable to a SKU).
getter/setter pair
quantity int?
The quantity of this order item. When type is sku, this is the number of instances of the SKU to be ordered.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type_ String?
The type of this order item. Must be sku, tax, or shipping.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) SourceOrderItem
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object