parent property
The ID of the associated object for this line item. Expandable if not null (e.g., expandable to a SKU).
Implementation
String? parent;
The ID of the associated object for this line item. Expandable if not null (e.g., expandable to a SKU).
String? parent;