SourceReceiverFlow class

auto generated

Constructors

SourceReceiverFlow()
Instantiates a new SourceReceiverFlow and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
address String?
The address of the receiver source. This is the value that should be communicated to the customer to send their funds to.
getter/setter pair
amountCharged int?
The total amount that was moved to your balance. This is almost always equal to the amount charged. In rare cases when customers deposit excess funds and we are unable to refund those, those funds get moved to your balance and show up in amount_charged as well. The amount charged is expressed in the source's currency.
getter/setter pair
amountReceived int?
The total amount received by the receiver source. amount_received = amount_returned + amount_charged should be true for consumed sources unless customers deposit excess funds. The amount received is expressed in the source's currency.
getter/setter pair
amountReturned int?
The total amount that was returned to the customer. The amount returned is expressed in the source's currency.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
refundAttributesMethod String?
Type of refund attribute method, one of email, manual, or none.
getter/setter pair
refundAttributesStatus String?
Type of refund attribute status, one of missing, requested, or available.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) SourceReceiverFlow
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object