address property
The address of the receiver source. This is the value that should be communicated to the customer to send their funds to.
Implementation
String? address;
The address of the receiver source. This is the value that should be communicated to the customer to send their funds to.
String? address;