models/source_transaction library

Classes

SourceTransaction
auto generated Some payment methods have no required amount that a customer must send.Customers can be instructed to send any amount, and it can be made up ofmultiple transactions. As such, sources can have multiple associatedtransactions.