SubscriptionBillingThresholds class
auto generated
Constructors
- SubscriptionBillingThresholds()
- Instantiates a new SubscriptionBillingThresholds and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- amountGte ↔ int?
-
Monetary threshold that triggers the subscription to create an invoice
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- resetBillingCycleAnchor ↔ bool?
-
Indicates if the
billing_cycle_anchorshould be reset when a threshold is reached. If true,billing_cycle_anchorwill be updated to the date/time the threshold was last reached; otherwise, the value will remain unchanged. This value may not betrueif the subscription contains items with plans that haveaggregate_usage=last_ever.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → SubscriptionBillingThresholds -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object