billingThresholds property
Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period
Implementation
SubscriptionItemBillingThresholds? billingThresholds;
Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period
SubscriptionItemBillingThresholds? billingThresholds;