SubscriptionPendingInvoiceItemInterval class

auto generated

Constructors

SubscriptionPendingInvoiceItemInterval()
Instantiates a new SubscriptionPendingInvoiceItemInterval and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
interval SubscriptionPendingInvoiceItemIntervalInterval?
Specifies invoicing frequency. Either day, week, month or year.
getter/setter pair
intervalCount int?
The number of intervals between invoices. For example, interval=month and interval_count=3 bills every 3 months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) SubscriptionPendingInvoiceItemInterval
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object