SubscriptionSchedule class

auto generated A subscription schedule allows you to create and manage the lifecycle of a subscription by predefining expected changes.Related guide: Subscription schedules

Constructors

SubscriptionSchedule()
Instantiates a new SubscriptionSchedule and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
application SubscriptionScheduleApplication?
ID of the Connect Application that created the schedule.
getter/setter pair
billingMode SubscriptionsResourceBillingMode?
The billing mode of the subscription.
getter/setter pair
canceledAt int?
Time at which the subscription schedule was canceled. Measured in seconds since the Unix epoch.
getter/setter pair
completedAt int?
Time at which the subscription schedule was completed. Measured in seconds since the Unix epoch.
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
currentPhase SubscriptionScheduleCurrentPhase?
Object representing the start and end dates for the current phase of the subscription schedule, if it is active.
getter/setter pair
customer SubscriptionScheduleCustomer?
ID of the customer who owns the subscription schedule.
getter/setter pair
customerAccount String?
ID of the account who owns the subscription schedule.
getter/setter pair
defaultSettings SubscriptionSchedulesResourceDefaultSettings?
The default_settings property
getter/setter pair
endBehavior SubscriptionScheduleEndBehavior?
Behavior of the subscription schedule and underlying subscription when it ends. Possible values are release or cancel with the default being release. release will end the subscription schedule and keep the underlying subscription running. cancel will end the subscription schedule and cancel the underlying subscription.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
metadata SubscriptionScheduleMetadata?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
object SubscriptionScheduleObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
phases Iterable<SubscriptionSchedulePhaseConfiguration>?
Configuration for the subscription schedule's phases.
getter/setter pair
releasedAt int?
Time at which the subscription schedule was released. Measured in seconds since the Unix epoch.
getter/setter pair
releasedSubscription String?
ID of the subscription once managed by the subscription schedule (if it is released).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status SubscriptionScheduleStatus?
The present status of the subscription schedule. Possible values are not_started, active, completed, released, and canceled. You can read more about the different states in our behavior guide.
getter/setter pair
subscription SubscriptionScheduleSubscription?
ID of the subscription managed by the subscription schedule.
getter/setter pair
testClock SubscriptionScheduleTestClock?
ID of the test clock this subscription schedule belongs to.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) SubscriptionSchedule
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object