currentPhase property
Object representing the start and end dates for the current phase of the subscription schedule, if it is active.
Implementation
SubscriptionScheduleCurrentPhase? currentPhase;
Object representing the start and end dates for the current phase of the subscription schedule, if it is active.
SubscriptionScheduleCurrentPhase? currentPhase;