releasedSubscription property
ID of the subscription once managed by the subscription schedule (if it is released).
Implementation
String? releasedSubscription;
ID of the subscription once managed by the subscription schedule (if it is released).
String? releasedSubscription;