SubscriptionScheduleEndBehavior enum

auto generated Behavior of the subscription schedule and underlying subscription when it ends. Possible values are release or cancel with the default being release. release will end the subscription schedule and keep the underlying subscription running. cancel will end the subscription schedule and cancel the underlying subscription.

Inheritance
Available extensions

Values

cancel → const SubscriptionScheduleEndBehavior
const SubscriptionScheduleEndBehavior('cancel')
none → const SubscriptionScheduleEndBehavior
const SubscriptionScheduleEndBehavior('none')
release → const SubscriptionScheduleEndBehavior
const SubscriptionScheduleEndBehavior('release')
renew → const SubscriptionScheduleEndBehavior
const SubscriptionScheduleEndBehavior('renew')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SubscriptionScheduleEndBehavior>
A constant List of the values in this enum, in order of their declaration.