models/subscription_schedule_phase_configuration_metadata library

Classes

SubscriptionSchedulePhaseConfigurationMetadata
auto generated Set of key-value pairs that you can attach to a phase. Metadata on a schedule's phase will update the underlying subscription's metadata when the phase is entered. Updating the underlying subscription's metadata directly will not affect the current phase's metadata.