SubscriptionSchedulesResourceDefaultSettingsCollectionMethod enum

auto generated Either charge_automatically, or send_invoice. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as active.

Inheritance
  • Object
  • Enum
  • SubscriptionSchedulesResourceDefaultSettingsCollectionMethod
Available extensions

Values

chargeAutomatically → const SubscriptionSchedulesResourceDefaultSettingsCollectionMethod
const SubscriptionSchedulesResourceDefaultSettingsCollectionMethod('charge_automatically')
sendInvoice → const SubscriptionSchedulesResourceDefaultSettingsCollectionMethod
const SubscriptionSchedulesResourceDefaultSettingsCollectionMethod('send_invoice')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SubscriptionSchedulesResourceDefaultSettingsCollectionMethod>
A constant List of the values in this enum, in order of their declaration.