SubscriptionStatus enum

auto generated Possible values are incomplete, incomplete_expired, trialing, active, past_due, canceled, unpaid, or paused. For collection_method=charge_automatically a subscription moves into incomplete if the initial payment attempt fails. A subscription in this status can only have metadata and default_source updated. Once the first invoice is paid, the subscription moves into an active status. If the first invoice is not paid within 23 hours, the subscription transitions to incomplete_expired. This is a terminal status, the open invoice will be voided and no further invoices will be generated. A subscription that is currently in a trial period is trialing and moves to active when the trial period is over. A subscription can only enter a paused status when a trial ends without a payment method. A paused subscription doesn't generate invoices and can be resumed after your customer adds their payment method. The paused status is different from pausing collection, which still generates invoices and leaves the subscription's status unchanged. If subscription collection_method=charge_automatically, it becomes past_due when payment is required but cannot be paid (due to failed payment or awaiting additional user actions). Once Stripe has exhausted all payment retry attempts, the subscription will become canceled or unpaid (depending on your subscriptions settings). If subscription collection_method=send_invoice it becomes past_due when its invoice is not paid by the due date, and canceled or unpaid if it is still not paid by an additional deadline after that. Note that when a subscription has a status of unpaid, no subsequent invoices will be attempted (invoices will be created, but then immediately automatically closed). After receiving updated payment information from a customer, you may choose to reopen and pay their closed invoices.

Inheritance
Available extensions

Values

active → const SubscriptionStatus
const SubscriptionStatus('active')
canceled → const SubscriptionStatus
const SubscriptionStatus('canceled')
incomplete → const SubscriptionStatus
const SubscriptionStatus('incomplete')
incompleteExpired → const SubscriptionStatus
const SubscriptionStatus('incomplete_expired')
pastDue → const SubscriptionStatus
const SubscriptionStatus('past_due')
paused → const SubscriptionStatus
const SubscriptionStatus('paused')
trialing → const SubscriptionStatus
const SubscriptionStatus('trialing')
unpaid → const SubscriptionStatus
const SubscriptionStatus('unpaid')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SubscriptionStatus>
A constant List of the values in this enum, in order of their declaration.