models/subscriptions_resource_pending_update library

Classes

SubscriptionsResourcePendingUpdate
auto generated Pending Updates store the changes pending from a previous update that will be appliedto the Subscription upon successful payment.