expiresAt property
The point after which the changes reflected by this update will be discarded and no longer applied.
Implementation
int? expiresAt;
The point after which the changes reflected by this update will be discarded and no longer applied.
int? expiresAt;