subscriptionItems property

Iterable<SubscriptionItem>? subscriptionItems
getter/setter pair

List of subscription items, each with an attached plan, that will be set if the update is applied.

Implementation

Iterable<SubscriptionItem>? subscriptionItems;