trialEnd property

int? trialEnd
getter/setter pair

Unix timestamp representing the end of the trial period the customer will get before being charged for the first time, if the update is applied.

Implementation

int? trialEnd;