Association class
auto generated A Tax Association exposes the Tax Transactions that Stripe attempted to create on your behalf based on the PaymentIntent input
Constructors
- Association()
- Instantiates a new Association and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- calculation ↔ String?
-
The Tax Calculation that was included in PaymentIntent.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- object ↔ AssociationObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- paymentIntent ↔ String?
-
The PaymentIntent that this Tax Association is tracking.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
taxTransactionAttempts
↔ Iterable<
TaxProductResourceTaxAssociationTransactionAttempts> ? -
Information about the tax transactions linked to this payment intent
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → Association -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object