Calculation class

auto generated A Tax Calculation allows you to calculate the tax to collect from your customer.Related guide: Calculate tax in your custom payment flow

Constructors

Calculation()
Instantiates a new Calculation and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amountTotal int?
Total amount after taxes in the smallest currency unit.
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
customer String?
The ID of an existing Customer used for the resource.
getter/setter pair
customerDetails TaxProductResourceCustomerDetails?
The customer_details property
getter/setter pair
expiresAt int?
Timestamp of date at which the tax calculation will expire.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the calculation.
getter/setter pair
lineItems CalculationLineItems?
The list of items the customer is purchasing.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
object CalculationObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shipFromDetails TaxProductResourceShipFromDetails?
The details of the ship from location, such as the address.
getter/setter pair
shippingCost TaxProductResourceTaxCalculationShippingCost?
The shipping cost details for the calculation.
getter/setter pair
taxAmountExclusive int?
The amount of tax to be collected on top of the line item prices.
getter/setter pair
taxAmountInclusive int?
The amount of tax already included in the line item prices.
getter/setter pair
taxBreakdown Iterable<TaxProductResourceTaxBreakdown>?
Breakdown of individual tax amounts that add up to the total.
getter/setter pair
taxDate int?
Timestamp of date at which the tax rules and rates in effect applies for the calculation.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) Calculation
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object