models/tax_id library

Classes

TaxId
auto generated You can add one or multiple tax IDs to a customer or account.Customer and account tax IDs get displayed on related invoices and credit notes.Related guides: Customer tax identification numbers, Account tax IDs