TaxRate class

auto generated Tax rates can be applied to invoices, subscriptions and Checkout Sessions to collect tax.Related guide: Tax rates

Constructors

TaxRate()
Instantiates a new TaxRate and sets the default values.

Properties

active bool?
Defaults to true. When set to false, this tax rate cannot be used with new applications or Checkout Sessions, but will still work for subscriptions and invoices that already have it set.
getter/setter pair
additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
country String?
Two-letter country code (ISO 3166-1 alpha-2).
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
description String?
An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.
getter/setter pair
displayName String?
The display name of the tax rates as it will appear to your customer on their receipt email, PDF, and the hosted invoice page.
getter/setter pair
effectivePercentage double?
Actual/effective tax rate percentage out of 100. For tax calculations with automatic_taxenabled=true,this percentage reflects the rate actually used to calculate tax based on the product's taxabilityand whether the user is registered to collect taxes in the corresponding jurisdiction.
getter/setter pair
flatAmount TaxRateFlatAmount?
The amount of the tax rate when the rate_type is flat_amount. Tax rates with rate_type percentage can vary based on the transaction, resulting in this field being null. This field exposes the amount and currency of the flat tax rate.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
inclusive bool?
This specifies if the tax rate is inclusive or exclusive.
getter/setter pair
jurisdiction String?
The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.
getter/setter pair
jurisdictionLevel TaxRateJurisdictionLevel?
The level of the jurisdiction that imposes this tax rate. Will be null for manually defined tax rates.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
metadata TaxRateMetadata?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
object TaxRateObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
percentage double?
Tax rate percentage out of 100. For tax calculations with automatic_taxenabled=true, this percentage includes the statutory tax rate of non-taxable jurisdictions.
getter/setter pair
rateType TaxRateRateType?
Indicates the type of tax rate applied to the taxable amount. This value can be null when no tax applies to the location. This field is only present for TaxRates created by Stripe Tax.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
ISO 3166-2 subdivision code, without country prefix. For example, "NY" for New York, United States.
getter/setter pair
taxType TaxRateTaxType?
The high-level tax type, such as vat or sales_tax.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) TaxRate
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object