description property
An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.
Implementation
String? description;
An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.
String? description;