models/tax_rate_flat_amount library

Classes

TaxRateFlatAmount
auto generated The amount of the tax rate when the rate_type`` is flat_amount. Tax rates with rate_type percentagecan vary based on the transaction, resulting in this field beingnull`. This field exposes the amount and currency of the flat tax rate.