TaxRateFlatAmount class

auto generated The amount of the tax rate when the rate_type`` is flat_amount. Tax rates with rate_type percentagecan vary based on the transaction, resulting in this field beingnull`. This field exposes the amount and currency of the flat tax rate.

Constructors

TaxRateFlatAmount()
Instantiates a new TaxRateFlatAmount and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amount int?
Amount of the tax when the rate_type is flat_amount. This positive integer represents how much to charge in the smallest currency unit (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) TaxRateFlatAmount
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object