models/tax/registration library

Classes

Registration
auto generated A Tax Registration lets us know that your business is registered to collect tax on payments within a region, enabling you to automatically collect tax.Stripe doesn't register on your behalf with the relevant authorities when you create a Tax Registration object. For more information on how to register to collect tax, see our guide.Related guide: Using the Registrations API