Registration class

auto generated A Tax Registration lets us know that your business is registered to collect tax on payments within a region, enabling you to automatically collect tax.Stripe doesn't register on your behalf with the relevant authorities when you create a Tax Registration object. For more information on how to register to collect tax, see our guide.Related guide: Using the Registrations API

Constructors

Registration()
Instantiates a new Registration and sets the default values.

Properties

activeFrom int?
Time at which the registration becomes active. Measured in seconds since the Unix epoch.
getter/setter pair
additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
country String?
Two-letter country code (ISO 3166-1 alpha-2).
getter/setter pair
countryOptions TaxProductRegistrationsResourceCountryOptions?
The country_options property
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
expiresAt int?
If set, the registration stops being active at this time. If not set, the registration will be active indefinitely. Measured in seconds since the Unix epoch.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
object RegistrationObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status RegistrationStatus?
The status of the registration. This field is present for convenience and can be deduced from active_from and expires_at.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) Registration
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object