RegistrationStatus enum

auto generated The status of the registration. This field is present for convenience and can be deduced from active_from and expires_at.

Inheritance
Available extensions

Values

active → const RegistrationStatus
const RegistrationStatus('active')
expired → const RegistrationStatus
const RegistrationStatus('expired')
scheduled → const RegistrationStatus
const RegistrationStatus('scheduled')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RegistrationStatus>
A constant List of the values in this enum, in order of their declaration.