Transaction class

auto generated A Tax Transaction records the tax collected from or refunded to your customer.Related guide: Calculate tax in your custom payment flow

Constructors

Transaction()
Instantiates a new Transaction and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
customer String?
The ID of an existing Customer used for the resource.
getter/setter pair
customerDetails TaxProductResourceCustomerDetails?
The customer_details property
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the transaction.
getter/setter pair
lineItems TransactionLineItems?
The tax collected or refunded, by line item.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
metadata TransactionMetadata?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
object TransactionObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
postedAt int?
The Unix timestamp representing when the tax liability is assumed or reduced.
getter/setter pair
reference String?
A custom unique identifier, such as 'myOrder_123'.
getter/setter pair
reversal TaxProductResourceTaxTransactionResourceReversal?
If type=reversal, contains information about what was reversed.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shipFromDetails TaxProductResourceShipFromDetails?
The details of the ship from location, such as the address.
getter/setter pair
shippingCost TaxProductResourceTaxTransactionShippingCost?
The shipping cost details for the transaction.
getter/setter pair
taxDate int?
Timestamp of date at which the tax rules and rates in effect applies for the calculation.
getter/setter pair
type_ TransactionType?
If reversal, this transaction reverses an earlier transaction.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) Transaction
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object