object property
String representing the object's type. Objects of the same type share the same value. Always has the value list.
Implementation
TransactionLineItemsObject? object;
String representing the object's type. Objects of the same type share the same value. Always has the value list.
TransactionLineItemsObject? object;