location property

String? location
getter/setter pair

The id of the location that this connection token is scoped to. Note that location scoping only applies to internet-connected readers. For more details, see the docs on scoping connection tokens.

Implementation

String? location;