configurationOverrides property
The ID of a configuration that will be used to customize all readers in this location.
Implementation
String? configurationOverrides;
The ID of a configuration that will be used to customize all readers in this location.
String? configurationOverrides;