status property
The networking status of the reader. We do not recommend using this field in flows that may block taking payments.
Implementation
ReaderStatus? status;
The networking status of the reader. We do not recommend using this field in flows that may block taking payments.
ReaderStatus? status;