TerminalReaderReaderResourceChoice class

auto generated Choice to be selected on a Reader

Constructors

TerminalReaderReaderResourceChoice()
Instantiates a new TerminalReaderReaderResourceChoice and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
id String?
The identifier for the selected choice. Maximum 50 characters.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TerminalReaderReaderResourceChoiceStyle?
The button style for the choice. Can be primary or secondary.
getter/setter pair
text String?
The text to be selected. Maximum 30 characters.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) TerminalReaderReaderResourceChoice
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object