TerminalReaderReaderResourceProcessConfig class
auto generated Represents a per-transaction override of a reader configuration
Constructors
- TerminalReaderReaderResourceProcessConfig()
- Instantiates a new TerminalReaderReaderResourceProcessConfig and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- enableCustomerCancellation ↔ bool?
-
Enable customer-initiated cancellation when processing this payment.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- returnUrl ↔ String?
-
If the customer doesn't abandon authenticating the payment, they're redirected to this URL after completion.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipTipping ↔ bool?
-
Override showing a tipping selection screen on this transaction.
getter/setter pair
- tipping ↔ TerminalReaderReaderResourceTippingConfig?
-
Represents a per-transaction tipping configuration
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → TerminalReaderReaderResourceProcessConfig -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object