collectPaymentMethod property
Represents a reader action to collect a payment method
Implementation
TerminalReaderReaderResourceCollectPaymentMethodAction? collectPaymentMethod;
Represents a reader action to collect a payment method
TerminalReaderReaderResourceCollectPaymentMethodAction? collectPaymentMethod;