setReaderDisplay property
Represents a reader action to set the reader display
Implementation
TerminalReaderReaderResourceSetReaderDisplayAction? setReaderDisplay;
Represents a reader action to set the reader display
TerminalReaderReaderResourceSetReaderDisplayAction? setReaderDisplay;