models/token library

Classes

Token
auto generated Tokenization is the process Stripe uses to collect sensitive card or bankaccount details, or personally identifiable information (PII), directly fromyour customers in a secure manner. A token representing this information isreturned to your server to use. Use ourrecommended payments integrations to perform this processon the client-side. This guarantees that no sensitive card data touches your server,and allows your integration to operate in a PCI-compliant way.If you can't use client-side tokenization, you can also create tokens usingthe API with either your publishable or secret API key. Ifyour integration uses this method, you're responsible for any PCI compliancethat it might require, and you must keep your secret API key safe. Unlike withclient-side tokenization, your customer's information isn't sent directly toStripe, so we can't determine how it's handled or stored.You can't store or use tokens more than once. To store card or bank accountinformation for later use, create Customerobjects or External accounts.Radar, our integrated solution for automatic fraud protection,performs best with integrations that use client-side tokenization.