Token class

auto generated Tokenization is the process Stripe uses to collect sensitive card or bankaccount details, or personally identifiable information (PII), directly fromyour customers in a secure manner. A token representing this information isreturned to your server to use. Use ourrecommended payments integrations to perform this processon the client-side. This guarantees that no sensitive card data touches your server,and allows your integration to operate in a PCI-compliant way.If you can't use client-side tokenization, you can also create tokens usingthe API with either your publishable or secret API key. Ifyour integration uses this method, you're responsible for any PCI compliancethat it might require, and you must keep your secret API key safe. Unlike withclient-side tokenization, your customer's information isn't sent directly toStripe, so we can't determine how it's handled or stored.You can't store or use tokens more than once. To store card or bank accountinformation for later use, create Customerobjects or External accounts.Radar, our integrated solution for automatic fraud protection,performs best with integrations that use client-side tokenization.

Constructors

Token()
Instantiates a new Token and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
bankAccount BankAccount?
These bank accounts are payment methods on Customer objects.On the other hand External Accounts are transferdestinations on Account objects for connected accounts.They can be bank accounts or debit cards as well, and are documented in the links above.Related guide: Bank debits and transfers
getter/setter pair
card Card?
You can store multiple cards on a customer in order to charge the customerlater. You can also store multiple debit cards on a recipient in order totransfer to those cards later.Related guide: Card payments with Sources
getter/setter pair
clientIp String?
IP address of the client that generates the token.
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
object TokenObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type_ String?
Type of the token: account, bank_account, card, or pii.
getter/setter pair
used bool?
Determines if you have already used this token (you can only use tokens once).
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) Token
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object