card property

Card? card
getter/setter pair

You can store multiple cards on a customer in order to charge the customerlater. You can also store multiple debit cards on a recipient in order totransfer to those cards later.Related guide: Card payments with Sources

Implementation

Card? card;