failureCode property
Error code explaining reason for top-up failure if available (see the errors section for a list of codes).
Implementation
String? failureCode;
Error code explaining reason for top-up failure if available (see the errors section for a list of codes).
String? failureCode;