Transfer class

auto generated A Transfer object is created when you move funds between Stripe accounts aspart of Connect.Before April 6, 2017, transfers also represented movement of funds from aStripe account to a card or bank account. This behavior has since been splitout into a Payout object, with corresponding payout endpoints. For moreinformation, read about thetransfer/payout split.Related guide: Creating separate charges and transfers

Constructors

Transfer()
Instantiates a new Transfer and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amount int?
Amount in cents (or local equivalent) to be transferred.
getter/setter pair
amountReversed int?
Amount in cents (or local equivalent) reversed (can be less than the amount attribute on the transfer if a partial reversal was issued).
getter/setter pair
balanceTransaction TransferBalanceTransaction?
Balance transaction that describes the impact of this transfer on your account balance.
getter/setter pair
created int?
Time that this record of the transfer was first created.
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
description String?
An arbitrary string attached to the object. Often useful for displaying to users.
getter/setter pair
destination TransferDestination?
ID of the Stripe account the transfer was sent to.
getter/setter pair
destinationPayment TransferDestinationPayment?
If the destination is a Stripe account, this will be the ID of the payment that the destination account received for the transfer.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
metadata TransferMetadata?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
object TransferObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
reversals TransferReversals?
A list of reversals that have been applied to the transfer.
getter/setter pair
reversed bool?
Whether the transfer has been fully reversed. If the transfer is only partially reversed, this attribute will still be false.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceTransaction TransferSourceTransaction?
ID of the charge that was used to fund the transfer. If null, the transfer was funded from the available balance.
getter/setter pair
sourceType String?
The source balance this transfer came from. One of card, fpx, or bank_account.
getter/setter pair
transferGroup String?
A string that identifies this transaction as part of a group. See the Connect documentation for details.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) Transfer
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object