Transfer constructor
Transfer()
Instantiates a new Transfer and sets the default values.
Implementation
Transfer() : additionalData = {};
Instantiates a new Transfer and sets the default values.
Transfer() : additionalData = {};