reversed property
Whether the transfer has been fully reversed. If the transfer is only partially reversed, this attribute will still be false.
Implementation
bool? reversed;
Whether the transfer has been fully reversed. If the transfer is only partially reversed, this attribute will still be false.
bool? reversed;