models/transfer_reversal library
Classes
- TransferReversal
- auto generated Stripe Connect platforms can reverse transfers made to aconnected account, either entirely or partially, and can also specify whetherto refund any related application fees. Transfer reversals add to theplatform's balance and subtract from the destination account's balance.Reversing a transfer that was made for a destinationcharge is allowed only up to the amount ofthe charge. It is possible to reverse atransfer_grouptransfer only if the destination account has enough balance to cover thereversal.Related guide: Reverse transfers