TransferReversalSourceRefund class
auto generated
Composed type wrapper for classes Refund, String?
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
refund
↔ Refund?
-
Composed type representation for type Refund
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
string_
↔ String?
-
Composed type representation for type String?
getter/setter pair
Methods
-
getFieldDeserializers()
→ Map<String, void Function(ParseNode)>
-
The deserialization information for the current model
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(SerializationWriter writer)
→ void
-
Serializes information the current object
writer Serialization writer to use to serialize this model
override
-
toString()
→ String
-
A string representation of this object.
inherited