models/treasury/outbound_transfer library
Classes
- OutboundTransfer
-
auto generated
Use OutboundTransfers to transfer funds from a FinancialAccount to a PaymentMethod belonging to the same entity. To send funds to a different party, use OutboundPayments instead. You can send funds over ACH rails or through a domestic wire transfer to a user's own external bank account.Simulate OutboundTransfer state changes with the
/v1/test_helpers/treasury/outbound_transfersendpoints. These methods can only be called on test mode objects.Related guide: Moving money with Treasury using OutboundTransfer objects