destinationPaymentMethod property
The PaymentMethod used as the payment instrument for an OutboundTransfer.
Implementation
String? destinationPaymentMethod;
The PaymentMethod used as the payment instrument for an OutboundTransfer.
String? destinationPaymentMethod;