OutboundTransferStatus enum
auto generated
Current status of the OutboundTransfer: processing, failed, canceled, posted, returned. An OutboundTransfer is processing if it has been created and is pending. The status changes to posted once the OutboundTransfer has been "confirmed" and funds have left the account, or to failed or canceled. If an OutboundTransfer fails to arrive at its destination, its status will change to returned.
Values
- canceled → const OutboundTransferStatus
-
const OutboundTransferStatus('canceled') - failed → const OutboundTransferStatus
-
const OutboundTransferStatus('failed') - posted → const OutboundTransferStatus
-
const OutboundTransferStatus('posted') - processing → const OutboundTransferStatus
-
const OutboundTransferStatus('processing') - returned → const OutboundTransferStatus
-
const OutboundTransferStatus('returned')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
OutboundTransferStatus> - A constant List of the values in this enum, in order of their declaration.