TreasuryReceivedDebitsResourceLinkedFlows class

auto generated

Constructors

TreasuryReceivedDebitsResourceLinkedFlows()
Instantiates a new TreasuryReceivedDebitsResourceLinkedFlows and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
debitReversal String?
The DebitReversal created as a result of this ReceivedDebit being reversed.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inboundTransfer String?
Set if the ReceivedDebit is associated with an InboundTransfer's return of funds.
getter/setter pair
issuingAuthorization String?
Set if the ReceivedDebit was created due to an Issuing Authorization object.
getter/setter pair
issuingTransaction String?
Set if the ReceivedDebit is also viewable as an Issuing Dispute object.
getter/setter pair
payout String?
Set if the ReceivedDebit was created due to a Payout object.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) TreasuryReceivedDebitsResourceLinkedFlows
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object