Transaction class
auto generated Transactions represent changes to a FinancialAccount's balance.
Constructors
- Transaction()
- Instantiates a new Transaction and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- amount ↔ int?
-
Amount (in cents) transferred.
getter/setter pair
- balanceImpact ↔ TreasuryTransactionsResourceBalanceImpact?
-
Change to a FinancialAccount's balance
getter/setter pair
- created ↔ int?
-
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
- currency ↔ String?
-
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
- description ↔ String?
-
An arbitrary string attached to the object. Often useful for displaying to users.
getter/setter pair
- entries ↔ TransactionEntries?
-
A list of TransactionEntries that are part of this Transaction. This cannot be expanded in any list endpoints.
getter/setter pair
- financialAccount ↔ String?
-
The FinancialAccount associated with this object.
getter/setter pair
- flow ↔ String?
-
ID of the flow that created the Transaction.
getter/setter pair
- flowDetails ↔ TreasuryTransactionsResourceFlowDetails?
-
Details of the flow that created the Transaction.
getter/setter pair
- flowType ↔ TransactionFlowType?
-
Type of the flow that created the Transaction.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - object ↔ TransactionObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ TransactionStatus?
-
Status of the Transaction.
getter/setter pair
- statusTransitions ↔ TreasuryTransactionsResourceAbstractTransactionResourceStatusTransitions?
-
The status_transitions property
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → Transaction -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object