object property
String representing the object's type. Objects of the same type share the same value. Always has the value list.
Implementation
TransactionEntriesObject? object;
String representing the object's type. Objects of the same type share the same value. Always has the value list.
TransactionEntriesObject? object;