TransactionEntry class

auto generated TransactionEntries represent individual units of money movements within a single Transaction.

Constructors

TransactionEntry()
Instantiates a new TransactionEntry and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
balanceImpact TreasuryTransactionsResourceBalanceImpact?
Change to a FinancialAccount's balance
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
effectiveAt int?
When the TransactionEntry will impact the FinancialAccount's balance.
getter/setter pair
financialAccount String?
The FinancialAccount associated with this object.
getter/setter pair
flow String?
Token of the flow associated with the TransactionEntry.
getter/setter pair
flowDetails TreasuryTransactionsResourceFlowDetails?
Details of the flow associated with the TransactionEntry.
getter/setter pair
flowType TransactionEntryFlowType?
Type of the flow associated with the TransactionEntry.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
object TransactionEntryObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transaction TransactionEntryTransaction?
The Transaction associated with this object.
getter/setter pair
type_ TransactionEntryType?
The specific money movement that generated the TransactionEntry.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) TransactionEntry
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object