status property
Indicates whether this object and its related objects have been redacted or not.
Implementation
VerificationSessionRedactionStatus? status;
Indicates whether this object and its related objects have been redacted or not.
VerificationSessionRedactionStatus? status;