getAsync method
Future<FilesGetResponse?>
getAsync(
- FilesGetRequestBody body, [
- void requestConfiguration(
- RequestConfiguration<
FilesRequestBuilderGetQueryParameters>
- RequestConfiguration<
Returns a list of the files that your account has access to. Stripe sorts and returns the files by their creation dates, placing the most recently created files at the top.
[body] The request body [requestConfiguration] Configuration for the request such as headers, query parameters, and middleware options.Implementation
Future<FilesGetResponse?> getAsync(FilesGetRequestBody body,
[void Function(
RequestConfiguration<FilesRequestBuilderGetQueryParameters>)?
requestConfiguration]) async {
var requestInfo = toGetRequestInformation(body, requestConfiguration);
final errorMapping = <String, ParsableFactory<Parsable>>{
'XXX': Error.createFromDiscriminatorValue,
};
return await requestAdapter.send<FilesGetResponse>(requestInfo,
FilesGetResponse.createFromDiscriminatorValue, errorMapping);
}