toGetRequestInformation method

RequestInformation toGetRequestInformation(
  1. FilesGetRequestBody body, [
  2. void requestConfiguration(
    1. RequestConfiguration<FilesRequestBuilderGetQueryParameters>
    )?
])

Returns a list of the files that your account has access to. Stripe sorts and returns the files by their creation dates, placing the most recently created files at the top.

[body] The request body [requestConfiguration] Configuration for the request such as headers, query parameters, and middleware options.

Implementation

RequestInformation toGetRequestInformation(FilesGetRequestBody body,
    [void Function(
            RequestConfiguration<FilesRequestBuilderGetQueryParameters>)?
        requestConfiguration]) {
  var requestInfo = RequestInformation(
      httpMethod: HttpMethod.get,
      urlTemplate: urlTemplate,
      pathParameters: pathParameters);
  requestInfo.configure<FilesRequestBuilderGetQueryParameters>(
      requestConfiguration, () => FilesRequestBuilderGetQueryParameters());
  requestInfo.headers.put('Accept', 'application/json');
  requestInfo.setContentFromParsable(
      requestAdapter, 'application/x-www-form-urlencoded', body);
  return requestInfo;
}