FilesRequestBuilderGetQueryParameters class

auto generated

Returns a list of the files that your account has access to. Stripe sorts and returns the files by their creation dates, placing the most recently created files at the top.

Properties

created int?
Only return files that were created during the given date interval.
getter/setter pair
endingBefore String?
A cursor for use in pagination. ending_before is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list. @QueryParameter('ending_before')
getter/setter pair
expand List<String>?
Specifies which fields in the response should be expanded.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
limit int?
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
getter/setter pair
purpose GetPurposeQueryParameterType?
Filter queries by the file purpose. If you don't provide a purpose, the queries return unfiltered files.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startingAfter String?
A cursor for use in pagination. starting_after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list. @QueryParameter('starting_after')
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Extracts the query parameters into a map for the URI template parsing.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited