Account class
auto generated
This is an object representing a Stripe account. You can retrieve it to seeproperties on the account like its current requirements or if the account isenabled to make live charges or receive payouts.For accounts where controller.requirement_collectionis application, which includes Custom accounts, the properties below are alwaysreturned.For accounts where controller.requirement_collectionis stripe, which includes Standard and Express accounts, some properties are only returneduntil you create an Account Link or Account Sessionto start Connect Onboarding. Learn about the differences between accounts.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- businessProfile ↔ AccountBusinessProfile?
-
Business information about the account.
getter/setter pair
- businessType ↔ AccountBusinessType?
-
The business type.
getter/setter pair
- capabilities ↔ AccountCapabilities?
-
The capabilities property
getter/setter pair
- chargesEnabled ↔ bool?
-
Whether the account can process charges.
getter/setter pair
- company ↔ LegalEntityCompany?
-
The company property
getter/setter pair
- controller ↔ AccountUnificationAccountController?
-
The controller property
getter/setter pair
- country ↔ String?
-
The account's country.
getter/setter pair
- created ↔ int?
-
Time at which the account was connected. Measured in seconds since the Unix epoch.
getter/setter pair
- defaultCurrency ↔ String?
-
Three-letter ISO currency code representing the default currency for the account. This must be a currency that Stripe supports in the account's country.
getter/setter pair
- detailsSubmitted ↔ bool?
-
Whether account details have been submitted. Accounts with Stripe Dashboard access, which includes Standard accounts, cannot receive payouts before this is true. Accounts where this is false should be directed to an onboarding flow to finish submitting account details.
getter/setter pair
- email ↔ String?
-
An email address associated with the account. It's not used for authentication and Stripe doesn't market to this field without explicit approval from the platform.
getter/setter pair
- externalAccounts ↔ AccountExternalAccounts?
-
External accounts (bank accounts and debit cards) currently attached to this account. External accounts are only returned for requests where
controller[is_controller]is true.getter/setter pair - futureRequirements ↔ AccountFutureRequirements?
-
The future_requirements property
getter/setter pair
- groups ↔ AccountGroupMembership?
-
The groups associated with the account.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- individual ↔ Person?
-
This is an object representing a person associated with a Stripe account.A platform can only access a subset of data in a person for an account where account.controller.requirement_collection is
stripe, which includes Standard and Express accounts, after creating an Account Link or Account Session to start Connect onboarding.See the Standard onboarding or Express onboarding documentation for information about prefilling information and account onboarding steps. Learn more about handling identity verification with the API.getter/setter pair - metadata ↔ AccountMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- object ↔ Account_object?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- payoutsEnabled ↔ bool?
-
Whether the funds in this account can be paid out.
getter/setter pair
- requirements ↔ AccountRequirements?
-
The requirements property
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings ↔ AccountSettings?
-
Options for customizing how the account functions within Stripe.
getter/setter pair
- tosAcceptance ↔ AccountTosAcceptance?
-
The tos_acceptance property
getter/setter pair
- type_ ↔ AccountType?
-
The Stripe account type. Can be
standard,express,custom, ornone.getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → Account -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object