AccountCapabilityFutureRequirements class
auto generated
Constructors
- AccountCapabilityFutureRequirements()
- Instantiates a new AccountCapabilityFutureRequirements and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
-
alternatives
↔ Iterable<
AccountRequirementsAlternative> ? -
Fields that are due and can be resolved by providing the corresponding alternative fields instead. Multiple alternatives can reference the same
original_fields_due. When this happens, any of these alternatives can serve as a pathway for attempting to resolve the fields. Additionally, providingoriginal_fields_dueagain also serves as a pathway for attempting to resolve the fields.getter/setter pair - currentDeadline ↔ int?
-
Date on which
future_requirementsbecomes the mainrequirementshash andfuture_requirementsbecomes empty. After the transition,currently_duerequirements may immediately becomepast_due, but the account may also be given a grace period depending on the capability's enablement state prior to transitioning.getter/setter pair -
currentlyDue
↔ Iterable<
String> ? -
Fields that need to be resolved to keep the capability enabled. If not resolved by
future_requirements[current_deadline], these fields will transition to the mainrequirementshash.getter/setter pair - disabledReason ↔ AccountCapabilityFutureRequirementsDisabledReason?
-
This is typed as an enum for consistency with
requirements.disabled_reason, but it safe to assumefuture_requirements.disabled_reasonis null because fields infuture_requirementswill never disable the account.getter/setter pair -
errors
↔ Iterable<
AccountRequirementsError> ? -
Details about validation and verification failures for
duerequirements that must be resolved.getter/setter pair -
eventuallyDue
↔ Iterable<
String> ? -
Fields you must collect when all thresholds are reached. As they become required, they appear in
currently_dueas well.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
-
pastDue
↔ Iterable<
String> ? -
Fields that haven't been resolved by
requirements.current_deadline. These fields need to be resolved to enable the capability on the account.future_requirements.past_dueis a subset ofrequirements.past_due.getter/setter pair -
pendingVerification
↔ Iterable<
String> ? -
Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move to
eventually_due,currently_due,past_dueoralternatives. Fields might appear ineventually_due,currently_due,past_dueoralternativesand inpending_verificationif one verification fails but another is still pending.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → AccountCapabilityFutureRequirements -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object