alternatives property
Fields that are due and can be resolved by providing the corresponding alternative fields instead. Multiple alternatives can reference the same original_fields_due. When this happens, any of these alternatives can serve as a pathway for attempting to resolve the fields. Additionally, providing original_fields_due again also serves as a pathway for attempting to resolve the fields.
Implementation
Iterable<AccountRequirementsAlternative>? alternatives;