isController property
true if the Connect application retrieving the resource controls the account and can therefore exercise platform controls. Otherwise, this field is null.
Implementation
bool? isController;
true if the Connect application retrieving the resource controls the account and can therefore exercise platform controls. Otherwise, this field is null.
bool? isController;