available property

Iterable<BalanceAmount>? available
getter/setter pair

Available funds that you can transfer or pay out automatically by Stripe or explicitly through the Transfers API or Payouts API. You can find the available balance for each currency and payment type in the source_types property.

Implementation

Iterable<BalanceAmount>? available;