connectReserved property
Funds held due to negative balances on connected accounts where account.controller.requirement_collection is application, which includes Custom accounts. You can find the connect reserve balance for each currency and payment type in the source_types property.
Implementation
Iterable<BalanceAmount>? connectReserved;