BalanceTransactionSource class

Constructors

BalanceTransactionSource()

Properties

applicationFee ApplicationFee?
Composed type representation for type ApplicationFee
getter/setter pair
authorization Authorization?
Composed type representation for type Authorization
getter/setter pair
charge Charge?
Composed type representation for type Charge
getter/setter pair
connectCollectionTransfer ConnectCollectionTransfer?
Composed type representation for type ConnectCollectionTransfer
getter/setter pair
customerCashBalanceTransaction CustomerCashBalanceTransaction?
Composed type representation for type CustomerCashBalanceTransaction
getter/setter pair
dispute Dispute?
Composed type representation for type Dispute
getter/setter pair
feeRefund FeeRefund?
Composed type representation for type FeeRefund
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
payout Payout?
Composed type representation for type Payout
getter/setter pair
refund Refund?
Composed type representation for type Refund
getter/setter pair
reserveTransaction ReserveTransaction?
Composed type representation for type ReserveTransaction
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
string_ String?
Composed type representation for type String?
getter/setter pair
taxDeductedAtSource TaxDeductedAtSource?
Composed type representation for type TaxDeductedAtSource
getter/setter pair
topup Topup?
Composed type representation for type Topup
getter/setter pair
transaction Transaction?
Composed type representation for type Transaction
getter/setter pair
transfer Transfer?
Composed type representation for type Transfer
getter/setter pair
transferReversal TransferReversal?
Composed type representation for type TransferReversal
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) BalanceTransactionSource
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object