availablePayoutMethods property
A set of available payout methods for this bank account. Only values from this set should be passed as the method when creating a payout.
Implementation
Iterable<BankAccountAvailablePayoutMethods>? availablePayoutMethods;