Meter class

auto generated Meters specify how to aggregate meter events over a billing period. Meter events represent the actions that customers take in your system. Meters attach to prices and form the basis of the bill.Related guide: Usage based billing

Constructors

Meter()
Instantiates a new Meter and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
customerMapping BillingMeterResourceCustomerMappingSettings?
The customer_mapping property
getter/setter pair
defaultAggregation BillingMeterResourceAggregationSettings?
The default_aggregation property
getter/setter pair
displayName String?
The meter's name.
getter/setter pair
eventName String?
The name of the meter event to record usage for. Corresponds with the event_name field on meter events.
getter/setter pair
eventTimeWindow MeterEventTimeWindow?
The time window which meter events have been pre-aggregated for, if any.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
object MeterObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status MeterStatus?
The meter's status.
getter/setter pair
statusTransitions BillingMeterResourceBillingMeterStatusTransitions?
The status_transitions property
getter/setter pair
updated int?
Time at which the object was last updated. Measured in seconds since the Unix epoch.
getter/setter pair
valueSettings BillingMeterResourceBillingMeterValue?
The value_settings property
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) Meter
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object