MeterEventAdjustment class
auto generated A billing meter event adjustment is a resource that allows you to cancel a meter event. For example, you might create a billing meter event adjustment to cancel a meter event that was created in error or attached to the wrong customer.
Constructors
- MeterEventAdjustment()
- Instantiates a new MeterEventAdjustment and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- cancel ↔ BillingMeterResourceBillingMeterEventAdjustmentCancel?
-
Specifies which event to cancel.
getter/setter pair
- eventName ↔ String?
-
The name of the meter event. Corresponds with the
event_namefield on a meter.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - object ↔ MeterEventAdjustmentObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ MeterEventAdjustmentStatus?
-
The meter event adjustment's status.
getter/setter pair
- type_ ↔ MeterEventAdjustmentType?
-
Specifies whether to cancel a single event or a range of events for a time period. Time period cancellation is not supported yet.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → MeterEventAdjustment -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object