MeterEventSummary class
auto generated A billing meter event summary represents an aggregated view of a customer's billing meter events within a specified timeframe. It indicates how muchusage was accrued by a customer for that period.Note: Meters events are aggregated asynchronously so the meter event summaries provide an eventually consistent view of the reported usage.
Constructors
- MeterEventSummary()
- Instantiates a new MeterEventSummary and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- aggregatedValue ↔ double?
-
Aggregated value of all the events within
start_time(inclusive) andend_time(inclusive). The aggregation strategy is defined on meter viadefault_aggregation.getter/setter pair - endTime ↔ int?
-
End timestamp for this event summary (exclusive). Must be aligned with minute boundaries.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - meter ↔ String?
-
The meter associated with this event summary.
getter/setter pair
- object ↔ MeterEventSummaryObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime ↔ int?
-
Start timestamp for this event summary (inclusive). Must be aligned with minute boundaries.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → MeterEventSummary -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object