Card class
auto generated You can store multiple cards on a customer in order to charge the customerlater. You can also store multiple debit cards on a recipient in order totransfer to those cards later.Related guide: Card payments with Sources
Properties
- account ↔ CardAccount?
-
The account property
getter/setter pair
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- addressCity ↔ String?
-
City/District/Suburb/Town/Village.
getter/setter pair
- addressCountry ↔ String?
-
Billing address country, if provided when creating card.
getter/setter pair
- addressLine1 ↔ String?
-
Address line 1 (Street address/PO Box/Company name).
getter/setter pair
- addressLine1Check ↔ String?
-
If
address_line1was provided, results of the check:pass,fail,unavailable, orunchecked.getter/setter pair - addressLine2 ↔ String?
-
Address line 2 (Apartment/Suite/Unit/Building).
getter/setter pair
- addressState ↔ String?
-
State/County/Province/Region.
getter/setter pair
- addressZip ↔ String?
-
ZIP or postal code.
getter/setter pair
- addressZipCheck ↔ String?
-
If
address_zipwas provided, results of the check:pass,fail,unavailable, orunchecked.getter/setter pair - allowRedisplay ↔ CardAllowRedisplay?
-
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.
getter/setter pair
-
availablePayoutMethods
↔ Iterable<
CardAvailablePayoutMethods> ? -
A set of available payout methods for this card. Only values from this set should be passed as the
methodwhen creating a payout.getter/setter pair - brand ↔ String?
-
Card brand. Can be
American Express,Cartes Bancaires,Diners Club,Discover,Eftpos Australia,Girocard,JCB,MasterCard,UnionPay,Visa, orUnknown.getter/setter pair - country ↔ String?
-
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.
getter/setter pair
- currency ↔ String?
-
Three-letter ISO code for currency in lowercase. Must be a supported currency. Only applicable on accounts (not customers or recipients). The card can be used as a transfer destination for funds in this currency. This property is only available when returned as an External Account where controller.is_controller is
true.getter/setter pair - customer ↔ CardCustomer?
-
The customer that this card belongs to. This attribute will not be in the card object if the card belongs to an account or recipient instead.
getter/setter pair
- cvcCheck ↔ String?
-
If a CVC was provided, results of the check:
pass,fail,unavailable, orunchecked. A result of unchecked indicates that CVC was provided but hasn't been checked yet. Checks are typically performed when attaching a card to a Customer object, or when creating a charge. For more details, see Check if a card is valid without a charge.getter/setter pair - defaultForCurrency ↔ bool?
-
Whether this card is the default external account for its currency. This property is only available for accounts where controller.requirement_collection is
application, which includes Custom accounts.getter/setter pair - dynamicLast4 ↔ String?
-
(For tokenized numbers only.) The last four digits of the device account number.
getter/setter pair
- expMonth ↔ int?
-
Two-digit number representing the card's expiration month.
getter/setter pair
- expYear ↔ int?
-
Four-digit number representing the card's expiration year.
getter/setter pair
- fingerprint ↔ String?
-
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.
getter/setter pair
- funding ↔ String?
-
Card funding type. Can be
credit,debit,prepaid, orunknown.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- iin ↔ String?
-
Issuer identification number of the card.
getter/setter pair
- last4 ↔ String?
-
The last four digits of the card.
getter/setter pair
- metadata ↔ CardMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- name ↔ String?
-
Cardholder name.
getter/setter pair
- networks ↔ TokenCardNetworks?
-
The networks property
getter/setter pair
- object ↔ CardObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- regulatedStatus ↔ CardRegulatedStatus?
-
Status of a card based on the card issuer.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String?
-
For external accounts that are cards, possible values are
newanderrored. If a payout fails, the status is set toerroredand scheduled payouts are stopped until account details are updated.getter/setter pair - tokenizationMethod ↔ String?
-
If the card number is tokenized, this is the method that was used. Can be
android_pay(includes Google Pay),apple_pay,masterpass,visa_checkout, or null.getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → Card -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object