customer property
The customer that this card belongs to. This attribute will not be in the card object if the card belongs to an account or recipient instead.
Implementation
CardCustomer? customer;
The customer that this card belongs to. This attribute will not be in the card object if the card belongs to an account or recipient instead.
CardCustomer? customer;