transfer property

ChargeTransfer? transfer
getter/setter pair

ID of the transfer to the destination account (only applicable if the charge was created using the destination parameter).

Implementation

ChargeTransfer? transfer;