SessionLocale enum
auto generated
The IETF language tag of the locale Checkout is displayed in. If blank or auto, the browser's locale is used.
Values
- auto → const SessionLocale
-
const SessionLocale('auto') - bg → const SessionLocale
-
const SessionLocale('bg') - cs → const SessionLocale
-
const SessionLocale('cs') - da → const SessionLocale
-
const SessionLocale('da') - de → const SessionLocale
-
const SessionLocale('de') - el → const SessionLocale
-
const SessionLocale('el') - en → const SessionLocale
-
const SessionLocale('en') - enGB → const SessionLocale
-
const SessionLocale('en-GB') - es → const SessionLocale
-
const SessionLocale('es') - es419 → const SessionLocale
-
const SessionLocale('es-419') - et → const SessionLocale
-
const SessionLocale('et') - fi → const SessionLocale
-
const SessionLocale('fi') - fil → const SessionLocale
-
const SessionLocale('fil') - fr → const SessionLocale
-
const SessionLocale('fr') - frCA → const SessionLocale
-
const SessionLocale('fr-CA') - hr → const SessionLocale
-
const SessionLocale('hr') - hu → const SessionLocale
-
const SessionLocale('hu') - id → const SessionLocale
-
const SessionLocale('id') - it → const SessionLocale
-
const SessionLocale('it') - ja → const SessionLocale
-
const SessionLocale('ja') - ko → const SessionLocale
-
const SessionLocale('ko') - lt → const SessionLocale
-
const SessionLocale('lt') - lv → const SessionLocale
-
const SessionLocale('lv') - ms → const SessionLocale
-
const SessionLocale('ms') - mt → const SessionLocale
-
const SessionLocale('mt') - nb → const SessionLocale
-
const SessionLocale('nb') - nl → const SessionLocale
-
const SessionLocale('nl') - pl → const SessionLocale
-
const SessionLocale('pl') - pt → const SessionLocale
-
const SessionLocale('pt') - ptBR → const SessionLocale
-
const SessionLocale('pt-BR') - ro → const SessionLocale
-
const SessionLocale('ro') - ru → const SessionLocale
-
const SessionLocale('ru') - sk → const SessionLocale
-
const SessionLocale('sk') - sl → const SessionLocale
-
const SessionLocale('sl') - sv → const SessionLocale
-
const SessionLocale('sv') - th → const SessionLocale
-
const SessionLocale('th') - tr → const SessionLocale
-
const SessionLocale('tr') - vi → const SessionLocale
-
const SessionLocale('vi') - zh → const SessionLocale
-
const SessionLocale('zh') - zhHK → const SessionLocale
-
const SessionLocale('zh-HK') - zhTW → const SessionLocale
-
const SessionLocale('zh-TW')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SessionLocale> - A constant List of the values in this enum, in order of their declaration.