Customer class
auto generated This object represents a customer of your business. Use it to create recurring charges, save payment and contact information,and track payments that belong to the same customer.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- address ↔ Address?
-
The customer's address.
getter/setter pair
- balance ↔ int?
-
The current balance, if any, that's stored on the customer in their default currency. If negative, the customer has credit to apply to their next invoice. If positive, the customer has an amount owed that's added to their next invoice. The balance only considers amounts that Stripe hasn't successfully applied to any invoice. It doesn't reflect unpaid invoices. This balance is only taken into account after invoices finalize. For multi-currency balances, see invoice_credit_balance.
getter/setter pair
- businessName ↔ String?
-
The customer's business name.
getter/setter pair
- cashBalance ↔ CashBalance?
-
The current funds being held by Stripe on behalf of the customer. You can apply these funds towards payment intents when the source is "cash_balance". The
settings[reconciliation_mode]field describes if these funds apply to these payment intents manually or automatically.getter/setter pair - created ↔ int?
-
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
- currency ↔ String?
-
Three-letter ISO code for the currency the customer can be charged in for recurring billing purposes.
getter/setter pair
- customerAccount ↔ String?
-
The ID of an Account representing a customer. You can use this ID with any v1 API that accepts a customer_account parameter.
getter/setter pair
- defaultSource ↔ CustomerDefaultSource?
-
ID of the default payment source for the customer.If you use payment methods created through the PaymentMethods API, see the invoice_settings.default_payment_method field instead.
getter/setter pair
- delinquent ↔ bool?
-
Tracks the most recent state change on any invoice belonging to the customer. Paying an invoice or marking it uncollectible via the API will set this field to false. An automatic payment failure or passing the
invoice.due_datewill set this field totrue.If an invoice becomes uncollectible by dunning,delinquentdoesn't reset tofalse.If you care whether the customer has paid their most recent subscription invoice, usesubscription.statusinstead. Paying or marking uncollectible any customer invoice regardless of whether it is the latest invoice for a subscription will always set this field tofalse.getter/setter pair - description ↔ String?
-
An arbitrary string attached to the object. Often useful for displaying to users.
getter/setter pair
- discount ↔ Discount?
-
Describes the current discount active on the customer, if there is one.
getter/setter pair
- email ↔ String?
-
The customer's email address.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- individualName ↔ String?
-
The customer's individual name.
getter/setter pair
- invoiceCreditBalance ↔ CustomerInvoiceCreditBalance?
-
The current multi-currency balances, if any, that's stored on the customer. If positive in a currency, the customer has a credit to apply to their next invoice denominated in that currency. If negative, the customer has an amount owed that's added to their next invoice denominated in that currency. These balances don't apply to unpaid invoices. They solely track amounts that Stripe hasn't successfully applied to any invoice. Stripe only applies a balance in a specific currency to an invoice after that invoice (which is in the same currency) finalizes.
getter/setter pair
- invoicePrefix ↔ String?
-
The prefix for the customer used to generate unique invoice numbers.
getter/setter pair
- invoiceSettings ↔ InvoiceSettingCustomerSetting?
-
The invoice_settings property
getter/setter pair
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - metadata ↔ CustomerMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- name ↔ String?
-
The customer's full name or business name.
getter/setter pair
- nextInvoiceSequence ↔ int?
-
The suffix of the customer's next invoice number (for example, 0001). When the account uses account level sequencing, this parameter is ignored in API requests and the field omitted in API responses.
getter/setter pair
- object ↔ CustomerObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- phone ↔ String?
-
The customer's phone number.
getter/setter pair
-
preferredLocales
↔ Iterable<
String> ? -
The customer's preferred locales (languages), ordered by preference.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shipping ↔ Shipping?
-
Mailing and shipping address for the customer. Appears on invoices emailed to this customer.
getter/setter pair
- sources ↔ CustomerSources?
-
The customer's payment sources, if any.
getter/setter pair
- subscriptions ↔ CustomerSubscriptions?
-
The customer's current subscriptions, if any.
getter/setter pair
- tax ↔ CustomerTax?
-
The tax property
getter/setter pair
- taxExempt ↔ CustomerTaxExempt?
-
Describes the customer's tax exemption status, which is
none,exempt, orreverse. When set toreverse, invoice and receipt PDFs include the following text: "Reverse charge".getter/setter pair - taxIds ↔ CustomerTaxIds?
-
The customer's tax IDs.
getter/setter pair
- testClock ↔ CustomerTestClock?
-
ID of the test clock that this customer belongs to.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → Customer -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object