models/customer_balance_transaction library
Classes
- CustomerBalanceTransaction
-
auto generated
Each customer has a Balance value,which denotes a debit or credit that's automatically applied to their next invoice upon finalization.You may modify the value directly by using the update customer API,or by creating a Customer Balance Transaction, which increments or decrements the customer's
balanceby the specifiedamount.Related guide: Customer balance