CustomerBalanceTransaction class
auto generated
Each customer has a Balance value,which denotes a debit or credit that's automatically applied to their next invoice upon finalization.You may modify the value directly by using the update customer API,or by creating a Customer Balance Transaction, which increments or decrements the customer's balance by the specified amount.Related guide: Customer balance
Constructors
- CustomerBalanceTransaction()
- Instantiates a new CustomerBalanceTransaction and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- amount ↔ int?
-
The amount of the transaction. A negative value is a credit for the customer's balance, and a positive value is a debit to the customer's
balance.getter/setter pair - checkoutSession ↔ CustomerBalanceTransactionCheckoutSession?
-
The ID of the checkout session (if any) that created the transaction.
getter/setter pair
- created ↔ int?
-
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
- creditNote ↔ CustomerBalanceTransactionCreditNote?
-
The ID of the credit note (if any) related to the transaction.
getter/setter pair
- currency ↔ String?
-
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
- customer ↔ CustomerBalanceTransactionCustomer?
-
The ID of the customer the transaction belongs to.
getter/setter pair
- customerAccount ↔ String?
-
The ID of an Account representing a customer that the transaction belongs to.
getter/setter pair
- description ↔ String?
-
An arbitrary string attached to the object. Often useful for displaying to users.
getter/setter pair
- endingBalance ↔ int?
-
The customer's
balanceafter the transaction was applied. A negative value decreases the amount due on the customer's next invoice. A positive value increases the amount due on the customer's next invoice.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- invoice ↔ CustomerBalanceTransactionInvoice?
-
The ID of the invoice (if any) related to the transaction.
getter/setter pair
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - metadata ↔ CustomerBalanceTransactionMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- object ↔ CustomerBalanceTransactionObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type_ ↔ CustomerBalanceTransactionType?
-
Transaction type:
adjustment,applied_to_invoice,credit_note,initial,invoice_overpaid,invoice_too_large,invoice_too_small,unspent_receiver_credit,unapplied_from_invoice,checkout_session_subscription_payment, orcheckout_session_subscription_payment_canceled. See the Customer Balance page to learn more about transaction types.getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → CustomerBalanceTransaction -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object