models/customer_session_resource_components_resource_mobile_payment_element library
Classes
- CustomerSessionResourceComponentsResourceMobilePaymentElement
- auto generated This hash contains whether the mobile payment element is enabled and the features it supports.