CustomerTax class
auto generated
Constructors
- CustomerTax()
- Instantiates a new CustomerTax and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- automaticTax ↔ CustomerTaxAutomaticTax?
-
Surfaces if automatic tax computation is possible given the current customer location information.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- ipAddress ↔ String?
-
A recent IP address of the customer used for tax reporting and tax location inference.
getter/setter pair
- location ↔ CustomerTaxLocation?
-
The identified tax location of the customer.
getter/setter pair
- provider ↔ CustomerTaxProvider?
-
The tax calculation provider used for location resolution. Defaults to
stripewhen not using a third-party provider.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → CustomerTax -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object