DisputeStatus enum

auto generated The current status of a dispute. Possible values include:warning_needs_response, warning_under_review, warning_closed, needs_response, under_review, won, lost, or prevented.

Inheritance
Available extensions

Values

lost → const DisputeStatus
const DisputeStatus('lost')
needsResponse → const DisputeStatus
const DisputeStatus('needs_response')
prevented → const DisputeStatus
const DisputeStatus('prevented')
underReview → const DisputeStatus
const DisputeStatus('under_review')
warningClosed → const DisputeStatus
const DisputeStatus('warning_closed')
warningNeedsResponse → const DisputeStatus
const DisputeStatus('warning_needs_response')
warningUnderReview → const DisputeStatus
const DisputeStatus('warning_under_review')
won → const DisputeStatus
const DisputeStatus('won')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DisputeStatus>
A constant List of the values in this enum, in order of their declaration.