Event class

auto generated Snapshot events allow you to track and react to activity in your Stripe integration. Whenthe state of another API resource changes, Stripe creates an Event object that containsall the relevant information associated with that action, including the affected APIresource. For example, a successful payment triggers a charge.succeeded event, whichcontains the Charge in the event's data property. Some actions trigger multiple events.For example, if you create a new subscription for a customer, it triggers both acustomer.subscription.created event and a charge.succeeded event.Configure an event destination in your account to listen for events that represent actionsyour integration needs to respond to. Additionally, you can retrieve an individual event ora list of events from the API.Connect platforms can also receive event notificationsthat occur in their connected accounts. These events include an account attribute thatidentifies the relevant connected account.You can access events through the Retrieve Event APIfor 30 days.

Constructors

Event()
Instantiates a new Event and sets the default values.

Properties

account String?
The connected account that originates the event.
getter/setter pair
additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
apiVersion String?
The Stripe API version used to render data when the event was created. The contents of data never change, so this value remains static regardless of the API version currently in use. This property is populated only for events created on or after October 31, 2014.
getter/setter pair
context String?
Authentication context needed to fetch the event or related object.
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
data NotificationEventData?
The data property
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
object EventObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
pendingWebhooks int?
Number of webhooks that haven't been successfully delivered (for example, to return a 20x response) to the URLs you specify.
getter/setter pair
request NotificationEventRequest?
Information on the API request that triggers the event.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type_ String?
Description of the event (for example, invoice.created or charge.refunded).
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) Event
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object