models/invoice_collection_method library
Enums
- InvoiceCollectionMethod
-
auto generated
Either
charge_automatically, orsend_invoice. When charging automatically, Stripe will attempt to pay this invoice using the default source attached to the customer. When sending an invoice, Stripe will email this invoice to the customer with payment instructions.