models/invoice_lines library
Classes
- InvoiceLines
-
auto generated
The individual line items that make up the invoice.
linesis sorted as follows: (1) pending invoice items (including prorations) in reverse chronological order, (2) subscription items in reverse chronological order, and (3) invoice items added after invoice creation in chronological order.