models/invoice_rendering_template library

Classes

InvoiceRenderingTemplate
auto generated Invoice Rendering Templates are used to configure how invoices are rendered on surfaces like the PDF. Invoice Rendering Templatescan be created from within the Dashboard, and they can be used over the API when creating invoices.