version property
Version of this template; version increases by one when an update on the template changes any field that controls invoice rendering
Implementation
int? version;
Version of this template; version increases by one when an update on the template changes any field that controls invoice rendering
int? version;