IssuingAuthorizationPendingRequest class
auto generated
Constructors
- IssuingAuthorizationPendingRequest()
- Instantiates a new IssuingAuthorizationPendingRequest and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- amount ↔ int?
-
The additional amount Stripe will hold if the authorization is approved, in the card's currency and in the smallest currency unit.
getter/setter pair
- amountDetails ↔ IssuingAuthorizationAmountDetails?
-
Detailed breakdown of amount components. These amounts are denominated in
currencyand in the smallest currency unit.getter/setter pair - currency ↔ String?
-
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAmountControllable ↔ bool?
-
If set
true, you may provide amount to control how much to hold for the authorization.getter/setter pair - merchantAmount ↔ int?
-
The amount the merchant is requesting to be authorized in the
merchant_currency. The amount is in the smallest currency unit.getter/setter pair - merchantCurrency ↔ String?
-
The local currency the merchant is requesting to authorize.
getter/setter pair
- networkRiskScore ↔ int?
-
The card network's estimate of the likelihood that an authorization is fraudulent. Takes on values between 1 and 99.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → IssuingAuthorizationPendingRequest -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object