reason property

IssuingAuthorizationRequestReason? reason
getter/setter pair

When an authorization is approved or declined by you or by Stripe, this field provides additional detail on the reason for the outcome.

Implementation

IssuingAuthorizationRequestReason? reason;