reasonMessage property

String? reasonMessage
getter/setter pair

If the request_history.reason is webhook_error because the direct webhook response is invalid (for example, parsing errors or missing parameters), we surface a more detailed error message via this field.

Implementation

String? reasonMessage;