IssuingCardShipping class
auto generated
Constructors
- IssuingCardShipping()
- Instantiates a new IssuingCardShipping and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- address ↔ Address?
-
The address property
getter/setter pair
- addressValidation ↔ IssuingCardShippingAddressValidation?
-
Address validation details for the shipment.
getter/setter pair
- carrier ↔ IssuingCardShippingCarrier?
-
The delivery company that shipped a card.
getter/setter pair
- customs ↔ IssuingCardShippingCustoms?
-
Additional information that may be required for clearing customs.
getter/setter pair
- eta ↔ int?
-
A unix timestamp representing a best estimate of when the card will be delivered.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Recipient name.
getter/setter pair
- phoneNumber ↔ String?
-
The phone number of the receiver of the shipment. Our courier partners will use this number to contact you in the event of card delivery issues. For individual shipments to the EU/UK, if this field is empty, we will provide them with the phone number provided when the cardholder was initially created.
getter/setter pair
- requireSignature ↔ bool?
-
Whether a signature is required for card delivery. This feature is only supported for US users. Standard shipping service does not support signature on delivery. The default value for standard shipping service is false and for express and priority services is true.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- service ↔ IssuingCardShippingService?
-
Shipment service, such as
standardorexpress.getter/setter pair - status ↔ IssuingCardShippingStatus?
-
The delivery status of the card.
getter/setter pair
- trackingNumber ↔ String?
-
A tracking number for a card shipment.
getter/setter pair
- trackingUrl ↔ String?
-
A link to the shipping carrier's site where you can view detailed information about a card shipment.
getter/setter pair
- type_ ↔ IssuingCardShippingType?
-
Packaging options.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → IssuingCardShipping -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object