Cardholder class
auto generated
An Issuing Cardholder object represents an individual or business entity who is issued cards.Related guide: How to create a cardholder
Constructors
- Cardholder()
- Instantiates a new Cardholder and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- billing ↔ IssuingCardholderAddress?
-
The billing property
getter/setter pair
- company ↔ IssuingCardholderCompany?
-
Additional information about a
companycardholder.getter/setter pair - created ↔ int?
-
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
- email ↔ String?
-
The cardholder's email address.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- individual ↔ IssuingCardholderIndividual?
-
Additional information about an
individualcardholder.getter/setter pair - livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - metadata ↔ CardholderMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- name ↔ String?
-
The cardholder's name. This will be printed on cards issued to them.
getter/setter pair
- object ↔ CardholderObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- phoneNumber ↔ String?
-
The cardholder's phone number. This is required for all cardholders who will be creating EU cards. See the 3D Secure documentation for more details.
getter/setter pair
-
preferredLocales
↔ Iterable<
CardholderPreferredLocales> ? -
The cardholder’s preferred locales (languages), ordered by preference. Locales can be
de,en,es,fr, orit. This changes the language of the 3D Secure flow and one-time password messages sent to the cardholder.getter/setter pair - requirements ↔ IssuingCardholderRequirements?
-
The requirements property
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spendingControls ↔ IssuingCardholderAuthorizationControls?
-
Rules that control spending across this cardholder's cards. Refer to our documentation for more details.
getter/setter pair
- status ↔ CardholderStatus?
-
Specifies whether to permit authorizations on this cardholder's cards.
getter/setter pair
- type_ ↔ CardholderType?
-
One of
individualorcompany. See Choose a cardholder type for more details.getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → Cardholder -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object