isPlatformDefault property
Whether this personalization design is used to create cards when one is not specified and a default for this connected account does not exist.
Implementation
bool? isPlatformDefault;
Whether this personalization design is used to create cards when one is not specified and a default for this connected account does not exist.
bool? isPlatformDefault;