IssuingPhysicalBundleFeatures class
auto generated
Constructors
- IssuingPhysicalBundleFeatures()
- Instantiates a new IssuingPhysicalBundleFeatures and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- cardLogo ↔ IssuingPhysicalBundleFeaturesCardLogo?
-
The policy for how to use card logo images in a card design with this physical bundle.
getter/setter pair
- carrierText ↔ IssuingPhysicalBundleFeaturesCarrierText?
-
The policy for how to use carrier letter text in a card design with this physical bundle.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondLine ↔ IssuingPhysicalBundleFeaturesSecondLine?
-
The policy for how to use a second line on a card with this physical bundle.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → IssuingPhysicalBundleFeatures -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object