cardLogo property
The policy for how to use card logo images in a card design with this physical bundle.
Implementation
IssuingPhysicalBundleFeaturesCardLogo? cardLogo;
The policy for how to use card logo images in a card design with this physical bundle.
IssuingPhysicalBundleFeaturesCardLogo? cardLogo;