Token class
auto generated An issuing token object is created when an issued card is added to a digital wallet. As a card issuer, you can view and manage these tokens through Stripe.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- card ↔ TokenCard?
-
Card associated with this token.
getter/setter pair
- created ↔ int?
-
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
- deviceFingerprint ↔ String?
-
The hashed ID derived from the device ID from the card network associated with the token.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- last4 ↔ String?
-
The last four digits of the token.
getter/setter pair
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - network ↔ TokenNetwork?
-
The token service provider / card network associated with the token.
getter/setter pair
- networkData ↔ IssuingNetworkTokenNetworkData?
-
The network_data property
getter/setter pair
- networkUpdatedAt ↔ int?
-
Time at which the token was last updated by the card network. Measured in seconds since the Unix epoch.
getter/setter pair
- object ↔ TokenObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ TokenStatus?
-
The usage state of the token.
getter/setter pair
- walletProvider ↔ TokenWalletProvider?
-
The digital wallet for this token, if one was used.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → Token -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object