Item class
auto generated A line item.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- amountDiscount ↔ int?
-
Total discount amount applied. If no discounts were applied, defaults to 0.
getter/setter pair
- amountSubtotal ↔ int?
-
Total before any discounts or taxes are applied.
getter/setter pair
- amountTax ↔ int?
-
Total tax amount applied. If no tax was applied, defaults to 0.
getter/setter pair
- amountTotal ↔ int?
-
Total after discounts and taxes.
getter/setter pair
- currency ↔ String?
-
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
- description ↔ String?
-
An arbitrary string attached to the object. Often useful for displaying to users. Defaults to product name.
getter/setter pair
-
discounts
↔ Iterable<
LineItemsDiscountAmount> ? -
The discounts applied to the line item.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- metadata ↔ ItemMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- object ↔ ItemObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- price ↔ Price?
-
The price used to generate the line item.
getter/setter pair
- quantity ↔ int?
-
The quantity of products being purchased.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
taxes
↔ Iterable<
LineItemsTaxAmount> ? -
The taxes applied to the line item.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → Item -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object