MandateAcssDebit class
auto generated
Constructors
- MandateAcssDebit()
- Instantiates a new MandateAcssDebit and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
-
defaultFor
↔ Iterable<
MandateAcssDebitDefaultFor> ? -
List of Stripe products where this mandate can be selected automatically.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- intervalDescription ↔ String?
-
Description of the interval. Only required if the 'payment_schedule' parameter is 'interval' or 'combined'.
getter/setter pair
- paymentSchedule ↔ MandateAcssDebitPaymentSchedule?
-
Payment schedule for the mandate.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transactionType ↔ MandateAcssDebitTransactionType?
-
Transaction type of the mandate.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → MandateAcssDebit -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object