PaymentAttemptRecord class

auto generated A Payment Attempt Record represents an individual attempt at making a payment, on or off Stripe.Each payment attempt tries to collect a fixed amount of money from a fixed customer and paymentmethod. Payment Attempt Records are attached to Payment Records. Only one attempt per Payment Recordcan have guaranteed funds.

Constructors

PaymentAttemptRecord()
Instantiates a new PaymentAttemptRecord and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amount PaymentsPrimitivesPaymentRecordsResourceAmount?
A representation of an amount of money, consisting of an amount and a currency.
getter/setter pair
amountAuthorized PaymentsPrimitivesPaymentRecordsResourceAmount?
A representation of an amount of money, consisting of an amount and a currency.
getter/setter pair
amountCanceled PaymentsPrimitivesPaymentRecordsResourceAmount?
A representation of an amount of money, consisting of an amount and a currency.
getter/setter pair
amountFailed PaymentsPrimitivesPaymentRecordsResourceAmount?
A representation of an amount of money, consisting of an amount and a currency.
getter/setter pair
amountGuaranteed PaymentsPrimitivesPaymentRecordsResourceAmount?
A representation of an amount of money, consisting of an amount and a currency.
getter/setter pair
amountRefunded PaymentsPrimitivesPaymentRecordsResourceAmount?
A representation of an amount of money, consisting of an amount and a currency.
getter/setter pair
amountRequested PaymentsPrimitivesPaymentRecordsResourceAmount?
A representation of an amount of money, consisting of an amount and a currency.
getter/setter pair
application String?
ID of the Connect application that created the PaymentAttemptRecord.
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
customerDetails PaymentsPrimitivesPaymentRecordsResourceCustomerDetails?
Customer information for this payment.
getter/setter pair
customerPresence PaymentAttemptRecordCustomerPresence?
Indicates whether the customer was present in your checkout flow during this payment.
getter/setter pair
description String?
An arbitrary string attached to the object. Often useful for displaying to users.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
metadata PaymentAttemptRecordMetadata?
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
object PaymentAttemptRecordObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
paymentMethodDetails PaymentsPrimitivesPaymentRecordsResourcePaymentMethodDetails?
Information about the Payment Method debited for this payment.
getter/setter pair
paymentRecord String?
ID of the Payment Record this Payment Attempt Record belongs to.
getter/setter pair
processorDetails PaymentsPrimitivesPaymentRecordsResourceProcessorDetails?
Processor information associated with this payment.
getter/setter pair
reportedBy PaymentAttemptRecordReportedBy?
Indicates who reported the payment.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingDetails PaymentsPrimitivesPaymentRecordsResourceShippingDetails?
Shipping information for this payment.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PaymentAttemptRecord
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object