PaymentIntentProcessingCustomerNotification class

auto generated

Constructors

PaymentIntentProcessingCustomerNotification()
Instantiates a new PaymentIntentProcessingCustomerNotification and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
approvalRequested bool?
Whether customer approval has been requested for this payment. For payments greater than INR 15000 or mandate amount, the customer must provide explicit approval of the payment with their bank.
getter/setter pair
completesAt int?
If customer approval is required, they need to provide approval before this time.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) PaymentIntentProcessingCustomerNotification
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object