inactiveMessage property

String? inactiveMessage
getter/setter pair

The custom message to be displayed to a customer when a payment link is no longer active.

Implementation

String? inactiveMessage;