subscriptionData property
When creating a subscription, the specified configuration data will be used. There must be at least one line item with a recurring price to use subscription_data.
Implementation
PaymentLinksResourceSubscriptionData? subscriptionData;