transferData property
The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to.
Implementation
PaymentLinksResourceTransferData? transferData;
The account (if any) the payments will be attributed to for tax reporting, and where funds from each payment will be transferred to.
PaymentLinksResourceTransferData? transferData;