createFromDiscriminatorValue static method
Creates a new instance of the appropriate class based on discriminator value
parseNode The parse node to use to read the discriminator value and create the object
Implementation
static PaymentMethod createFromDiscriminatorValue(ParseNode parseNode) {
return PaymentMethod();
}