models/payment_method_domain_resource_payment_method_status_details library
Classes
- PaymentMethodDomainResourcePaymentMethodStatusDetails
- auto generated Contains additional details about the status of a payment method for a specific payment method domain.