PaymentMethodOptionsKonbini class
auto generated
Constructors
- PaymentMethodOptionsKonbini()
- Instantiates a new PaymentMethodOptionsKonbini and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- confirmationNumber ↔ String?
-
An optional 10 to 11 digit numeric-only string determining the confirmation code at applicable convenience stores.
getter/setter pair
- expiresAfterDays ↔ int?
-
The number of calendar days (between 1 and 60) after which Konbini payment instructions will expire. For example, if a PaymentIntent is confirmed with Konbini and
expires_after_daysset to 2 on Monday JST, the instructions will expire on Wednesday 23:59:59 JST.getter/setter pair - expiresAt ↔ int?
-
The timestamp at which the Konbini payment instructions will expire. Only one of
expires_after_daysorexpires_atmay be set.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- productDescription ↔ String?
-
A product descriptor of up to 22 characters, which will appear to customers at the convenience store.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setupFutureUsage ↔ PaymentMethodOptionsKonbiniSetupFutureUsage?
-
Indicates that you intend to make future payments with this PaymentIntent's payment method.If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.If the payment method is
card_presentand isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.When processing card payments, Stripe usessetup_future_usageto help you comply with regional legislation and network rules, such as SCA.getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → PaymentMethodOptionsKonbini -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object