PaymentSource class
auto generated
Constructors
- PaymentSource()
- Instantiates a new PaymentSource and sets the default values.
Properties
- account ↔ PaymentSourceAccount?
-
The account this bank account belongs to. Only applicable on Accounts (not customers or recipients) This property is only available when returned as an External Account where controller.is_controller is
true.getter/setter pair - accountHolderName ↔ String?
-
The name of the person or business that owns the bank account.
getter/setter pair
- accountHolderType ↔ String?
-
The type of entity that holds the account. This can be either
individualorcompany.getter/setter pair - accountType ↔ String?
-
The bank account type. This can only be
checkingorsavingsin most countries. In Japan, this can only befutsuortoza.getter/setter pair - achCreditTransfer ↔ SourceTypeAchCreditTransfer?
-
The ach_credit_transfer property
getter/setter pair
- achDebit ↔ SourceTypeAchDebit?
-
The ach_debit property
getter/setter pair
- acssDebit ↔ SourceTypeAcssDebit?
-
The acss_debit property
getter/setter pair
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- addressCity ↔ String?
-
City/District/Suburb/Town/Village.
getter/setter pair
- addressCountry ↔ String?
-
Billing address country, if provided when creating card.
getter/setter pair
- addressLine1 ↔ String?
-
Address line 1 (Street address/PO Box/Company name).
getter/setter pair
- addressLine1Check ↔ String?
-
If
address_line1was provided, results of the check:pass,fail,unavailable, orunchecked.getter/setter pair - addressLine2 ↔ String?
-
Address line 2 (Apartment/Suite/Unit/Building).
getter/setter pair
- addressState ↔ String?
-
State/County/Province/Region.
getter/setter pair
- addressZip ↔ String?
-
ZIP or postal code.
getter/setter pair
- addressZipCheck ↔ String?
-
If
address_zipwas provided, results of the check:pass,fail,unavailable, orunchecked.getter/setter pair - alipay ↔ SourceTypeAlipay?
-
The alipay property
getter/setter pair
- allowRedisplay ↔ PaymentSourceAllowRedisplay?
-
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.
getter/setter pair
- amount ↔ int?
-
A positive integer in the smallest currency unit (that is, 100 cents for $1.00, or 1 for ¥1, Japanese Yen being a zero-decimal currency) representing the total amount associated with the source. This is the amount for which the source will be chargeable once ready. Required for
single_usesources.getter/setter pair - auBecsDebit ↔ SourceTypeAuBecsDebit?
-
The au_becs_debit property
getter/setter pair
-
availablePayoutMethods
↔ Iterable<
PaymentSourceAvailablePayoutMethods> ? -
A set of available payout methods for this bank account. Only values from this set should be passed as the
methodwhen creating a payout.getter/setter pair - bancontact ↔ SourceTypeBancontact?
-
The bancontact property
getter/setter pair
- bankName ↔ String?
-
Name of the bank associated with the routing number (e.g.,
WELLS FARGO).getter/setter pair - brand ↔ String?
-
Card brand. Can be
American Express,Cartes Bancaires,Diners Club,Discover,Eftpos Australia,Girocard,JCB,MasterCard,UnionPay,Visa, orUnknown.getter/setter pair - businessProfile ↔ AccountBusinessProfile?
-
Business information about the account.
getter/setter pair
- businessType ↔ PaymentSourceBusinessType?
-
The business type.
getter/setter pair
- capabilities ↔ AccountCapabilities?
-
The capabilities property
getter/setter pair
- card ↔ SourceTypeCard?
-
The card property
getter/setter pair
- cardPresent ↔ SourceTypeCardPresent?
-
The card_present property
getter/setter pair
- chargesEnabled ↔ bool?
-
Whether the account can process charges.
getter/setter pair
- clientSecret ↔ String?
-
The client secret of the source. Used for client-side retrieval using a publishable key.
getter/setter pair
- codeVerification ↔ SourceCodeVerificationFlow?
-
The code_verification property
getter/setter pair
- company ↔ LegalEntityCompany?
-
The company property
getter/setter pair
- controller ↔ AccountUnificationAccountController?
-
The controller property
getter/setter pair
- country ↔ String?
-
The account's country.
getter/setter pair
- created ↔ int?
-
Time at which the account was connected. Measured in seconds since the Unix epoch.
getter/setter pair
- currency ↔ String?
-
Three-letter ISO code for the currency paid out to the bank account.
getter/setter pair
- customer ↔ PaymentSourceCustomer?
-
The ID of the customer that the bank account is associated with.
getter/setter pair
- cvcCheck ↔ String?
-
If a CVC was provided, results of the check:
pass,fail,unavailable, orunchecked. A result of unchecked indicates that CVC was provided but hasn't been checked yet. Checks are typically performed when attaching a card to a Customer object, or when creating a charge. For more details, see Check if a card is valid without a charge.getter/setter pair - defaultCurrency ↔ String?
-
Three-letter ISO currency code representing the default currency for the account. This must be a currency that Stripe supports in the account's country.
getter/setter pair
- defaultForCurrency ↔ bool?
-
Whether this bank account is the default external account for its currency.
getter/setter pair
- detailsSubmitted ↔ bool?
-
Whether account details have been submitted. Accounts with Stripe Dashboard access, which includes Standard accounts, cannot receive payouts before this is true. Accounts where this is false should be directed to an onboarding flow to finish submitting account details.
getter/setter pair
- dynamicLast4 ↔ String?
-
(For tokenized numbers only.) The last four digits of the device account number.
getter/setter pair
- email ↔ String?
-
An email address associated with the account. It's not used for authentication and Stripe doesn't market to this field without explicit approval from the platform.
getter/setter pair
- eps ↔ SourceTypeEps?
-
The eps property
getter/setter pair
- expMonth ↔ int?
-
Two-digit number representing the card's expiration month.
getter/setter pair
- expYear ↔ int?
-
Four-digit number representing the card's expiration year.
getter/setter pair
- externalAccounts ↔ PaymentSourceExternalAccounts?
-
External accounts (bank accounts and debit cards) currently attached to this account. External accounts are only returned for requests where
controller[is_controller]is true.getter/setter pair - fingerprint ↔ String?
-
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
getter/setter pair
- flow ↔ String?
-
The authentication
flowof the source.flowis one ofredirect,receiver,code_verification,none.getter/setter pair - funding ↔ String?
-
Card funding type. Can be
credit,debit,prepaid, orunknown.getter/setter pair - futureRequirements ↔ AccountFutureRequirements?
-
The future_requirements property
getter/setter pair
- giropay ↔ SourceTypeGiropay?
-
The giropay property
getter/setter pair
- groups ↔ AccountGroupMembership?
-
The groups associated with the account.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- ideal ↔ SourceTypeIdeal?
-
The ideal property
getter/setter pair
- iin ↔ String?
-
Issuer identification number of the card.
getter/setter pair
- individual ↔ Person?
-
This is an object representing a person associated with a Stripe account.A platform can only access a subset of data in a person for an account where account.controller.requirement_collection is
stripe, which includes Standard and Express accounts, after creating an Account Link or Account Session to start Connect onboarding.See the Standard onboarding or Express onboarding documentation for information about prefilling information and account onboarding steps. Learn more about handling identity verification with the API.getter/setter pair - klarna ↔ SourceTypeKlarna?
-
The klarna property
getter/setter pair
- last4 ↔ String?
-
The last four digits of the bank account number.
getter/setter pair
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - metadata ↔ PaymentSourceMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- multibanco ↔ SourceTypeMultibanco?
-
The multibanco property
getter/setter pair
- name ↔ String?
-
Cardholder name.
getter/setter pair
- networks ↔ TokenCardNetworks?
-
The networks property
getter/setter pair
- object ↔ PaymentSourceObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- owner ↔ SourceOwner?
-
Information about the owner of the payment instrument that may be used or required by particular source types.
getter/setter pair
- p24 ↔ SourceTypeP24?
-
The p24 property
getter/setter pair
- payoutsEnabled ↔ bool?
-
Whether the funds in this account can be paid out.
getter/setter pair
- receiver ↔ SourceReceiverFlow?
-
The receiver property
getter/setter pair
- redirect ↔ SourceRedirectFlow?
-
The redirect property
getter/setter pair
- regulatedStatus ↔ PaymentSourceRegulatedStatus?
-
Status of a card based on the card issuer.
getter/setter pair
- requirements ↔ AccountRequirements?
-
The requirements property
getter/setter pair
- routingNumber ↔ String?
-
The routing transit number for the bank account.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sepaDebit ↔ SourceTypeSepaDebit?
-
The sepa_debit property
getter/setter pair
- settings ↔ AccountSettings?
-
Options for customizing how the account functions within Stripe.
getter/setter pair
- sofort ↔ SourceTypeSofort?
-
The sofort property
getter/setter pair
- sourceOrder ↔ SourceOrder?
-
The source_order property
getter/setter pair
- statementDescriptor ↔ String?
-
Extra information about a source. This will appear on your customer's statement every time you charge the source.
getter/setter pair
- status ↔ String?
-
For bank accounts, possible values are
new,validated,verified,verification_failed,tokenized_account_number_deactivatedorerrored. A bank account that hasn't had any activity or validation performed isnew. If Stripe can determine that the bank account exists, its status will bevalidated. Note that there often isn’t enough information to know (e.g., for smaller credit unions), and the validation is not always run. If customer bank account verification has succeeded, the bank account status will beverified. If the verification failed for any reason, such as microdeposit failure, the status will beverification_failed. If the status istokenized_account_number_deactivated, the account utilizes a tokenized account number which has been deactivated due to expiration or revocation. This account will need to be reverified to continue using it for money movement. If a payout sent to this bank account fails, we'll set the status toerroredand will not continue to send scheduled payouts until the bank details are updated.For external accounts, possible values arenew,errored,verification_failed, andtokenized_account_number_deactivated. If a payout fails, the status is set toerroredand scheduled payouts are stopped until account details are updated. In the US and India, if we can't verify the owner of the bank account, we'll set the status toverification_failed. Other validations aren't run against external accounts because they're only used for payouts. This means the other statuses don't apply.getter/setter pair - threeDSecure ↔ SourceTypeThreeDSecure?
-
The three_d_secure property
getter/setter pair
- tokenizationMethod ↔ String?
-
If the card number is tokenized, this is the method that was used. Can be
android_pay(includes Google Pay),apple_pay,masterpass,visa_checkout, or null.getter/setter pair - tosAcceptance ↔ AccountTosAcceptance?
-
The tos_acceptance property
getter/setter pair
- type_ ↔ PaymentSourceType?
-
The Stripe account type. Can be
standard,express,custom, ornone.getter/setter pair - usage ↔ String?
-
Either
reusableorsingle_use. Whether this source should be reusable or not. Some source types may or may not be reusable by construction, while others may leave the option at creation. If an incompatible value is passed, an error will be returned.getter/setter pair - wechat ↔ SourceTypeWechat?
-
The wechat property
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → PaymentSource -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object