RefundDestinationDetails class
auto generated
Constructors
- RefundDestinationDetails()
- Instantiates a new RefundDestinationDetails and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- affirm ↔ DestinationDetailsUnimplemented?
-
The affirm property
getter/setter pair
- afterpayClearpay ↔ DestinationDetailsUnimplemented?
-
The afterpay_clearpay property
getter/setter pair
- alipay ↔ DestinationDetailsUnimplemented?
-
The alipay property
getter/setter pair
- alma ↔ DestinationDetailsUnimplemented?
-
The alma property
getter/setter pair
- amazonPay ↔ DestinationDetailsUnimplemented?
-
The amazon_pay property
getter/setter pair
- auBankTransfer ↔ DestinationDetailsUnimplemented?
-
The au_bank_transfer property
getter/setter pair
- blik ↔ RefundDestinationDetailsBlik?
-
The blik property
getter/setter pair
- brBankTransfer ↔ RefundDestinationDetailsBrBankTransfer?
-
The br_bank_transfer property
getter/setter pair
- card ↔ RefundDestinationDetailsCard?
-
The card property
getter/setter pair
- cashapp ↔ DestinationDetailsUnimplemented?
-
The cashapp property
getter/setter pair
- crypto ↔ RefundDestinationDetailsCrypto?
-
The crypto property
getter/setter pair
- customerCashBalance ↔ DestinationDetailsUnimplemented?
-
The customer_cash_balance property
getter/setter pair
- eps ↔ DestinationDetailsUnimplemented?
-
The eps property
getter/setter pair
- euBankTransfer ↔ RefundDestinationDetailsEuBankTransfer?
-
The eu_bank_transfer property
getter/setter pair
- gbBankTransfer ↔ RefundDestinationDetailsGbBankTransfer?
-
The gb_bank_transfer property
getter/setter pair
- giropay ↔ DestinationDetailsUnimplemented?
-
The giropay property
getter/setter pair
- grabpay ↔ DestinationDetailsUnimplemented?
-
The grabpay property
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- jpBankTransfer ↔ RefundDestinationDetailsJpBankTransfer?
-
The jp_bank_transfer property
getter/setter pair
- klarna ↔ DestinationDetailsUnimplemented?
-
The klarna property
getter/setter pair
- mbWay ↔ RefundDestinationDetailsMbWay?
-
The mb_way property
getter/setter pair
- multibanco ↔ RefundDestinationDetailsMultibanco?
-
The multibanco property
getter/setter pair
- mxBankTransfer ↔ RefundDestinationDetailsMxBankTransfer?
-
The mx_bank_transfer property
getter/setter pair
- nzBankTransfer ↔ DestinationDetailsUnimplemented?
-
The nz_bank_transfer property
getter/setter pair
- p24 ↔ RefundDestinationDetailsP24?
-
The p24 property
getter/setter pair
- paynow ↔ DestinationDetailsUnimplemented?
-
The paynow property
getter/setter pair
- paypal ↔ RefundDestinationDetailsPaypal?
-
The paypal property
getter/setter pair
- pix ↔ DestinationDetailsUnimplemented?
-
The pix property
getter/setter pair
- revolut ↔ DestinationDetailsUnimplemented?
-
The revolut property
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sofort ↔ DestinationDetailsUnimplemented?
-
The sofort property
getter/setter pair
- swish ↔ RefundDestinationDetailsSwish?
-
The swish property
getter/setter pair
- thBankTransfer ↔ RefundDestinationDetailsThBankTransfer?
-
The th_bank_transfer property
getter/setter pair
- twint ↔ DestinationDetailsUnimplemented?
-
The twint property
getter/setter pair
- type_ ↔ String?
-
The type of transaction-specific details of the payment method used in the refund (e.g.,
card). An additional hash is included ondestination_detailswith a name matching this value. It contains information specific to the refund transaction.getter/setter pair - usBankTransfer ↔ RefundDestinationDetailsUsBankTransfer?
-
The us_bank_transfer property
getter/setter pair
- wechatPay ↔ DestinationDetailsUnimplemented?
-
The wechat_pay property
getter/setter pair
- zip ↔ DestinationDetailsUnimplemented?
-
The zip property
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → RefundDestinationDetails -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object