SetupAttemptPaymentMethodDetails class
auto generated
Constructors
- SetupAttemptPaymentMethodDetails()
- Instantiates a new SetupAttemptPaymentMethodDetails and sets the default values.
Properties
- acssDebit ↔ SetupAttemptPaymentMethodDetailsAcssDebit?
-
The acss_debit property
getter/setter pair
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- amazonPay ↔ SetupAttemptPaymentMethodDetailsAmazonPay?
-
The amazon_pay property
getter/setter pair
- auBecsDebit ↔ SetupAttemptPaymentMethodDetailsAuBecsDebit?
-
The au_becs_debit property
getter/setter pair
- bacsDebit ↔ SetupAttemptPaymentMethodDetailsBacsDebit?
-
The bacs_debit property
getter/setter pair
- bancontact ↔ SetupAttemptPaymentMethodDetailsBancontact?
-
The bancontact property
getter/setter pair
- boleto ↔ SetupAttemptPaymentMethodDetailsBoleto?
-
The boleto property
getter/setter pair
- card ↔ SetupAttemptPaymentMethodDetailsCard?
-
The card property
getter/setter pair
- cardPresent ↔ SetupAttemptPaymentMethodDetailsCardPresent?
-
The card_present property
getter/setter pair
- cashapp ↔ SetupAttemptPaymentMethodDetailsCashapp?
-
The cashapp property
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- ideal ↔ SetupAttemptPaymentMethodDetailsIdeal?
-
The ideal property
getter/setter pair
- kakaoPay ↔ SetupAttemptPaymentMethodDetailsKakaoPay?
-
The kakao_pay property
getter/setter pair
- klarna ↔ SetupAttemptPaymentMethodDetailsKlarna?
-
The klarna property
getter/setter pair
- krCard ↔ SetupAttemptPaymentMethodDetailsKrCard?
-
The kr_card property
getter/setter pair
- link ↔ SetupAttemptPaymentMethodDetailsLink?
-
The link property
getter/setter pair
-
The naver_pay property
getter/setter pair
- nzBankAccount ↔ SetupAttemptPaymentMethodDetailsNzBankAccount?
-
The nz_bank_account property
getter/setter pair
- paypal ↔ SetupAttemptPaymentMethodDetailsPaypal?
-
The paypal property
getter/setter pair
- payto ↔ SetupAttemptPaymentMethodDetailsPayto?
-
The payto property
getter/setter pair
- revolutPay ↔ SetupAttemptPaymentMethodDetailsRevolutPay?
-
The revolut_pay property
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sepaDebit ↔ SetupAttemptPaymentMethodDetailsSepaDebit?
-
The sepa_debit property
getter/setter pair
- sofort ↔ SetupAttemptPaymentMethodDetailsSofort?
-
The sofort property
getter/setter pair
- type_ ↔ String?
-
The type of the payment method used in the SetupIntent (e.g.,
card). An additional hash is included onpayment_method_detailswith a name matching this value. It contains confirmation-specific information for the payment method.getter/setter pair - usBankAccount ↔ SetupAttemptPaymentMethodDetailsUsBankAccount?
-
The us_bank_account property
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → SetupAttemptPaymentMethodDetails -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object