SetupAttemptPaymentMethodDetailsCard class
auto generated
Constructors
- SetupAttemptPaymentMethodDetailsCard()
- Instantiates a new SetupAttemptPaymentMethodDetailsCard and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- brand ↔ String?
-
Card brand. Can be
amex,cartes_bancaires,diners,discover,eftpos_au,jcb,link,mastercard,unionpay,visaorunknown.getter/setter pair - checks ↔ SetupAttemptPaymentMethodDetailsCardChecks?
-
Check results by Card networks on Card address and CVC at the time of authorization
getter/setter pair
- country ↔ String?
-
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.
getter/setter pair
- expMonth ↔ int?
-
Two-digit number representing the card's expiration month.
getter/setter pair
- expYear ↔ int?
-
Four-digit number representing the card's expiration year.
getter/setter pair
- fingerprint ↔ String?
-
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.
getter/setter pair
- funding ↔ String?
-
Card funding type. Can be
credit,debit,prepaid, orunknown.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- last4 ↔ String?
-
The last four digits of the card.
getter/setter pair
- network ↔ String?
-
Identifies which network this charge was processed on. Can be
amex,cartes_bancaires,diners,discover,eftpos_au,interac,jcb,link,mastercard,unionpay,visa, orunknown.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- threeDSecure ↔ ThreeDSecureDetails?
-
Populated if this authorization used 3D Secure authentication.
getter/setter pair
- wallet ↔ SetupAttemptPaymentMethodDetailsCardWallet?
-
If this Card is part of a card wallet, this contains the details of the card wallet.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → SetupAttemptPaymentMethodDetailsCard -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object