SetupAttemptPaymentMethodDetailsCardWallet class
auto generated
Constructors
- SetupAttemptPaymentMethodDetailsCardWallet()
- Instantiates a new SetupAttemptPaymentMethodDetailsCardWallet and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- applePay ↔ PaymentMethodDetailsCardWalletApplePay?
-
The apple_pay property
getter/setter pair
- googlePay ↔ PaymentMethodDetailsCardWalletGooglePay?
-
The google_pay property
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type_ ↔ SetupAttemptPaymentMethodDetailsCardWalletType?
-
The type of the card wallet, one of
apple_pay,google_pay, orlink. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → SetupAttemptPaymentMethodDetailsCardWallet -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object