SetupIntentNextAction class
auto generated
Constructors
- SetupIntentNextAction()
- Instantiates a new SetupIntentNextAction and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- cashappHandleRedirectOrDisplayQrCode ↔ PaymentIntentNextActionCashappHandleRedirectOrDisplayQrCode?
-
The cashapp_handle_redirect_or_display_qr_code property
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- redirectToUrl ↔ SetupIntentNextActionRedirectToUrl?
-
The redirect_to_url property
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type_ ↔ String?
-
Type of the next action to perform. Refer to the other child attributes under
next_actionfor available values. Examples include:redirect_to_url,use_stripe_sdk,alipay_handle_redirect,oxxo_display_details, orverify_with_microdeposits.getter/setter pair - useStripeSdk ↔ SetupIntentNextActionUseStripeSdk?
-
When confirming a SetupIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows. The shape of the contents is subject to change and is only intended to be used by Stripe.js.
getter/setter pair
- verifyWithMicrodeposits ↔ SetupIntentNextActionVerifyWithMicrodeposits?
-
The verify_with_microdeposits property
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → SetupIntentNextAction -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object