useStripeSdk property
When confirming a SetupIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows. The shape of the contents is subject to change and is only intended to be used by Stripe.js.
Implementation
SetupIntentNextActionUseStripeSdk? useStripeSdk;