ShippingRate class
auto generated Shipping rates describe the price of shipping presented to your customers andapplied to a purchase. For more information, see Charge for shipping.
Constructors
- ShippingRate()
- Instantiates a new ShippingRate and sets the default values.
Properties
- active ↔ bool?
-
Whether the shipping rate can be used for new purchases. Defaults to
true.getter/setter pair -
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- created ↔ int?
-
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
- deliveryEstimate ↔ ShippingRateDeliveryEstimate?
-
The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions.
getter/setter pair
- displayName ↔ String?
-
The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions.
getter/setter pair
- fixedAmount ↔ ShippingRateFixedAmount?
-
The fixed_amount property
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - metadata ↔ ShippingRateMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- object ↔ ShippingRateObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taxBehavior ↔ ShippingRateTaxBehavior?
-
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of
inclusive,exclusive, orunspecified.getter/setter pair - taxCode ↔ ShippingRateTaxCode?
-
A tax code ID. The Shipping tax code is
txcd_92010001.getter/setter pair - type_ ↔ ShippingRateType?
-
The type of calculation to use on the shipping rate.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → ShippingRate -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object