SourceOwner class

auto generated

Constructors

SourceOwner()
Instantiates a new SourceOwner and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
address Address?
Owner's address.
getter/setter pair
email String?
Owner's email address.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Owner's full name.
getter/setter pair
phone String?
Owner's phone number (including extension).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verifiedAddress Address?
Verified owner's address. Verified values are verified or provided by the payment method directly (and if supported) at the time of authorization or settlement. They cannot be set or mutated.
getter/setter pair
verifiedEmail String?
Verified owner's email address. Verified values are verified or provided by the payment method directly (and if supported) at the time of authorization or settlement. They cannot be set or mutated.
getter/setter pair
verifiedName String?
Verified owner's full name. Verified values are verified or provided by the payment method directly (and if supported) at the time of authorization or settlement. They cannot be set or mutated.
getter/setter pair
verifiedPhone String?
Verified owner's phone number (including extension). Verified values are verified or provided by the payment method directly (and if supported) at the time of authorization or settlement. They cannot be set or mutated.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) SourceOwner
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object