SourceTransaction class

auto generated Some payment methods have no required amount that a customer must send.Customers can be instructed to send any amount, and it can be made up ofmultiple transactions. As such, sources can have multiple associatedtransactions.

Constructors

SourceTransaction()
Instantiates a new SourceTransaction and sets the default values.

Properties

achCreditTransfer SourceTransactionAchCreditTransferData?
The ach_credit_transfer property
getter/setter pair
additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
amount int?
A positive integer in the smallest currency unit (that is, 100 cents for $1.00, or 1 for ¥1, Japanese Yen being a zero-decimal currency) representing the amount your customer has pushed to the receiver.
getter/setter pair
chfCreditTransfer SourceTransactionChfCreditTransferData?
The chf_credit_transfer property
getter/setter pair
created int?
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
currency String?
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
gbpCreditTransfer SourceTransactionGbpCreditTransferData?
The gbp_credit_transfer property
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Unique identifier for the object.
getter/setter pair
livemode bool?
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
getter/setter pair
object SourceTransactionObject?
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
paperCheck SourceTransactionPaperCheckData?
The paper_check property
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sepaCreditTransfer SourceTransactionSepaCreditTransferData?
The sepa_credit_transfer property
getter/setter pair
source String?
The ID of the source this transaction is attached to.
getter/setter pair
status String?
The status of the transaction, one of succeeded, pending, or failed.
getter/setter pair
type_ SourceTransactionType?
The type of source this transaction is attached to.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) SourceTransaction
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object