SubscriptionItem class
auto generated Subscription items allow you to create customer subscriptions with more thanone plan, making it easy to represent complex billing relationships.
Constructors
- SubscriptionItem()
- Instantiates a new SubscriptionItem and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- billingThresholds ↔ SubscriptionItemBillingThresholds?
-
Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period
getter/setter pair
- created ↔ int?
-
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
- currentPeriodEnd ↔ int?
-
The end time of this subscription item's current billing period.
getter/setter pair
- currentPeriodStart ↔ int?
-
The start time of this subscription item's current billing period.
getter/setter pair
-
discounts
↔ Iterable<
String> ? -
The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use
expand[]=discountsto expand each discount.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- metadata ↔ SubscriptionItemMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- object ↔ SubscriptionItemObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- price ↔ Price?
-
Prices define the unit cost, currency, and (optional) billing cycle for both recurring and one-time purchases of products.Products help you track inventory or provisioning, and prices help you track payment terms. Different physical goods or levels of service should be represented by products, and pricing options should be represented by prices. This approach lets you change prices without having to change your provisioning scheme.For example, you might have a single "gold" product that has prices for $10/month, $100/year, and €9 once.Related guides: Set up a subscription, create an invoice, and more about products and prices.
getter/setter pair
- quantity ↔ int?
-
The quantity of the plan to which the customer should be subscribed.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscription ↔ String?
-
The
subscriptionthissubscription_itembelongs to.getter/setter pair -
taxRates
↔ Iterable<
TaxRate> ? -
The tax rates which apply to this
subscription_item. When set, thedefault_tax_rateson the subscription do not apply to thissubscription_item.getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → SubscriptionItem -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object