billingThresholds property

SubscriptionItemBillingThresholds? billingThresholds
getter/setter pair

Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period

Implementation

SubscriptionItemBillingThresholds? billingThresholds;