SubscriptionScheduleConfigurationItem class
auto generated A phase item describes the price and quantity of a phase.
Constructors
- SubscriptionScheduleConfigurationItem()
- Instantiates a new SubscriptionScheduleConfigurationItem and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- billingThresholds ↔ SubscriptionItemBillingThresholds?
-
Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period
getter/setter pair
-
discounts
↔ Iterable<
DiscountsResourceStackableDiscount> ? -
The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use
expand[]=discountsto expand each discount.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- metadata ↔ SubscriptionScheduleConfigurationItemMetadata?
-
Set of key-value pairs that you can attach to an item. Metadata on this item will update the underlying subscription item's
metadatawhen the phase is entered.getter/setter pair - price ↔ SubscriptionScheduleConfigurationItemPrice?
-
ID of the price to which the customer should be subscribed.
getter/setter pair
- quantity ↔ int?
-
Quantity of the plan to which the customer should be subscribed.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
taxRates
↔ Iterable<
TaxRate> ? -
The tax rates which apply to this
phase_item. When set, thedefault_tax_rateson the phase do not apply to thisphase_item.getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → SubscriptionScheduleConfigurationItem -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object