metadata property
Set of key-value pairs that you can attach to an item. Metadata on this item will update the underlying subscription item's metadata when the phase is entered.
Implementation
SubscriptionScheduleConfigurationItemMetadata? metadata;