SubscriptionSchedulePhaseConfigurationDefaultPaymentMethod class
auto generated Composed type wrapper for classes PaymentMethod, String?
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- paymentMethod ↔ PaymentMethod?
-
Composed type representation for type PaymentMethod
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- string_ ↔ String?
-
Composed type representation for type String?
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → SubscriptionSchedulePhaseConfigurationDefaultPaymentMethod -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object