SubscriptionsResourcePendingUpdate class
auto generated Pending Updates store the changes pending from a previous update that will be appliedto the Subscription upon successful payment.
Constructors
- SubscriptionsResourcePendingUpdate()
- Instantiates a new SubscriptionsResourcePendingUpdate and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- billingCycleAnchor ↔ int?
-
If the update is applied, determines the date of the first full invoice, and, for plans with
monthoryearintervals, the day of the month for subsequent invoices. The timestamp is in UTC format.getter/setter pair - expiresAt ↔ int?
-
The point after which the changes reflected by this update will be discarded and no longer applied.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subscriptionItems
↔ Iterable<
SubscriptionItem> ? -
List of subscription items, each with an attached plan, that will be set if the update is applied.
getter/setter pair
- trialEnd ↔ int?
-
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time, if the update is applied.
getter/setter pair
- trialFromPlan ↔ bool?
-
Indicates if a plan's
trial_period_daysshould be applied to the subscription. Settingtrial_endper subscription is preferred, and this defaults tofalse. Setting this flag totruetogether withtrial_endis not allowed. See Using trial periods on subscriptions to learn more.getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → SubscriptionsResourcePendingUpdate -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object