subscriptionItems property
List of subscription items, each with an attached plan, that will be set if the update is applied.
Implementation
Iterable<SubscriptionItem>? subscriptionItems;
List of subscription items, each with an attached plan, that will be set if the update is applied.
Iterable<SubscriptionItem>? subscriptionItems;