trialEnd property
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time, if the update is applied.
Implementation
int? trialEnd;
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time, if the update is applied.
int? trialEnd;