CalculationLineItem class
auto generated
Constructors
- CalculationLineItem()
- Instantiates a new CalculationLineItem and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- amount ↔ int?
-
The line item amount in the smallest currency unit. If
tax_behavior=inclusive, then this amount includes taxes. Otherwise, taxes were calculated on top of this amount.getter/setter pair - amountTax ↔ int?
-
The amount of tax calculated for this line item, in the smallest currency unit.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - metadata ↔ CalculationLineItemMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- object ↔ CalculationLineItemObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- product ↔ String?
-
The ID of an existing Product.
getter/setter pair
- quantity ↔ int?
-
The number of units of the item being purchased. For reversals, this is the quantity reversed.
getter/setter pair
- reference ↔ String?
-
A custom identifier for this line item.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taxBehavior ↔ CalculationLineItemTaxBehavior?
-
Specifies whether the
amountincludes taxes. Iftax_behavior=inclusive, then the amount includes taxes.getter/setter pair -
taxBreakdown
↔ Iterable<
TaxProductResourceLineItemTaxBreakdown> ? -
Detailed account of taxes relevant to this line item.
getter/setter pair
- taxCode ↔ String?
-
The tax code ID used for this resource.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → CalculationLineItem -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object