active property

bool? active
getter/setter pair

Defaults to true. When set to false, this tax rate cannot be used with new applications or Checkout Sessions, but will still work for subscriptions and invoices that already have it set.

Implementation

bool? active;