models/tax_rate_flat_amount library
Classes
- TaxRateFlatAmount
-
auto generated
The amount of the tax rate when the
rate_type`` isflat_amount. Tax rates withrate_typepercentagecan vary based on the transaction, resulting in this field beingnull`. This field exposes the amount and currency of the flat tax rate.