Location class
auto generated A Location represents a grouping of readers.Related guide: Fleet management
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- address ↔ Address?
-
The address property
getter/setter pair
- addressKana ↔ LegalEntityJapanAddress?
-
The address_kana property
getter/setter pair
- addressKanji ↔ LegalEntityJapanAddress?
-
The address_kanji property
getter/setter pair
- configurationOverrides ↔ String?
-
The ID of a configuration that will be used to customize all readers in this location.
getter/setter pair
- displayName ↔ String?
-
The display name of the location.
getter/setter pair
- displayNameKana ↔ String?
-
The Kana variation of the display name of the location.
getter/setter pair
- displayNameKanji ↔ String?
-
The Kanji variation of the display name of the location.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - metadata ↔ LocationMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- object ↔ LocationObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- phone ↔ String?
-
The phone number of the location.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → Location -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object