Reader class
auto generated A Reader represents a physical device for accepting payment details.Related guide: Connecting to a reader
Properties
- action ↔ TerminalReaderReaderResourceReaderAction?
-
The most recent action performed by the reader.
getter/setter pair
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- deviceSwVersion ↔ String?
-
The current software version of the reader.
getter/setter pair
- deviceType ↔ ReaderDeviceType?
-
Device type of the reader.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- ipAddress ↔ String?
-
The local IP address of the reader.
getter/setter pair
- label ↔ String?
-
Custom label given to the reader for easier identification.
getter/setter pair
- lastSeenAt ↔ int?
-
The last time this reader reported to Stripe backend. Timestamp is measured in milliseconds since the Unix epoch. Unlike most other Stripe timestamp fields which use seconds, this field uses milliseconds.
getter/setter pair
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - location ↔ ReaderLocation?
-
The location identifier of the reader.
getter/setter pair
- metadata ↔ ReaderMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- object ↔ ReaderObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serialNumber ↔ String?
-
Serial number of the reader.
getter/setter pair
- status ↔ ReaderStatus?
-
The networking status of the reader. We do not recommend using this field in flows that may block taking payments.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → Reader -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object