TerminalReaderReaderResourceInput class

auto generated Represents an input to be collected using the reader

Constructors

TerminalReaderReaderResourceInput()
Instantiates a new TerminalReaderReaderResourceInput and sets the default values.

Properties

additionalData Map<String, Object?>
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
customText TerminalReaderReaderResourceCustomText?
Default text of input being collected.
getter/setter pair
email TerminalReaderReaderResourceEmail?
Information about a email being collected using a reader
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
numeric TerminalReaderReaderResourceNumeric?
Information about a number being collected using a reader
getter/setter pair
phone TerminalReaderReaderResourcePhone?
Information about a phone number being collected using a reader
getter/setter pair
required_ bool?
Indicate that this input is required, disabling the skip button.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection TerminalReaderReaderResourceSelection?
Information about a selection being collected using a reader
getter/setter pair
signature TerminalReaderReaderResourceSignature?
Information about a signature being collected using a reader
getter/setter pair
skipped bool?
Indicate that this input was skipped by the user.
getter/setter pair
text TerminalReaderReaderResourceText?
Information about text being collected using a reader
getter/setter pair
toggles Iterable<TerminalReaderReaderResourceToggle>?
List of toggles being collected. Values are present if collection is complete.
getter/setter pair
type_ TerminalReaderReaderResourceInputType?
Type of input being collected.
getter/setter pair

Methods

getFieldDeserializers() Map<String, void Function(ParseNode)>
The deserialization information for the current model
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(SerializationWriter writer) → void
Serializes information the current object writer Serialization writer to use to serialize this model
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromDiscriminatorValue(ParseNode parseNode) TerminalReaderReaderResourceInput
Creates a new instance of the appropriate class based on discriminator value parseNode The parse node to use to read the discriminator value and create the object