TerminalReaderReaderResourceReaderAction class
auto generated Represents an action performed by the reader
Constructors
- TerminalReaderReaderResourceReaderAction()
- Instantiates a new TerminalReaderReaderResourceReaderAction and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- collectInputs ↔ TerminalReaderReaderResourceCollectInputsAction?
-
Represents a reader action to collect customer inputs
getter/setter pair
- collectPaymentMethod ↔ TerminalReaderReaderResourceCollectPaymentMethodAction?
-
Represents a reader action to collect a payment method
getter/setter pair
- confirmPaymentIntent ↔ TerminalReaderReaderResourceConfirmPaymentIntentAction?
-
Represents a reader action to confirm a payment
getter/setter pair
- failureCode ↔ String?
-
Failure code, only set if status is
failed.getter/setter pair - failureMessage ↔ String?
-
Detailed failure message, only set if status is
failed.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- processPaymentIntent ↔ TerminalReaderReaderResourceProcessPaymentIntentAction?
-
Represents a reader action to process a payment intent
getter/setter pair
- processSetupIntent ↔ TerminalReaderReaderResourceProcessSetupIntentAction?
-
Represents a reader action to process a setup intent
getter/setter pair
- refundPayment ↔ TerminalReaderReaderResourceRefundPaymentAction?
-
Represents a reader action to refund a payment
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setReaderDisplay ↔ TerminalReaderReaderResourceSetReaderDisplayAction?
-
Represents a reader action to set the reader display
getter/setter pair
- status ↔ TerminalReaderReaderResourceReaderActionStatus?
-
Status of the action performed by the reader.
getter/setter pair
- type_ ↔ TerminalReaderReaderResourceReaderActionType?
-
Type of action performed by the reader.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → TerminalReaderReaderResourceReaderAction -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object