Topup class
auto generated To top up your Stripe balance, you create a top-up object. You can retrieveindividual top-ups, as well as list all top-ups. Top-ups are identified by aunique, random ID.Related guide: Topping up your platform account
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- amount ↔ int?
-
Amount transferred.
getter/setter pair
- balanceTransaction ↔ TopupBalanceTransaction?
-
ID of the balance transaction that describes the impact of this top-up on your account balance. May not be specified depending on status of top-up.
getter/setter pair
- created ↔ int?
-
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
- currency ↔ String?
-
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
- description ↔ String?
-
An arbitrary string attached to the object. Often useful for displaying to users.
getter/setter pair
- expectedAvailabilityDate ↔ int?
-
Date the funds are expected to arrive in your Stripe account for payouts. This factors in delays like weekends or bank holidays. May not be specified depending on status of top-up.
getter/setter pair
- failureCode ↔ String?
-
Error code explaining reason for top-up failure if available (see the errors section for a list of codes).
getter/setter pair
- failureMessage ↔ String?
-
Message to user further explaining reason for top-up failure if available.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - metadata ↔ TopupMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- object ↔ TopupObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source ↔ Source?
-
The source field is deprecated. It might not always be present in the API response.
getter/setter pair
- statementDescriptor ↔ String?
-
Extra information about a top-up. This will appear on your source's bank statement. It must contain at least one letter.
getter/setter pair
- status ↔ TopupStatus?
-
The status of the top-up is either
canceled,failed,pending,reversed, orsucceeded.getter/setter pair - transferGroup ↔ String?
-
A string that identifies this top-up as part of a group.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → Topup -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object