destinationPayment property
If the destination is a Stripe account, this will be the ID of the payment that the destination account received for the transfer.
Implementation
TransferDestinationPayment? destinationPayment;
If the destination is a Stripe account, this will be the ID of the payment that the destination account received for the transfer.
TransferDestinationPayment? destinationPayment;