TransferReversal class
auto generated Stripe Connect platforms can reverse transfers made to aconnected account, either entirely or partially, and can also specify whetherto refund any related application fees. Transfer reversals add to theplatform's balance and subtract from the destination account's balance.Reversing a transfer that was made for a destinationcharge is allowed only up to the amount ofthe charge. It is possible to reverse atransfer_grouptransfer only if the destination account has enough balance to cover thereversal.Related guide: Reverse transfers
Constructors
- TransferReversal()
- Instantiates a new TransferReversal and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- amount ↔ int?
-
Amount, in cents (or local equivalent).
getter/setter pair
- balanceTransaction ↔ TransferReversalBalanceTransaction?
-
Balance transaction that describes the impact on your account balance.
getter/setter pair
- created ↔ int?
-
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
- currency ↔ String?
-
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
- destinationPaymentRefund ↔ TransferReversalDestinationPaymentRefund?
-
Linked payment refund for the transfer reversal.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- metadata ↔ TransferReversalMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- object ↔ TransferReversalObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceRefund ↔ TransferReversalSourceRefund?
-
ID of the refund responsible for the transfer reversal.
getter/setter pair
- transfer ↔ TransferReversalTransfer?
-
ID of the transfer that was reversed.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → TransferReversal -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object