OutboundTransfer class
auto generated
Use OutboundTransfers to transfer funds from a FinancialAccount to a PaymentMethod belonging to the same entity. To send funds to a different party, use OutboundPayments instead. You can send funds over ACH rails or through a domestic wire transfer to a user's own external bank account.Simulate OutboundTransfer state changes with the /v1/test_helpers/treasury/outbound_transfers endpoints. These methods can only be called on test mode objects.Related guide: Moving money with Treasury using OutboundTransfer objects
Constructors
- OutboundTransfer()
- Instantiates a new OutboundTransfer and sets the default values.
Properties
-
additionalData
↔ Map<
String, Object?> -
Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
getter/setter pairoverride
- amount ↔ int?
-
Amount (in cents) transferred.
getter/setter pair
- cancelable ↔ bool?
-
Returns
trueif the object can be canceled, andfalseotherwise.getter/setter pair - created ↔ int?
-
Time at which the object was created. Measured in seconds since the Unix epoch.
getter/setter pair
- currency ↔ String?
-
Three-letter ISO currency code, in lowercase. Must be a supported currency.
getter/setter pair
- description ↔ String?
-
An arbitrary string attached to the object. Often useful for displaying to users.
getter/setter pair
- destinationPaymentMethod ↔ String?
-
The PaymentMethod used as the payment instrument for an OutboundTransfer.
getter/setter pair
- destinationPaymentMethodDetails ↔ OutboundTransfersPaymentMethodDetails?
-
The destination_payment_method_details property
getter/setter pair
- expectedArrivalDate ↔ int?
-
The date when funds are expected to arrive in the destination account.
getter/setter pair
- financialAccount ↔ String?
-
The FinancialAccount that funds were pulled from.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostedRegulatoryReceiptUrl ↔ String?
-
A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe's money transmission licenses.
getter/setter pair
- id ↔ String?
-
Unique identifier for the object.
getter/setter pair
- livemode ↔ bool?
-
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode.getter/setter pair - metadata ↔ OutboundTransferMetadata?
-
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
getter/setter pair
- object ↔ OutboundTransferObject?
-
String representing the object's type. Objects of the same type share the same value.
getter/setter pair
- returnedDetails ↔ TreasuryOutboundTransfersResourceReturnedDetails?
-
Details about a returned OutboundTransfer. Only set when the status is
returned.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statementDescriptor ↔ String?
-
Information about the OutboundTransfer to be sent to the recipient account.
getter/setter pair
- status ↔ OutboundTransferStatus?
-
Current status of the OutboundTransfer:
processing,failed,canceled,posted,returned. An OutboundTransfer isprocessingif it has been created and is pending. The status changes topostedonce the OutboundTransfer has been "confirmed" and funds have left the account, or tofailedorcanceled. If an OutboundTransfer fails to arrive at its destination, its status will change toreturned.getter/setter pair - statusTransitions ↔ TreasuryOutboundTransfersResourceStatusTransitions?
-
The status_transitions property
getter/setter pair
- trackingDetails ↔ TreasuryOutboundTransfersResourceOutboundTransferResourceTrackingDetails?
-
Details about network-specific tracking information if available.
getter/setter pair
- transaction ↔ OutboundTransferTransaction?
-
The Transaction associated with this object.
getter/setter pair
Methods
-
getFieldDeserializers(
) → Map< String, void Function(ParseNode)> -
The deserialization information for the current model
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
SerializationWriter writer) → void -
Serializes information the current object
writerSerialization writer to use to serialize this modeloverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFromDiscriminatorValue(
ParseNode parseNode) → OutboundTransfer -
Creates a new instance of the appropriate class based on discriminator value
parseNodeThe parse node to use to read the discriminator value and create the object