BalanceRequestBuilderGetQueryParameters class
auto generated
Retrieves the current account balance, based on the authentication that was used to make the request. For a sample request, see Accounting for negative balances.
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
Extracts the query parameters into a map for the URI template parsing.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited