FilesRequestBuilder class
auto generated Builds and executes requests for operations under \v1\files
- Inheritance
-
- Object
- BaseRequestBuilder<
FilesRequestBuilder> - FilesRequestBuilder
Constructors
-
FilesRequestBuilder(Map<
String, dynamic> pathParameters, RequestAdapter requestAdapter) -
Instantiates a new FilesRequestBuilder and sets the default values.
pathParametersPath parameters for the requestrequestAdapterThe request adapter to use to execute the requests. - FilesRequestBuilder.withUrl(String rawUrl, RequestAdapter requestAdapter)
-
Instantiates a new FilesRequestBuilder and sets the default values.
rawUrlThe raw URL to use for the request builder.requestAdapterThe request adapter to use to execute the requests.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pathParameters
↔ Map<
String, dynamic> -
The path parameters of the request.
getter/setter pairinherited
- requestAdapter ↔ RequestAdapter
-
The request adapter to use to execute the request.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- urlTemplate ↔ String
-
Url template to use to build the URL for the current request builder.
getter/setter pairinherited
Methods
-
byFile(
String file) → WithFileItemRequestBuilder -
Gets an item from the ApiSdk.v1.files.item collection
fileUnique identifier of the item -
clone(
) → FilesRequestBuilder -
Clones the requestbuilder.
override
-
getAsync(
FilesGetRequestBody body, [void requestConfiguration(RequestConfiguration< FilesRequestBuilderGetQueryParameters> )?]) → Future<FilesGetResponse?> - Returns a list of the files that your account has access to. Stripe sorts and returns the files by their creation dates, placing the most recently created files at the top.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
postAsync(
MultipartBody body, [void requestConfiguration(RequestConfiguration< DefaultQueryParameters> )?]) → Future<File?> -
To upload a file to Stripe, you need to send a request of type
multipart/form-data. Include the file you want to upload in the request, and the parameters for creating a file. -
toGetRequestInformation(
FilesGetRequestBody body, [void requestConfiguration(RequestConfiguration< FilesRequestBuilderGetQueryParameters> )?]) → RequestInformation - Returns a list of the files that your account has access to. Stripe sorts and returns the files by their creation dates, placing the most recently created files at the top.
-
toPostRequestInformation(
MultipartBody body, [void requestConfiguration(RequestConfiguration< DefaultQueryParameters> )?]) → RequestInformation -
To upload a file to Stripe, you need to send a request of type
multipart/form-data. Include the file you want to upload in the request, and the parameters for creating a file. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited