WithFileItemRequestBuilder class
auto generated Builds and executes requests for operations under \v1\files{file}
- Inheritance
-
- Object
- BaseRequestBuilder<
WithFileItemRequestBuilder> - WithFileItemRequestBuilder
Constructors
-
WithFileItemRequestBuilder(Map<
String, dynamic> pathParameters, RequestAdapter requestAdapter) -
Instantiates a new WithFileItemRequestBuilder and sets the default values.
pathParametersPath parameters for the requestrequestAdapterThe request adapter to use to execute the requests. - WithFileItemRequestBuilder.withUrl(String rawUrl, RequestAdapter requestAdapter)
-
Instantiates a new WithFileItemRequestBuilder and sets the default values.
rawUrlThe raw URL to use for the request builder.requestAdapterThe request adapter to use to execute the requests.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pathParameters
↔ Map<
String, dynamic> -
The path parameters of the request.
getter/setter pairinherited
- requestAdapter ↔ RequestAdapter
-
The request adapter to use to execute the request.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- urlTemplate ↔ String
-
Url template to use to build the URL for the current request builder.
getter/setter pairinherited
Methods
-
clone(
) → WithFileItemRequestBuilder -
Clones the requestbuilder.
override
-
getAsync(
WithFileGetRequestBody body, [void requestConfiguration(RequestConfiguration< WithFileItemRequestBuilderGetQueryParameters> )?]) → Future<File?> - Retrieves the details of an existing file object. After you supply a unique file ID, Stripe returns the corresponding file object. Learn how to access file contents.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toGetRequestInformation(
WithFileGetRequestBody body, [void requestConfiguration(RequestConfiguration< WithFileItemRequestBuilderGetQueryParameters> )?]) → RequestInformation - Retrieves the details of an existing file object. After you supply a unique file ID, Stripe returns the corresponding file object. Learn how to access file contents.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited